"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Autocomplete = Autocomplete;
exports.AutocompleteOptions = AutocompleteOptions;
exports.AutocompleteOption = AutocompleteOption;
exports.AutocompleteFooter = AutocompleteFooter;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _TextField = require("../TextField");

var _Theme = require("../Theme");

var _Popper = require("../Popper");

var _Icon = require("../Icon");

var _focus = require("../../utilities/focus");

var _Autocomplete = _interopRequireDefault(require("./Autocomplete.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function Autocomplete(_ref) {
  var error = _ref.error,
      id = _ref.id,
      label = _ref.label,
      name = _ref.name,
      onInput = _ref.onInput,
      onChange = _ref.onChange,
      options = _ref.options,
      onSelectOption = _ref.onSelectOption,
      value = _ref.value,
      ariaLabel = _ref.ariaLabel,
      title = _ref.title,
      children = _ref.children,
      required = _ref.required,
      autocomplete = _ref.autocomplete,
      disabled = _ref.disabled,
      readonly = _ref.readonly;

  var _useState = (0, _react.useState)(false),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var _useState3 = (0, _react.useState)(0),
      _useState4 = _slicedToArray(_useState3, 2),
      selected = _useState4[0],
      setSelected = _useState4[1];

  var fieldRef = (0, _react.useRef)(null);
  var popperRef = (0, _react.useRef)(null);
  var closeButtonRef = (0, _react.useRef)(null);

  var _useThemeConfiguratio = (0, _Theme.useThemeConfiguration)(),
      controlsBackground = _useThemeConfiguratio.controls.background,
      textFieldsBackground = _useThemeConfiguratio.textFields.background;

  var background = textFieldsBackground || controlsBackground || 'surfaceTertiary';

  var handleOpen = function handleOpen() {
    if (open) {
      return;
    }

    if (options.length === 0) {
      return;
    } // Prevents opening the autocomplete when the address field is filled
    // via browser autofill.


    if (fieldRef.current == null || !(0, _focus.isFocused)(fieldRef.current)) return;
    setOpen(true);
  };

  var handleClose = (0, _react.useCallback)(function () {
    if (!open) {
      return;
    }

    setOpen(false);
  }, [open]);

  var handleInput = function handleInput(newValue) {
    if (newValue === '') {
      handleClose();
    } else {
      handleOpen();
    }

    onInput === null || onInput === void 0 ? void 0 : onInput(newValue);
  };

  var handleOptionMouseOver = function handleOptionMouseOver(index) {
    setSelected(index);
  };

  var handleOptionMouseDown = function handleOptionMouseDown(index) {
    handleClose();

    if (onSelectOption) {
      onSelectOption(options[index]);
    }
  };

  var changeSelectedOption = function changeSelectedOption(diff) {
    if (!open) {
      return;
    }

    setSelected(function (selected) {
      if (selected + diff >= options.length) {
        return 0;
      } else if (selected + diff < 0) {
        return options.length - 1;
      }

      return selected + diff;
    });
  };

  var handleKeyDown = function handleKeyDown(event) {
    switch (event.key) {
      case 'ArrowDown':
      case 'Down':
        // Prevent cursor move
        event.preventDefault();
        changeSelectedOption(1);
        handleOpen();
        break;

      case 'ArrowUp':
      case 'Up':
        // Prevent cursor move
        event.preventDefault();
        changeSelectedOption(-1);
        handleOpen();
        break;

      case 'Enter':
        if (open) {
          // Prevent form validation
          event.preventDefault();
          handleClose();

          if (onSelectOption) {
            onSelectOption(options[selected]);
          }
        } else {
          onChange === null || onChange === void 0 ? void 0 : onChange(event.currentTarget.value);
        }

        break;

      case 'Escape':
      case 'Esc':
        if (open) {
          handleClose();
        }

        break;

      case 'Tab':
        if (event.shiftKey) {
          handleClose();
        } else if (closeButtonRef.current) {
          closeButtonRef.current.focus();
          event.preventDefault();
        }

        break;
    }
  };

  var autocompleteOptions = _react["default"].Children.map(children, function (child) {
    if ( /*#__PURE__*/_react["default"].isValidElement(child) && child.type === AutocompleteOptions) {
      return /*#__PURE__*/_react["default"].cloneElement(child, {
        id: "".concat(id, "-options")
      }, _react["default"].Children.toArray(child.props.children).map(function (child, index) {
        if (_typeof(child) === 'object' && 'type' in child && child.type === AutocompleteOption) {
          return /*#__PURE__*/_react["default"].cloneElement(child, {
            id: "".concat(id, "-option-").concat(index),
            isSelected: selected === index,
            onMouseDown: function onMouseDown() {
              var _fieldRef$current;

              handleOptionMouseDown(index);
              (_fieldRef$current = fieldRef.current) === null || _fieldRef$current === void 0 ? void 0 : _fieldRef$current.focus();
            },
            onMouseOver: function onMouseOver() {
              return handleOptionMouseOver(index);
            }
          });
        }
      }));
    }
  });

  (0, _react.useEffect)(function () {
    var handleClickOutside = function handleClickOutside(event) {
      var _fieldRef$current2, _popperRef$current;

      if (event.target instanceof Node && !((_fieldRef$current2 = fieldRef.current) === null || _fieldRef$current2 === void 0 ? void 0 : _fieldRef$current2.contains(event.target)) && !((_popperRef$current = popperRef.current) === null || _popperRef$current === void 0 ? void 0 : _popperRef$current.contains(event.target))) {
        handleClose();
      } else if (event.target !== fieldRef.current) {
        var _fieldRef$current3;

        (_fieldRef$current3 = fieldRef.current) === null || _fieldRef$current3 === void 0 ? void 0 : _fieldRef$current3.focus();
      }
    };

    document.addEventListener('click', handleClickOutside);
    return function () {
      document.removeEventListener('click', handleClickOutside);
    };
  }, [handleClose]);
  (0, _react.useEffect)(function () {
    if (options.length === 0) {
      // Prevents the loss of focus
      if (open && fieldRef.current && !(0, _focus.isFocused)(fieldRef.current)) {
        fieldRef.current.focus();
      }
    } else if (!open && fieldRef.current && (0, _focus.isFocused)(fieldRef.current)) {
      handleOpen();
    }
  }, // eslint-disable-next-line react-hooks/exhaustive-deps
  [options.length]);

  var autocompleteFooter = _react["default"].Children.map(children, function (child) {
    if ( /*#__PURE__*/_react["default"].isValidElement(child) && child.type === AutocompleteFooter) {
      return child;
    }
  });

  var fieldFocused = Boolean(fieldRef.current && (0, _focus.isFocused)(fieldRef.current));
  var closeButtonFocused = Boolean(closeButtonRef.current && (0, _focus.isFocused)(closeButtonRef.current));
  var renderPopper = open && options.length > 0 && (fieldFocused || closeButtonFocused);
  var autocompleteClassName = (0, _cssUtilities.classNames)(_Autocomplete["default"].Autocomplete, background && _Autocomplete["default"][(0, _cssUtilities.variationName)('background', background)]);
  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_TextField.TextFieldInternal, {
    label: label,
    ariaActiveDescendant: open ? "".concat(id, "-option-").concat(selected) : undefined,
    ariaAutocomplete: "list",
    ariaControls: "".concat(id, "-options"),
    ariaExpanded: renderPopper,
    required: required,
    autocomplete: !open && autocomplete,
    error: error,
    id: id,
    name: name,
    onInput: handleInput,
    onChange: onChange,
    onFocus: handleOpen,
    onKeyDown: handleKeyDown,
    ref: fieldRef,
    role: "combobox",
    controlledValue: value,
    disabled: disabled,
    readonly: readonly
  }), renderPopper && /*#__PURE__*/_react["default"].createElement(_Popper.Popper, {
    activator: fieldRef.current,
    sameInlineSize: true,
    minInlineSize: 320,
    preventOverflow: true,
    placement: "blockEnd",
    offset: 7
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: autocompleteClassName,
    ref: popperRef
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: _Autocomplete["default"].Header
  }, /*#__PURE__*/_react["default"].createElement("h3", {
    className: _Autocomplete["default"].Title
  }, title), /*#__PURE__*/_react["default"].createElement("button", {
    type: "button",
    className: _Autocomplete["default"].Close,
    onClick: function onClick() {
      var _fieldRef$current4;

      handleClose();
      (_fieldRef$current4 = fieldRef.current) === null || _fieldRef$current4 === void 0 ? void 0 : _fieldRef$current4.focus();
    },
    onKeyDown: function onKeyDown(event) {
      if (event.key === 'Tab') {
        if (event.shiftKey) {
          var _fieldRef$current5;

          (_fieldRef$current5 = fieldRef.current) === null || _fieldRef$current5 === void 0 ? void 0 : _fieldRef$current5.focus();
          event.preventDefault();
        } else {
          var _fieldRef$current6;

          handleClose();
          (_fieldRef$current6 = fieldRef.current) === null || _fieldRef$current6 === void 0 ? void 0 : _fieldRef$current6.focus();
        }
      }
    },
    ref: closeButtonRef
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    size: "base",
    source: "close",
    appearance: "subdued",
    accessibilityLabel: ariaLabel
  }))), autocompleteOptions, autocompleteFooter)));
}

function AutocompleteOptions(_ref2) {
  var children = _ref2.children,
      id = _ref2.id;
  return /*#__PURE__*/_react["default"].createElement("ul", {
    className: _Autocomplete["default"].Options,
    id: id,
    onMouseDown: function onMouseDown(event) {
      // Prevent blur
      event.preventDefault();
    } // eslint-disable-next-line jsx-a11y/no-noninteractive-element-to-interactive-role
    ,
    role: "listbox"
  }, children);
}

function AutocompleteOption(_ref3) {
  var children = _ref3.children,
      id = _ref3.id,
      isSelected = _ref3.isSelected,
      onMouseDown = _ref3.onMouseDown,
      onMouseOver = _ref3.onMouseOver;
  return (
    /*#__PURE__*/
    // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
    _react["default"].createElement("li", {
      "aria-selected": isSelected,
      className: (0, _cssUtilities.classNames)(_Autocomplete["default"].Option, _defineProperty({}, _Autocomplete["default"].selected, isSelected)),
      id: id,
      onMouseDown: onMouseDown,
      onMouseOver: onMouseOver // eslint-disable-next-line jsx-a11y/no-noninteractive-element-to-interactive-role
      ,
      role: "option"
    }, children)
  );
}

function AutocompleteFooter(_ref4) {
  var children = _ref4.children;
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: _Autocomplete["default"].Footer
  }, children);
}