"use strict";

var _react = _interopRequireDefault(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Link = require("../Link");

var _Spinner = require("../Spinner");

var _Form = require("../Form");

var _Button = require("./Button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  children: 'Go to next step'
};
describe('<Button />', function () {
  beforeEach(function () {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(function () {
    _jestDomMocks.matchMedia.restore();
  });
  describe('`<button />`', function () {
    describe('children', function () {
      it('renders the children into the button', function () {
        var text = 'Go to shipping';
        var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, null, text));
        expect(button).toContainReactText(text);
      });
      it('renders the children into the link', function () {
        var text = 'Go to shipping';
        var linkButton = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, {
          to: "/shipping"
        }, text));
        expect(linkButton).toContainReactText(text);
      });
    });
    describe('onPress()', function () {
      it('is called when button is pressed', function () {
        var onPressSpy = jest.fn();
        var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
          onPress: onPressSpy
        })));
        button.find('button').trigger('onClick');
        expect(onPressSpy).toHaveBeenCalledTimes(1);
      });
    });
  });
  describe('`<UnstyledLink />`', function () {
    it('renders when a url is provided', function () {
      var url = '/shipping';
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        to: url
      })));
      expect(button).toContainReactComponent(_Link.UnstyledLink, {
        to: url
      });
    });
    it('renders a button when disabled', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        disabled: true,
        to: "/shipping"
      })));
      expect(button).not.toContainReactComponent(_Link.UnstyledLink);
      expect(button).toContainReactComponent('button', {
        disabled: true
      });
    });
  });
  describe('submit', function () {
    it('renders a type button when not present', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, defaultProps));
      expect(button).toContainReactComponent('button', {
        type: 'button'
      });
    });
    it('renders a type submit when present', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      })));
      expect(button).toContainReactComponent('button', {
        type: 'submit'
      });
    });
    it('renders a form id when rendered in a nested form', function () {
      var testId = _faker["default"].random.word();

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        onSubmit: noop
      }, /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        id: testId,
        onSubmit: noop
      }, /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      })))));
      expect(button).toContainReactComponent('button', {
        type: 'submit',
        form: testId
      });
    });
    it('does not render a form id when rendered in a non-nested form', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        onSubmit: noop
      }, /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      }))));
      expect(button).toContainReactComponent('button', {
        type: 'submit',
        form: undefined
      });
    });
  });
  describe('loading', function () {
    it('disables button when loading', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        disabled: true
      });
    });
    it('indicates that the button is getting updated', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        'aria-busy': true
      });
      var unstyledLink = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true,
        to: "/shipping"
      })));
      expect(unstyledLink).toContainReactComponent(_Link.UnstyledLink, {
        ariaBusy: true
      });
    });
    it('does not indicate that the button is getting updated when not set', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, defaultProps));
      expect(button).toContainReactComponent('button', {
        'aria-busy': undefined
      });
    });
    it('sets the right priority of announcement for screen readers', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        'aria-live': 'assertive'
      });
      var unstyledLink = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true,
        to: "/shipping"
      })));
      expect(unstyledLink).toContainReactComponent(_Link.UnstyledLink, {
        ariaLive: 'assertive'
      });
    });
    it('renders a <Spinner> when loading', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: false
        };
      });

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent(_Spinner.Spinner);
    });
    it('renders the loadingLabel as the Spinner children when provided', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).toContainReactComponent(_Spinner.Spinner, {
        accessibilityLabel: 'Processing'
      });
    });
    it('adds the Spinner class when user does not prefers reduced motion', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: false
        };
      });

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).toContainReactComponent('span', {
        className: 'LoadingContent Spinner'
      });
    });
    it('removes the Spinner class when user prefers reduced motion', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: true
        };
      });

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).not.toContainReactComponent('span', {
        className: 'LoadingContent Spinner'
      });
    });
  });
  describe('accessibilityLabel', function () {
    it('renders an accessible label when provided', function () {
      var content = 'Accessible label';
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        accessibilityLabel: content
      })));
      expect(button).toContainReactComponent('button', {
        'aria-label': content
      });
      var unstyledLink = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        accessibilityLabel: content,
        to: "/shipping"
      })));
      expect(unstyledLink).toContainReactComponent(_Link.UnstyledLink, {
        ariaLabel: content
      });
    });
  });
});

function noop() {}