"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Collapsible = require("./Collapsible");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<Collapsible />', function () {
  describe('open', function () {
    it('renders children but is hidden when closed', function () {
      var collapsible = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Collapsible.Collapsible, {
        id: "test-collapsible",
        open: false
      }, "content"));
      expect(collapsible).toContainReactComponent('div', {
        'aria-expanded': false,
        hidden: true,
        style: {
          height: 0
        }
      });
      expect(collapsible).toContainReactText('content');
    });
    it('renders children and is aria-expanded when open', function () {
      var collapsible = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Collapsible.Collapsible, {
        id: "test-collapsible",
        open: true
      }, "content"));
      expect(collapsible).toContainReactComponent('div', {
        'aria-expanded': true,
        hidden: false,
        style: {
          height: 'auto'
        }
      });
      expect(collapsible).toContainReactText('content');
    });
  });
  describe('minSize', function () {
    it('height is set to minSize when closed and not hidden', function () {
      var minSize = 50;
      var collapsible = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Collapsible.Collapsible, {
        id: "test-collapsible",
        open: false,
        minSize: minSize
      }, "content"));
      expect(collapsible).toContainReactComponent('div', {
        'aria-expanded': false,
        hidden: false,
        style: {
          height: minSize
        }
      });
    });
  });
});