"use strict";

var _react = _interopRequireDefault(require("react"));

var _autoHeadings = require("../../utilities/auto-headings");

var _testUtilities = require("../../test-utilities");

var _Heading = require("./Heading");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<Heading />', function () {
  it('renders its children', function () {
    var text = 'Snowdevil';
    var heading = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Heading.Heading, null, text));
    expect(heading).toContainReactText(text);
  });
  it('uses a <p> when the role is set to presentation', function () {
    var heading = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Heading.Heading, {
      role: "presentation"
    }, "Snowdevil"));
    expect(heading).toContainReactComponent('p');
  });
  it('assigns an id and focusable tabIndex on the element when an id is set', function () {
    var id = 'MyId';
    var heading = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Heading.Heading, {
      role: "presentation",
      id: id
    }, "Snowdevil"));
    expect(heading).toContainReactComponent('p', {
      id: id,
      tabIndex: -1
    });
  });
  it('uses a heading based on the semantic heading level', function () {
    var headings = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_autoHeadings.AutoHeadingGroup, {
      level: 1
    }, /*#__PURE__*/_react["default"].createElement(_Heading.Heading, {
      id: "one"
    }, "Snowdevil"), /*#__PURE__*/_react["default"].createElement(_autoHeadings.AutoHeadingGroup, null, /*#__PURE__*/_react["default"].createElement(_Heading.Heading, {
      id: "two"
    }, "History"))));
    expect(headings).toContainReactComponent('h1', {
      id: 'one'
    });
    expect(headings).toContainReactComponent('h2', {
      id: 'two'
    });
  });
});