"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Hidden = Hidden;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _inlineFormatting = require("../../utilities/inlineFormatting");

var _Hidden = _interopRequireDefault(require("./Hidden.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var VIEWPORT_SIZES = ['small', 'medium', 'large'];

/**
 * Hidden is used to hide content from users based on their viewport size.
 */
function Hidden(_ref) {
  var above = _ref.above,
      below = _ref.below,
      children = _ref.children;
  var inline = (0, _inlineFormatting.useInlineFormatting)();
  var Component = inline ? 'span' : 'div';

  var _getResponsiveValuesF = getResponsiveValuesFromRange(above, below),
      hiddenOnSmall = _getResponsiveValuesF.hiddenOnSmall,
      hiddenOnMedium = _getResponsiveValuesF.hiddenOnMedium,
      hiddenOnLarge = _getResponsiveValuesF.hiddenOnLarge;

  var className = (0, _cssUtilities.classNames)(_Hidden["default"].Hidden, hiddenOnSmall && _Hidden["default"].hiddenOnSmall, hiddenOnMedium && _Hidden["default"].hiddenOnMedium, hiddenOnLarge && _Hidden["default"].hiddenOnLarge);
  return /*#__PURE__*/_react["default"].createElement(Component, {
    className: className
  }, children);
}

function getResponsiveValuesFromRange(above, below) {
  if (above === below) {
    return {
      hiddenOnSmall: true,
      hiddenOnMedium: false,
      hiddenOnLarge: true
    };
  }

  var start = above ? VIEWPORT_SIZES.indexOf(above) + 1 : 0;
  var end = below ? VIEWPORT_SIZES.indexOf(below) - 1 : VIEWPORT_SIZES.length - 1;
  var range = VIEWPORT_SIZES.slice(start, end + 1);
  var hiddenOnSmall = range.indexOf('small') >= 0;
  var hiddenOnMedium = range.indexOf('medium') >= 0;
  var hiddenOnLarge = range.indexOf('large') >= 0;
  return {
    hiddenOnSmall: hiddenOnSmall,
    hiddenOnMedium: hiddenOnMedium,
    hiddenOnLarge: hiddenOnLarge
  };
}