"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Image = Image;
exports.MEDIA_MAP = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _View = require("../View");

var _breakpoint = require("../../utilities/breakpoint");

var _Image = _interopRequireDefault(require("./Image.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var MEDIA_MAP = new Map((0, _breakpoint.createMediaQueries)({
  addMaxWidth: false
}).map(function (_ref) {
  var breakpoint = _ref.breakpoint,
      query = _ref.query;
  return [breakpoint, query];
}));
exports.MEDIA_MAP = MEDIA_MAP;

function Image(_ref2) {
  var source = _ref2.source,
      sources = _ref2.sources,
      _ref2$description = _ref2.description,
      description = _ref2$description === void 0 ? '' : _ref2$description,
      fit = _ref2.fit,
      loading = _ref2.loading,
      aspectRatio = _ref2.aspectRatio,
      decorative = _ref2.decorative;
  var sourcesMarkup = sources && Object.entries(sources).sort(function (_ref3, _ref4) {
    var _ref5 = _slicedToArray(_ref3, 1),
        firstBreakpoint = _ref5[0];

    var _ref6 = _slicedToArray(_ref4, 1),
        secondBreakpoint = _ref6[0];

    var firstWidth = _breakpoint.BREAKPOINTS[firstBreakpoint];
    var secondWidth = _breakpoint.BREAKPOINTS[secondBreakpoint];

    if (firstWidth != null && secondWidth != null) {
      return secondWidth - firstWidth;
    }

    return 0;
  }).map(function (_ref7) {
    var _ref8 = _slicedToArray(_ref7, 2),
        viewportSize = _ref8[0],
        sizeSources = _ref8[1];

    if (typeof sizeSources === 'string') {
      return [viewportSize, [{
        source: sizeSources
      }]];
    }

    if (!Array.isArray(sizeSources) && sizeSources !== undefined) {
      return [viewportSize, [sizeSources]];
    }

    return [viewportSize, sizeSources];
  }).map(function (_ref9) {
    var _ref10 = _slicedToArray(_ref9, 2),
        viewportSize = _ref10[0],
        sizeSources = _ref10[1];

    var media = MEDIA_MAP.get(viewportSize);

    if (media !== undefined && Array.isArray(sizeSources)) {
      var srcSet = sizeSources.map(function (_ref11) {
        var source = _ref11.source,
            resolution = _ref11.resolution;
        return [source, resolution && "".concat(resolution, "x")].join(' ').trim();
      }).join(', ');
      return /*#__PURE__*/_react["default"].createElement("source", {
        key: media,
        media: media,
        srcSet: srcSet
      });
    }
  });
  var className = (0, _cssUtilities.classNames)(_Image["default"].Image, fit && _Image["default"][(0, _cssUtilities.variationName)('fit', fit)]);
  return /*#__PURE__*/_react["default"].createElement(MaybeHiddenForA11y, {
    condition: decorative === true
  }, /*#__PURE__*/_react["default"].createElement(MaybeAspectRatio, {
    condition: aspectRatio != null,
    aspectRatio: aspectRatio
  }, /*#__PURE__*/_react["default"].createElement(MaybePicture, {
    condition: sourcesMarkup != null
  }, sourcesMarkup, /*#__PURE__*/_react["default"].createElement("img", {
    src: source,
    alt: description,
    className: className,
    loading: loading
  }))));
}

function MaybeHiddenForA11y(_ref12) {
  var children = _ref12.children,
      condition = _ref12.condition;
  return condition ? /*#__PURE__*/_react["default"].createElement(_View.View, {
    accessibilityVisibility: "hidden"
  }, children) : /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, children);
}

function MaybeAspectRatio(_ref13) {
  var children = _ref13.children,
      condition = _ref13.condition,
      aspectRatio = _ref13.aspectRatio;
  return condition ? /*#__PURE__*/_react["default"].createElement("div", {
    className: _Image["default"].aspectRatio,
    style: {
      paddingBottom: "calc(100% / ".concat(aspectRatio, ")")
    }
  }, children) : /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, children);
}

function MaybePicture(_ref14) {
  var children = _ref14.children,
      condition = _ref14.condition;
  return condition ? /*#__PURE__*/_react["default"].createElement("picture", null, children) : /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, children);
}