"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _faker = _interopRequireDefault(require("faker"));

var _View = require("../View");

var _Image = require("./Image");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

describe('<Image />', function () {
  var source = _faker["default"].image.imageUrl();

  describe('sources', function () {
    it('renders a picture element with sources with an img fallback', function () {
      var description = _faker["default"].random.words();

      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        sources: {
          base: source
        },
        description: description,
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('picture');
      expect(image).toContainReactComponent('source', {
        srcSet: source
      });
      expect(image).toContainReactComponent('img', {
        src: source,
        alt: description,
        loading: 'lazy'
      });
    });
    it('reduces multiple sources with the same breakpoint into a single srcSet', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        sources: {
          small: [{
            source: source,
            resolution: 1
          }, {
            source: source,
            resolution: 2
          }]
        },
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('source', {
        srcSet: "".concat(source, " 1x, ").concat(source, " 2x"),
        media: _Image.MEDIA_MAP.get('small')
      });
    });
    it('renders an img element only when no sources are provided', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('picture');
      expect(image).not.toContainReactComponent('source');
      expect(image).toContainReactComponent('img', {
        src: source
      });
    });
    it('renders sources in descending breakpoint width order', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        sources: {
          small: [{
            source: source
          }, {
            source: source,
            resolution: 2
          }],
          large: [{
            source: source
          }, {
            source: source,
            resolution: 2
          }],
          medium: source
        }
      }));

      var _image$findAll = image.findAll('source'),
          _image$findAll2 = _slicedToArray(_image$findAll, 3),
          largeSource = _image$findAll2[0],
          mediumSource = _image$findAll2[1],
          smallSource = _image$findAll2[2];

      expect(largeSource.prop('media')).toBe(_Image.MEDIA_MAP.get('large'));
      expect(mediumSource.prop('media')).toBe(_Image.MEDIA_MAP.get('medium'));
      expect(smallSource.prop('media')).toBe(_Image.MEDIA_MAP.get('small'));
    });
    it('accepts different types of sources', function () {
      var sourceArray = _faker["default"].image.imageUrl();

      var sourceString = _faker["default"].image.imageUrl();

      var sourceObject = _faker["default"].image.imageUrl();

      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        sources: {
          base: [{
            source: sourceArray,
            resolution: 1
          }],
          small: sourceString,
          medium: {
            source: sourceObject
          }
        }
      }));
      expect(image).toContainReactComponent('source', {
        srcSet: "".concat(sourceArray, " 1x"),
        media: _Image.MEDIA_MAP.get('base')
      });
      expect(image).toContainReactComponent('source', {
        srcSet: sourceString,
        media: _Image.MEDIA_MAP.get('small')
      });
      expect(image).toContainReactComponent('source', {
        srcSet: sourceObject,
        media: _Image.MEDIA_MAP.get('medium')
      });
    });
  });
  describe('decorative', function () {
    it('wraps the image with <View accessibilityVisibility="hidden" />', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        decorative: true
      }));
      expect(image).toContainReactComponent(_View.View, {
        accessibilityVisibility: 'hidden'
      });
    });
    it('by default the image is not wrapped with <View accessibilityVisibility="hidden" />', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent(_View.View, {
        accessibilityVisibility: 'hidden'
      });
    });
  });
  describe('aspectRatio', function () {
    it('wraps the image with placeholder container', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source,
        aspectRatio: 16 / 9
      }));
      expect(image).toContainReactComponent('div', {
        style: {
          paddingBottom: "calc(100% / ".concat(16 / 9, ")")
        }
      });
    });
    it('by default the image does not have any container', function () {
      var image = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('div');
    });
  });
});