"use strict";

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Labelled = require("./Labelled");

var _hook = require("./hook");

var _context11 = require("./context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var defaultProps = {
  children: /*#__PURE__*/_react["default"].createElement(Child, null),
  label: '',
  htmlFor: '',
  empty: true
};
describe('<Labelled />', function () {
  it('renders the children', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
    var labelled;
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, defaultProps));
            expect(labelled).toContainReactComponent(Child);

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('wraps children with a LabelledContext.Provider', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee2() {
    var labelled;
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email"
            })));
            expect(labelled).toProvideReactContext(_context11.LabelledContext);

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('renders a floating label when the value is prefilled', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee3() {
    var labelled;
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email",
              empty: false
            })));
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: true
            }));

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('does not render a floating label on focus when empty', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee4() {
    var labelled;
    return _regenerator["default"].wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email"
            }))); // Gain focus

            labelled.act(function () {
              var _labelled$find;

              (_labelled$find = labelled.find('input')) === null || _labelled$find === void 0 ? void 0 : _labelled$find.trigger('onFocus');
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: false
            }));

          case 3:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('renders a floating label once a value is entered', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee5() {
    var labelled;
    return _regenerator["default"].wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email"
            }))); // Enter value

            labelled.act(function () {
              labelled.setProps({
                empty: false
              });
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: true
            }));

          case 3:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('renders a floating label when focused, then the value is removed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee6() {
    var labelled;
    return _regenerator["default"].wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              empty: false,
              label: "Email"
            }))); // Gain focus

            labelled.act(function () {
              var _labelled$find2;

              (_labelled$find2 = labelled.find('input')) === null || _labelled$find2 === void 0 ? void 0 : _labelled$find2.trigger('onFocus');
            }); // Remove value

            labelled.act(function () {
              labelled.setProps({
                empty: true
              });
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: true
            }));

          case 4:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('does not render a floating label when not focused and the value is removed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee7() {
    var labelled;
    return _regenerator["default"].wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              empty: false,
              label: "Email"
            }))); // Remove value

            labelled.act(function () {
              labelled.setProps({
                empty: true
              });
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: false
            }));

          case 3:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('does not render a floating label when focused, then a value is entered, then removed, then the focus is lost', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee8() {
    var labelled;
    return _regenerator["default"].wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email"
            }))); // Gain focus

            labelled.act(function () {
              var _labelled$find3;

              (_labelled$find3 = labelled.find('input')) === null || _labelled$find3 === void 0 ? void 0 : _labelled$find3.trigger('onFocus');
            }); // Enter value

            labelled.act(function () {
              labelled.setProps({
                empty: false
              });
            }); // Remove value

            labelled.act(function () {
              labelled.setProps({
                empty: true
              });
            }); // Lose focus

            labelled.act(function () {
              var _labelled$find4;

              (_labelled$find4 = labelled.find('input')) === null || _labelled$find4 === void 0 ? void 0 : _labelled$find4.trigger('onBlur');
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: false
            }));

          case 6:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('renders a floating label when focused, then a value is entered, then the focus is lost', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee9() {
    var labelled;
    return _regenerator["default"].wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email"
            }))); // Gain focus

            labelled.act(function () {
              var _labelled$find5;

              (_labelled$find5 = labelled.find('input')) === null || _labelled$find5 === void 0 ? void 0 : _labelled$find5.trigger('onFocus');
            }); // Enter value

            labelled.act(function () {
              labelled.setProps({
                empty: false
              });
            }); // Lose focus

            labelled.act(function () {
              var _labelled$find6;

              (_labelled$find6 = labelled.find('input')) === null || _labelled$find6 === void 0 ? void 0 : _labelled$find6.trigger('onBlur');
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: true
            }));

          case 5:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('renders a floating label when focused, then a value is entered, then lost focus, then focused, then the value removed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee10() {
    var labelled;
    return _regenerator["default"].wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
              label: "Email"
            }))); // Gain focus

            labelled.act(function () {
              var _labelled$find7;

              (_labelled$find7 = labelled.find('input')) === null || _labelled$find7 === void 0 ? void 0 : _labelled$find7.trigger('onFocus');
            }); // Enter value

            labelled.act(function () {
              labelled.setProps({
                empty: false
              });
            }); // Lose focus

            labelled.act(function () {
              var _labelled$find8;

              (_labelled$find8 = labelled.find('input')) === null || _labelled$find8 === void 0 ? void 0 : _labelled$find8.trigger('onBlur');
            }); // Gain focus

            labelled.act(function () {
              var _labelled$find9;

              (_labelled$find9 = labelled.find('input')) === null || _labelled$find9 === void 0 ? void 0 : _labelled$find9.trigger('onFocus');
            }); // Remove value

            labelled.act(function () {
              labelled.setProps({
                empty: true
              });
            });
            expect(labelled).toProvideReactContext(_context11.LabelledContext, expect.objectContaining({
              floating: true
            }));

          case 7:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
});

function Child(_ref11) {
  var value = _ref11.value;

  var _useLabelled = (0, _hook.useLabelled)(),
      onBlur = _useLabelled.onBlur,
      onFocus = _useLabelled.onFocus;

  return /*#__PURE__*/_react["default"].createElement("input", {
    value: value,
    onBlur: onBlur,
    onFocus: onFocus,
    onChange: function onChange() {}
  });
}