"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _View = require("../View");

var _context = require("./context");

var _OptionList = require("./OptionList");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  id: _faker["default"].random.uuid(),
  selectedItems: [_faker["default"].random.uuid()],
  onChange: function onChange() {
    return null;
  },
  children: /*#__PURE__*/_react["default"].createElement("div", null)
};
describe('<OptionList />', function () {
  it('renders its children', function () {
    function Children() {
      return /*#__PURE__*/_react["default"].createElement("div", null, "children");
    }

    var accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, defaultProps, /*#__PURE__*/_react["default"].createElement(Children, null)));
    expect(accordion).toContainReactComponent(Children);
  });
  it('wraps children with OptionListContext', function () {
    var id = _faker["default"].random.uuid();

    var selectedItems = [_faker["default"].random.uuid()];

    var onChange = function onChange() {
      return null;
    };

    var allowMultiple = false;
    var controlHidden = false;
    var accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultProps, {
      id: id,
      selectedItems: selectedItems,
      onChange: onChange,
      allowMultiple: allowMultiple
    })));
    expect(accordion).toProvideReactContext(_context.OptionListContext, {
      id: id,
      selectedItems: selectedItems,
      onChange: onChange,
      allowMultiple: allowMultiple,
      controlHidden: controlHidden
    });
  });
  it('renders a title if provided', function () {
    var title = _faker["default"].random.word();

    var accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultProps, {
      title: title
    })));
    expect(accordion).toContainReactComponent('legend');
    expect(accordion.find('legend')).toContainReactText(title);
  });
  it('renders a hidden title if provided when titleHidden prop is set to true', function () {
    var title = _faker["default"].random.word();

    var accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultProps, {
      title: title,
      titleHidden: true
    })));
    expect(accordion.find(_View.View, {
      visibility: 'hidden'
    })).toContainReactComponent('legend');
    expect(accordion.find('legend')).toContainReactText(title);
  });
});