"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _RadioControl = require("./RadioControl");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  name: 'radio_button'
};
describe('<RadioControl />', function () {
  it('renders an un-checked radio', function () {
    var radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_RadioControl.RadioControl, defaultProps));
    expect(radio).toContainReactComponent('input', {
      checked: false,
      type: 'radio'
    });
  });
  it('renders a checked radio when the checked prop is provided and set to true', function () {
    var radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_RadioControl.RadioControl, Object.assign({}, defaultProps, {
      checked: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a checked radio when the value prop is provided and set to true', function () {
    var radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_RadioControl.RadioControl, Object.assign({}, defaultProps, {
      value: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a disabled radio when the disabled prop is provided and set to true', function () {
    var radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_RadioControl.RadioControl, Object.assign({}, defaultProps, {
      disabled: true
    })));
    expect(radio).toContainReactComponent('input', {
      disabled: true,
      type: 'radio'
    });
  });
  it('calls the onChange callback when the radio is checked and unchecked', function () {
    var onChangeSpy = jest.fn();
    var radio = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_RadioControl.RadioControl, Object.assign({}, defaultProps, {
      onChange: onChangeSpy
    })));
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: true
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(true);
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: false
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(false);
  });
});