"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tabs = Tabs;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../Icon");

var _InlineStack = require("../InlineStack");

var _id = require("../../utilities/id");

var _Tabs = _interopRequireDefault(require("./Tabs.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var createId = (0, _id.createIdCreator)('Tabs');
var TabsContext = /*#__PURE__*/(0, _react.createContext)(null);
/**
 * Tabs are used when there’s multiple ways to display the same information,
 * like a map or list view. When a buyer needs to make a choice, use the
 * OptionList component instead as Buyers are more likely to choose the
 * non-default option. Don’t hide important information in tabs. Limit to two
 * of three tabs and keep labels short to optimize for mobile.
 */

function Tabs(_ref) {
  var tabs = _ref.tabs,
      selected = _ref.selected,
      ariaLabel = _ref.ariaLabel,
      bordered = _ref.bordered,
      onChange = _ref.onChange,
      children = _ref.children;
  var id = (0, _id.useId)(undefined, createId);
  var tabList = (0, _react.useRef)(null);
  var lastIndex = tabs.length - 1;

  var childrenCount = _react.Children.count(children);

  var handleKeyDown = (0, _react.useCallback)(function (event) {
    var prev = selected - 1 < 0 ? lastIndex : selected - 1;
    var next = selected + 1 > lastIndex ? 0 : selected + 1;
    var handlerMap = new Map([['ArrowLeft', prev], ['Left', prev], ['ArrowRight', next], ['Right', next], ['Home', 0], ['End', lastIndex]]);
    var newSelected = handlerMap.get(event.key);

    if (newSelected != null) {
      event.preventDefault();
      onChange(newSelected);
    }
  }, [onChange, selected, lastIndex]);
  (0, _react.useEffect)(function () {
    var current = tabList.current;
    if (current == null) return;
    current.addEventListener('keydown', handleKeyDown, false);
    return function () {
      current.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [tabList, handleKeyDown]);
  (0, _react.useEffect)(function () {
    if (childrenCount !== tabs.length) {
      // eslint-disable-next-line no-console
      console.warn("<Tabs /> has ".concat(tabs.length, " tabs and ").concat(childrenCount, " children. A mismatch will cause some content to be unavailable."));
    }
  }, [childrenCount, tabs.length]);
  var tabsMarkup = [];
  var panelsMarkup = [];

  _react.Children.forEach(children, function (child, index) {
    var tab = tabs[index];

    if (tab != null) {
      var _ref2 = typeof tab === 'string' ? {
        label: tab,
        icon: undefined
      } : tab,
          label = _ref2.label,
          icon = _ref2.icon;

      tabsMarkup.push( /*#__PURE__*/_react["default"].createElement(Tab, Object.assign({
        label: label,
        icon: icon,
        selected: selected,
        onChange: onChange,
        id: id
      }, {
        index: index,
        key: label
      })));
    }

    panelsMarkup.push( /*#__PURE__*/_react["default"].createElement(TabPanel, {
      index: index
    }, child));
  });

  return /*#__PURE__*/_react["default"].createElement(TabsContext.Provider, {
    value: {
      id: id,
      selected: selected,
      bordered: bordered
    }
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: _Tabs["default"].Tabs
  }, /*#__PURE__*/_react["default"].createElement("div", {
    ref: tabList,
    role: "tablist",
    "aria-label": ariaLabel,
    className: _Tabs["default"].TabList
  }, tabsMarkup), panelsMarkup));
}

function Tab(_ref3) {
  var label = _ref3.label,
      icon = _ref3.icon,
      index = _ref3.index,
      selectedIndex = _ref3.selected,
      onChange = _ref3.onChange,
      id = _ref3.id;

  if (index == null) {
    throw new Error('`index` is missing');
  }

  var tabRef = (0, _react.useRef)(null);
  var mountedRef = (0, _react.useRef)(false);
  var selected = selectedIndex === index;
  var markup = icon == null ? label : /*#__PURE__*/_react["default"].createElement(_InlineStack.InlineStack, {
    spacing: "extraTight",
    blockAlignment: "center"
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    source: icon,
    size: "large"
  }), /*#__PURE__*/_react["default"].createElement("span", null, label));
  (0, _react.useEffect)(function () {
    if (tabRef.current && selected && mountedRef.current) tabRef.current.focus();else mountedRef.current = true;
  }, [tabRef, selected]);
  return /*#__PURE__*/_react["default"].createElement("button", {
    type: "button",
    role: "tab",
    tabIndex: selected ? 0 : -1,
    "aria-selected": selected,
    id: "".concat(id, "Tab").concat(index),
    "aria-controls": "".concat(id, "TabPanel").concat(index),
    onClick: function onClick() {
      return onChange(index);
    },
    className: (0, _cssUtilities.classNames)(_Tabs["default"].Tab, selected && _Tabs["default"].selected),
    ref: tabRef
  }, markup);
}

function TabPanel(_ref4) {
  var index = _ref4.index,
      children = _ref4.children;

  var _useTabs = useTabs(),
      selectedIndex = _useTabs.selected,
      id = _useTabs.id,
      bordered = _useTabs.bordered;

  var selected = selectedIndex === index;
  return /*#__PURE__*/_react["default"].createElement("div", {
    role: "tabpanel",
    id: "".concat(id, "TabPanel").concat(index),
    "aria-labelledby": "".concat(id, "Tab").concat(index),
    hidden: !selected,
    className: (0, _cssUtilities.classNames)(_Tabs["default"].TabPanel, bordered && _Tabs["default"].bordered)
  }, children);
}

function useTabs() {
  var context = (0, _react.useContext)(TabsContext);

  if (context == null) {
    throw new Error('No tabs found in context');
  }

  return context;
}