"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.View = View;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsive = require("../../utilities/responsive");

var _responsiveValue = require("../../utilities/responsiveValue");

var _units = require("../../utilities/units");

var _View = _interopRequireDefault(require("./View.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var ELEMENT_MAP = new Map([['region', 'section'], ['complementary', 'aside']]);

function View(_ref) {
  var _ref2;

  var accessibilityLabel = _ref.accessibilityLabel,
      accessibilityVisibility = _ref.accessibilityVisibility,
      backgroundFit = _ref.backgroundFit,
      backgroundImage = _ref.backgroundImage,
      _ref$backgroundPositi = _ref.backgroundPosition,
      backgroundPosition = _ref$backgroundPositi === void 0 ? 'center' : _ref$backgroundPositi,
      _ref$backgroundRepeat = _ref.backgroundRepeat,
      backgroundRepeat = _ref$backgroundRepeat === void 0 ? false : _ref$backgroundRepeat,
      children = _ref.children,
      _ref$display = _ref.display,
      display = _ref$display === void 0 ? 'block' : _ref$display,
      id = _ref.id,
      maxInlineSize = _ref.maxInlineSize,
      role = _ref.role,
      visibility = _ref.visibility,
      props = _objectWithoutProperties(_ref, ["accessibilityLabel", "accessibilityVisibility", "backgroundFit", "backgroundImage", "backgroundPosition", "backgroundRepeat", "children", "display", "id", "maxInlineSize", "role", "visibility"]);

  var responsiveClassNames = (0, _responsive.useResponsive)(props);
  var responsiveStyle = (0, _responsiveValue.useResponsiveStyle)({
    backgroundImage: {
      value: backgroundImage,
      transform: function transform(value) {
        return "url(".concat(JSON.stringify(value), ")");
      }
    },
    maxWidth: {
      value: maxInlineSize,
      transform: function transform(value) {
        return (0, _units.pixelOrPercent)(value);
      }
    }
  });
  var Element = (_ref2 = role && ELEMENT_MAP.get(role)) !== null && _ref2 !== void 0 ? _ref2 : 'div';
  return /*#__PURE__*/_react["default"].createElement(Element, {
    className: (0, _cssUtilities.classNames)(_View["default"].View, backgroundImage && backgroundFit && _View["default"][(0, _cssUtilities.variationName)('backgroundFit', backgroundFit)], backgroundImage && backgroundPosition && _View["default"][(0, _cssUtilities.variationName)('backgroundPosition', backgroundPosition)], backgroundImage && _View["default"][(0, _cssUtilities.variationName)('backgroundRepeat', "".concat(backgroundRepeat))], display && _View["default"][(0, _cssUtilities.variationName)('display', display)], visibility && _View["default"][(0, _cssUtilities.variationName)('visibility', visibility)], responsiveClassNames && responsiveClassNames.map(function (className) {
      return _View["default"][className];
    })),
    style: responsiveStyle,
    "aria-hidden": accessibilityVisibility === 'hidden' ? true : undefined,
    "aria-label": role && accessibilityLabel,
    id: id
  }, children);
}