"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _faker = _interopRequireDefault(require("faker"));

var _View = require("./View");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<View />', function () {
  describe('children', function () {
    it('renders its children', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, null, text, " "));
      expect(view).toContainReactText(text);
    });
  });
  describe('id', function () {
    it('sets id when id is set', function () {
      var id = _faker["default"].random.uuid();

      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        id: id
      }));
      expect(view).toContainReactComponent('div', {
        id: id
      });
    });
  });
  describe('role', function () {
    it('renders a div by default', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div');
    });
    it('renders a section when "region" is set', function () {
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        role: "region"
      }));
      expect(view).toContainReactComponent('section');
    });
    it('renders an aside when "complimentary" is set', function () {
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        role: "complementary"
      }));
      expect(view).toContainReactComponent('aside');
    });
  });
  describe('accessibilityVisibility', function () {
    it('sets aria-hidden to true when accessibilityVisibility is set', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        accessibilityVisibility: "hidden"
      }, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': true
      });
    });
    it('does not set aria-hidden when accessibilityVisibility is not set', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': undefined
      });
    });
  });
  describe('accessibilityLabel', function () {
    it('sets aria-label with accessibilityLabel if role is set', function () {
      var text = _faker["default"].random.words();

      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        accessibilityLabel: text,
        role: "region"
      }));
      expect(view).toContainReactComponent('section', {
        'aria-label': text
      });
    });
    it('does not set aria-label if role is not set', function () {
      var text = _faker["default"].random.words();

      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        accessibilityLabel: text
      }));
      expect(view).not.toContainReactComponent('div', {
        'aria-label': text
      });
    });
  });
});