"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.themeWithKnobs = themeWithKnobs;

var _react = _interopRequireDefault(require("react"));

var _addonKnobs = require("@storybook/addon-knobs");

var _hsluv = require("hsluv");

var _ = require("..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var Group;

(function (Group) {
  Group["TextField"] = "Text field";
  Group["Select"] = "Select";
  Group["Breadcrumb"] = "Breadcrumb";
  Group["HeadingLevel1"] = "Heading level 1";
  Group["HeadingLevel2"] = "Heading level 2";
  Group["HeadingLevel3"] = "Heading level 3";
  Group["Checkbox"] = "Checkbox";
  Group["PrimaryButton"] = "Primary button";
  Group["SecondaryButton"] = "Secondary button";
  Group["FormLayout"] = "Form layout";
  Group["Tag"] = "Tag";
  Group["Tooltip"] = "Tooltip";
  Group["Banner"] = "Banner";
  Group["OptionList"] = "Option list";
  Group["Style"] = "Style";
  Group["Color"] = "Color";
  Group["Typography"] = "Typography";
  Group["Thumbnail"] = "Thumbnail";
  Group["Link"] = "Link";
  Group["ReviewBlock"] = "Review block";
})(Group || (Group = {}));

var Label;

(function (Label) {
  Label["Border"] = "Border";
  Label["BorderRadius"] = "Border radius";
  Label["LabelPosition"] = "Label position";
  Label["Style"] = "Style";
  Label["TypographyStyle"] = "Typography style";
  Label["ErrorIndentation"] = "Error indentation";
  Label["BlockPadding"] = "Block padding";
  Label["InlinePadding"] = "Inline padding";
  Label["LoadingStyle"] = "Loading style";
  Label["BadgeColor"] = "Badge color";
  Label["ColorHovered"] = "Color hovered";
  Label["TransitionDuration"] = "Transition duration";
  Label["Spacing"] = "Spacing";
})(Label || (Label = {}));

var Breadcrumb;

(function (Breadcrumb) {
  Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
  Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));

var SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
var BORDER_RADIUS_OPTIONS = optionify(['none', 'tight', 'base', 'fullyRounded']);
var SIMPLE_BORDER_OPTIONS = optionify(['full', 'none']);
var BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
var LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
var NUMBER_STYLE_OPTIONS = optionify(['none', 'decimal', 'decimalLeadingZero']);
var BUTTON_STYLE_OPTIONS = optionify(['fill', 'inverse', 'plain']);
var STYLE_OPTIONS = optionify(['style1']);
var SIZE_OPTIONS = optionify(['base', 'extraSmall', 'small', 'medium', 'large', 'extraLarge', 'extraExtraLarge']);
var LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
var FONT_OPTIONS = optionify(['primary', 'secondary']);
var WEIGHT_OPTIONS = optionify(['base', 'bold']);
var LINE_SIZE_OPTIONS = optionify(['base', 'small']);
var KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);
var DECORATION_OPTIONS = optionify(['none', 'underline']);
var SPACING_OPTIONS = optionify(['none', 'extraTight', 'tight', 'base', 'loose', 'extraLoose']);
var LOADING_STYLE_OPTIONS = optionify(['spinner', 'progressBar']);
var ERROR_INDENTATION_OPTIONS = optionify(['none', 'toText']);
var OPACITY_OPTIONS = optionify(['translucent', 'opaque']);
var TEXT_ALIGNMENT_OPTIONS = optionify(['start', 'center']);
var OPTION_LIST_BORDER_OPTIONS = optionify(['full', 'none', 'inner']);
var BORDER_STYLE_OPTIONS = optionify(['base', 'dotted']);
var UNDEFINED = '';
var FONT_WEIGHT_OPTIONS = optionify(['100', '200', '300', '400', '500', '600', '700', '800', '900']);
var BADGE_COLOR_OPTIONS = optionify(['subdued', 'primary']);
var COLOR_STYLE_OPTIONS = optionify(['color1', 'color2']);
var TRANSITION_DURATION_OPTIONS = optionify(['none', 'fast', 'base', 'slow', 'slower', 'slowest']);
var DIVIDER_OPTIONS = optionify(['toContainerEdge']);

function themeWithKnobs() {
  for (var _len = arguments.length, picks = new Array(_len), _key = 0; _key < _len; _key++) {
    picks[_key] = arguments[_key];
  }

  return function (storyFn) {
    return /*#__PURE__*/_react["default"].createElement(ThemeWithKnobs, {
      pick: picks
    }, storyFn());
  };
}

function ThemeWithKnobs(_ref) {
  var _ref$pick = _ref.pick,
      pick = _ref$pick === void 0 ? [] : _ref$pick,
      children = _ref.children;
  var textFields = {
    border: undefined,
    labelPosition: undefined,
    errorIndentation: undefined
  };
  var stepper = {
    separator: true
  };
  var selects = {
    border: undefined,
    labelPosition: undefined,
    errorIndentation: undefined,
    disclosureIconSeparator: true
  };
  var buyerJourney = {
    spacing: undefined,
    chevronIconSeparator: true,
    numberStyle: undefined,
    typographyStyle: undefined
  };
  var headingLevel1 = {
    typographyStyle: undefined
  };
  var headingLevel2 = {
    typographyStyle: undefined
  };
  var headingLevel3 = {
    typographyStyle: undefined
  };
  var checkbox = {
    borderRadius: undefined,
    errorIndentation: undefined
  };
  var primaryButton = {
    style: undefined,
    border: undefined,
    borderRadius: undefined,
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined,
    loadingStyle: undefined
  };
  var secondaryButton = {
    style: undefined,
    border: undefined,
    borderRadius: undefined,
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined,
    loadingStyle: undefined
  };
  var formLayout = {
    spacing: undefined
  };
  var tag = {
    borderRadius: undefined
  };
  var tooltip = {
    borderRadius: undefined,
    opacity: undefined,
    textAlignment: undefined
  };
  var banner = {
    border: undefined,
    borderRadius: undefined
  };
  var thumbnail = {
    aspectRatio: 1,
    border: undefined,
    badgeBackground: undefined
  };
  var optionList = {
    border: undefined,
    borderRadius: undefined,
    borderStyle: undefined,
    spacing: undefined,
    blockPadding: undefined,
    inlinePadding: undefined,
    typographyStyle: undefined
  };
  var reviewBlock = {
    borderRadius: undefined,
    border: undefined,
    spacing: undefined,
    inlinePadding: undefined,
    blockPadding: undefined,
    divider: undefined
  };
  var link = {
    transitionDuration: undefined,
    colorHovered: undefined,
    typographyStyle: undefined
  };

  if (pick.includes('textFields')) {
    textFields.border = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, textFields.border, Group.TextField);
    textFields.labelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFields.labelPosition, Group.TextField);
    textFields.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, textFields.errorIndentation, Group.TextField);
  }

  if (pick.includes('stepper')) {
    stepper.separator = (0, _addonKnobs["boolean"])('Separator', stepper.separator, 'Stepper');
  }

  if (pick.includes('select')) {
    selects.border = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, selects.border, Group.Select);
    selects.labelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, selects.labelPosition, Group.Select);
    selects.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, selects.errorIndentation, Group.Select);
    selects.disclosureIconSeparator = (0, _addonKnobs["boolean"])('Separator', selects.disclosureIconSeparator, Group.Select);
  }

  if (pick.includes('buyerJourney')) {
    buyerJourney.spacing = (0, _addonKnobs.select)(Label.Spacing, SPACING_OPTIONS, buyerJourney.spacing, Group.Breadcrumb);
    buyerJourney.chevronIconSeparator = (0, _addonKnobs["boolean"])(Breadcrumb.ChevronIconSeparator, buyerJourney.chevronIconSeparator, Group.Breadcrumb);
    buyerJourney.numberStyle = (0, _addonKnobs.select)(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, buyerJourney.numberStyle, Group.Breadcrumb);
    buyerJourney.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, buyerJourney.typographyStyle, Group.Breadcrumb);
  }

  if (pick.includes('checkbox')) {
    checkbox.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, SIMPLE_BORDER_RADIUS_OPTIONS, checkbox.borderRadius, Group.Checkbox);
    checkbox.errorIndentation = (0, _addonKnobs.select)(Label.ErrorIndentation, ERROR_INDENTATION_OPTIONS, checkbox.errorIndentation, Group.Checkbox);
  }

  if (pick.includes('banner')) {
    banner.border = (0, _addonKnobs.select)(Label.Border, SIMPLE_BORDER_OPTIONS, banner.border, Group.Banner);
    banner.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, banner.borderRadius, Group.Banner);
  }

  if (pick.includes('thumbnail')) {
    thumbnail.aspectRatio = (0, _addonKnobs.number)('Aspect ratio', 1, {
      min: 0
    }, Group.Thumbnail);
    thumbnail.border = (0, _addonKnobs.select)(Label.Border, SIMPLE_BORDER_OPTIONS, thumbnail.border, Group.Thumbnail);
    thumbnail.badgeBackground = (0, _addonKnobs.select)(Label.BadgeColor, BADGE_COLOR_OPTIONS, thumbnail.badgeBackground, Group.Thumbnail);
  }

  if (pick.includes('optionList')) {
    optionList.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, optionList.borderRadius, Group.OptionList);
    optionList.border = (0, _addonKnobs.select)(Label.Border, OPTION_LIST_BORDER_OPTIONS, optionList.border, Group.OptionList);
    optionList.borderStyle = (0, _addonKnobs.select)('Border style', BORDER_STYLE_OPTIONS, optionList.borderStyle, Group.OptionList);
    optionList.spacing = (0, _addonKnobs.select)(Label.Spacing, optionify(['none', 'tight', 'base']), optionList.spacing, Group.OptionList);
    optionList.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, optionList.blockPadding, Group.OptionList);
    optionList.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, optionList.inlinePadding, Group.OptionList);
    optionList.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, optionList.typographyStyle, Group.OptionList);
  }

  if (pick.includes('reviewBlock')) {
    reviewBlock.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, reviewBlock.borderRadius, Group.ReviewBlock);
    reviewBlock.border = (0, _addonKnobs.select)(Label.Border, OPTION_LIST_BORDER_OPTIONS, reviewBlock.border, Group.ReviewBlock);
    reviewBlock.spacing = (0, _addonKnobs.select)(Label.Spacing, optionify(['none', 'tight', 'base']), reviewBlock.spacing, Group.ReviewBlock);
    reviewBlock.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, reviewBlock.blockPadding, Group.ReviewBlock);
    reviewBlock.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, reviewBlock.inlinePadding, Group.ReviewBlock);
    reviewBlock.divider = (0, _addonKnobs.select)('Divider', DIVIDER_OPTIONS, reviewBlock.divider, Group.ReviewBlock);
  }

  if (pick.includes('headingLevel1')) {
    headingLevel1.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel1.typographyStyle, Group.HeadingLevel1);
  }

  if (pick.includes('headingLevel2')) {
    headingLevel2.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel2.typographyStyle, Group.HeadingLevel2);
  }

  if (pick.includes('headingLevel3')) {
    headingLevel3.typographyStyle = (0, _addonKnobs.select)(Label.Style, STYLE_OPTIONS, headingLevel3.typographyStyle, Group.HeadingLevel3);
  }

  if (pick.includes('primaryButton')) {
    primaryButton.style = (0, _addonKnobs.select)(Label.Style, BUTTON_STYLE_OPTIONS, primaryButton.style, Group.PrimaryButton);
    primaryButton.style = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, primaryButton.border, Group.PrimaryButton);
    primaryButton.style = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, primaryButton.borderRadius, Group.PrimaryButton);
    primaryButton.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, primaryButton.blockPadding, Group.PrimaryButton);
    primaryButton.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, primaryButton.inlinePadding, Group.PrimaryButton);
    primaryButton.typographyStyle = (0, _addonKnobs.select)(Label.TypographyStyle, STYLE_OPTIONS, primaryButton.typographyStyle, Group.PrimaryButton);
    primaryButton.loadingStyle = (0, _addonKnobs.select)(Label.LoadingStyle, LOADING_STYLE_OPTIONS, primaryButton.loadingStyle, Group.PrimaryButton);
  }

  if (pick.includes('secondaryButton')) {
    secondaryButton.style = (0, _addonKnobs.select)(Label.Style, BUTTON_STYLE_OPTIONS, secondaryButton.style, Group.SecondaryButton);
    secondaryButton.style = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, secondaryButton.border, Group.SecondaryButton);
    secondaryButton.style = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, secondaryButton.borderRadius, Group.SecondaryButton);
    secondaryButton.blockPadding = (0, _addonKnobs.select)(Label.BlockPadding, SPACING_OPTIONS, secondaryButton.blockPadding, Group.SecondaryButton);
    secondaryButton.inlinePadding = (0, _addonKnobs.select)(Label.InlinePadding, SPACING_OPTIONS, secondaryButton.inlinePadding, Group.SecondaryButton);
    secondaryButton.typographyStyle = (0, _addonKnobs.select)(Label.TypographyStyle, STYLE_OPTIONS, secondaryButton.typographyStyle, Group.SecondaryButton);
    secondaryButton.loadingStyle = (0, _addonKnobs.select)(Label.LoadingStyle, LOADING_STYLE_OPTIONS, secondaryButton.loadingStyle, Group.SecondaryButton);
  }

  if (pick.includes('formLayout')) {
    formLayout.spacing = (0, _addonKnobs.select)('Spacing', SPACING_OPTIONS, formLayout.spacing, Group.FormLayout);
  }

  if (pick.includes('tag')) {
    tag.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tag.borderRadius, Group.Tag);
  }

  if (pick.includes('tooltip')) {
    tooltip.borderRadius = (0, _addonKnobs.select)(Label.BorderRadius, BORDER_RADIUS_OPTIONS, tooltip.borderRadius, Group.Tooltip);
    tooltip.opacity = (0, _addonKnobs.select)('Opacity', OPACITY_OPTIONS, tooltip.opacity, Group.Tooltip);
    tooltip.textAlignment = (0, _addonKnobs.select)('Text alignment', TEXT_ALIGNMENT_OPTIONS, tooltip.textAlignment, Group.Tooltip);
  }

  if (pick.includes('link')) {
    link.transitionDuration = (0, _addonKnobs.select)(Label.TransitionDuration, TRANSITION_DURATION_OPTIONS, link.transitionDuration, Group.Link);
    link.colorHovered = (0, _addonKnobs.select)(Label.ColorHovered, COLOR_STYLE_OPTIONS, link.colorHovered, Group.Link);
  }

  var theme = (0, _.createTheme)({
    textFields: textFields,
    stepper: stepper,
    select: selects,
    buyerJourney: buyerJourney,
    headingLevel1: headingLevel1,
    headingLevel2: headingLevel2,
    headingLevel3: headingLevel3,
    checkbox: checkbox,
    primaryButton: primaryButton,
    secondaryButton: secondaryButton,
    formLayout: formLayout,
    tag: tag,
    tooltip: tooltip,
    banner: banner,
    thumbnail: thumbnail,
    optionList: optionList,
    reviewBlock: reviewBlock,
    link: link,
    typographyStyle1: {
      size: (0, _addonKnobs.select)("Size", SIZE_OPTIONS, undefined, Group.Style),
      letterCase: (0, _addonKnobs.select)("Letter case", LETTER_CASE_OPTIONS, undefined, Group.Style),
      fonts: (0, _addonKnobs.select)("Font", FONT_OPTIONS, undefined, Group.Style),
      weight: (0, _addonKnobs.select)("Weight", WEIGHT_OPTIONS, undefined, Group.Style),
      lineSize: (0, _addonKnobs.select)("Line size", LINE_SIZE_OPTIONS, undefined, Group.Style),
      kerning: (0, _addonKnobs.select)("Kerning", KERNING_OPTIONS, undefined, Group.Style),
      decoration: (0, _addonKnobs.select)("Decoration", DECORATION_OPTIONS, undefined, Group.Style)
    },
    typographyScale: {
      base: (0, _addonKnobs.number)('Base size', 14, {}, Group.Typography),
      ratio: (0, _addonKnobs.number)('Scale ratio', 1.285, {
        step: 0.001
      }, Group.Typography)
    },
    typographyPrimary: {
      fonts: (0, _addonKnobs.text)('Primary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
      weightBase: (0, _addonKnobs.select)('Primary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
      weightBold: (0, _addonKnobs.select)('Primary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography)
    },
    typographySecondary: {
      fonts: (0, _addonKnobs.text)('Secondary font stack', "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', sans-serif", Group.Typography),
      weightBase: (0, _addonKnobs.select)('Secondary font - base weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography),
      weightBold: (0, _addonKnobs.select)('Secondary font - bold weight', FONT_WEIGHT_OPTIONS, undefined, Group.Typography)
    },
    colors: {
      canvas: hsluvColorGroup('Canvas'),
      surfacePrimary: hsluvColorGroup('Surface primary'),
      surfaceSecondary: hsluvColorGroup('Surface secondary'),
      surfaceTertiary: hsluvColorGroup('Surface tertiary'),
      primaryAction: hsluvColorGroup('Primary action'),
      secondaryAction: hsluvColorGroup('Secondary action'),
      tertiaryAction: hsluvColorGroup('Tertiary action'),
      interactive: hsluvColorGroup('Interactive'),
      info: hsluvColorGroup('Info'),
      success: hsluvColorGroup('Success'),
      warning: hsluvColorGroup('Warning'),
      critical: hsluvColorGroup('Critical'),
      color1: hsluvColorGroup('Color 1'),
      color2: hsluvColorGroup('Color 2')
    }
  });
  return /*#__PURE__*/_react["default"].createElement(_.Theme, {
    theme: theme
  }, children);
}

function optionify(array) {
  return array.reduce(function (acc, value) {
    return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, value, value));
  }, {
    ' ': undefined
  });
}

function toHsluv(str) {
  if (str === UNDEFINED) return undefined;
  var rgb = str.slice(5, -1).split(',').slice(0, 3).map(Number).map(function (num) {
    return num / 255;
  });
  return (0, _hsluv.rgbToHsluv)(rgb);
}

function hsluvColor(name) {
  return toHsluv((0, _addonKnobs.color)(name, UNDEFINED, Group.Color));
}

function hsluvColorGroup(name) {
  return {
    background: hsluvColor("".concat(name, " background")),
    foreground: hsluvColor("".concat(name, " foreground")),
    accent: hsluvColor("".concat(name, " accent"))
  };
}