"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var _react = _interopRequireWildcard(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../test-utilities");

var _breakpoint = require("./breakpoint");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('createMediaQueries', function () {
  it('creates media queries', function () {
    var mediaQueries = (0, _breakpoint.createMediaQueries)();
    expect(mediaQueries).toStrictEqual([{
      breakpoint: 'base',
      query: '(min-width: 0px) and (max-width: 749px)'
    }, {
      breakpoint: 'small',
      query: '(min-width: 750px) and (max-width: 999px)'
    }, {
      breakpoint: 'medium',
      query: '(min-width: 1000px) and (max-width: 1199px)'
    }, {
      breakpoint: 'large',
      query: '(min-width: 1200px)'
    }]);
  });
});
describe('useBreakpoint', function () {
  var spy = jest.fn();

  function Component() {
    var breakpoint = (0, _breakpoint.useBreakpoint)();
    (0, _react.useEffect)(function () {
      spy(breakpoint);
    });
    return null;
  }

  beforeEach(function () {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(function () {
    _jestDomMocks.matchMedia.restore();

    spy.mockReset();
  });
  it('does not match any breakpoint', function () {
    _jestDomMocks.matchMedia.setMedia(function () {
      return {
        matches: false
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([[undefined]]);
  });
  it('matches base breakpoint', function () {
    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 0px) and (max-width: 749px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['base']]);
  });
  it('matches small breakpoint', function () {
    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 750px) and (max-width: 999px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['small']]);
  });
  it('matches medium breakpoint', function () {
    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1000px) and (max-width: 1199px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['medium']]);
  });
  it('matches large breakpoint', function () {
    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1200px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['large']]);
  });
});