"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var _react = _interopRequireWildcard(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _responsive = require("./responsive");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('generateResponsiveClassnames', function () {
  it('returns base className', function () {
    var prop = {
      background: 'surfacePrimary'
    };
    var classNames = (0, _responsive.generateResponsiveClassnames)(prop);
    expect(classNames).toStrictEqual(['backgroundSurfacePrimary']);
  });
  it('returns multiple base classNames when prop maps to many properties', function () {
    var prop = {
      padding: 'base'
    };
    var classNames = (0, _responsive.generateResponsiveClassnames)(prop);
    expect(classNames).toStrictEqual(['paddingInlineStartBase', 'paddingInlineEndBase', 'paddingBlockStartBase', 'paddingBlockEndBase']);
  });
  it('returns responsive classNames when breakpoint is provided', function () {
    var prop = {
      padding: 'base'
    };
    var baseClassNames = (0, _responsive.generateResponsiveClassnames)(prop, 'base');
    var smallClassNames = (0, _responsive.generateResponsiveClassnames)(prop, 'small');
    var mediumClassNames = (0, _responsive.generateResponsiveClassnames)(prop, 'medium');
    var largeClassNames = (0, _responsive.generateResponsiveClassnames)(prop, 'large');
    expect(baseClassNames).toStrictEqual(['paddingInlineStartBase', 'paddingInlineEndBase', 'paddingBlockStartBase', 'paddingBlockEndBase']);
    expect(smallClassNames).toStrictEqual(['smallPaddingInlineStartBase', 'smallPaddingInlineEndBase', 'smallPaddingBlockStartBase', 'smallPaddingBlockEndBase']);
    expect(mediumClassNames).toStrictEqual(['mediumPaddingInlineStartBase', 'mediumPaddingInlineEndBase', 'mediumPaddingBlockStartBase', 'mediumPaddingBlockEndBase']);
    expect(largeClassNames).toStrictEqual(['largePaddingInlineStartBase', 'largePaddingInlineEndBase', 'largePaddingBlockStartBase', 'largePaddingBlockEndBase']);
  });
});
describe('convertLogicalProps', function () {
  it('returns prop untouched if not using a shorthand', function () {
    var logicalProps = (0, _responsive.convertLogicalProps)('padding', 'base');
    expect(logicalProps).toStrictEqual({
      padding: 'base'
    });
  });
  it('returns block and inline logical props when using 2 directions', function () {
    var logicalProps = (0, _responsive.convertLogicalProps)('padding', ['base', 'tight']);
    expect(logicalProps).toStrictEqual({
      paddingBlock: 'base',
      paddingInline: 'tight'
    });
  });
  it('returns block start/end and inline start/end logical props when using 4 directions', function () {
    var logicalProps = (0, _responsive.convertLogicalProps)('padding', ['base', 'tight', 'loose', 'extraLoose']);
    expect(logicalProps).toStrictEqual({
      paddingBlockEnd: 'loose',
      paddingBlockStart: 'base',
      paddingInlineEnd: 'tight',
      paddingInlineStart: 'extraLoose'
    });
  });
});
describe('useResponsive', function () {
  var spy = jest.fn();

  function ResponsiveComponent(_ref) {
    var props = _extends({}, _ref);

    var responsiveClassNames = (0, _responsive.useResponsive)(props);
    (0, _react.useEffect)(function () {
      spy(responsiveClassNames);
    }, [responsiveClassNames]);
    return null;
  }

  afterEach(function () {
    spy.mockReset();
  });
  describe('padding', function () {
    it('applies the base padding classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        padding: "base"
      }));
      expect(spy.mock.calls).toMatchObject([[['paddingInlineStartBase', 'paddingInlineEndBase', 'paddingBlockStartBase', 'paddingBlockEndBase']]]);
    });
    it('applies the base block and inline padding classNames when using 2 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        padding: ['base', 'tight']
      }));
      expect(spy.mock.calls).toMatchObject([[['paddingBlockStartBase', 'paddingBlockEndBase', 'paddingInlineStartTight', 'paddingInlineEndTight']]]);
    });
    it('applies the base block start/end and inline start/end padding classNames when using 4 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        padding: ['tight', 'base', 'loose', 'extraLoose']
      }));
      expect(spy.mock.calls).toMatchObject([[['paddingBlockStartTight', 'paddingInlineEndBase', 'paddingBlockEndLoose', 'paddingInlineStartExtraLoose']]]);
    });
  });
  describe('background', function () {
    it('applies the base background className', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        background: "surfacePrimary"
      }));
      expect(spy.mock.calls).toMatchObject([[['backgroundSurfacePrimary']]]);
    });
  });
  describe('border', function () {
    it('applies the base border classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        border: "base"
      }));
      expect(spy.mock.calls).toMatchObject([[['borderInlineStartBase', 'borderInlineEndBase', 'borderBlockStartBase', 'borderBlockEndBase']]]);
    });
    it('applies the base block and inline border classNames when using 2 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        border: ['base', 'dotted']
      }));
      expect(spy.mock.calls).toMatchObject([[['borderBlockStartBase', 'borderBlockEndBase', 'borderInlineStartDotted', 'borderInlineEndDotted']]]);
    });
    it('applies the base block start/end and inline start/end border classNames when using 4 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        border: ['base', 'dotted', 'base', 'dotted']
      }));
      expect(spy.mock.calls).toMatchObject([[['borderBlockStartBase', 'borderInlineEndDotted', 'borderBlockEndBase', 'borderInlineStartDotted']]]);
    });
  });
  describe('borderWidth', function () {
    it('applies the base borderWidth classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderWidth: "thin"
      }));
      expect(spy.mock.calls).toMatchObject([[['borderWidthInlineStartThin', 'borderWidthInlineEndThin', 'borderWidthBlockStartThin', 'borderWidthBlockEndThin']]]);
    });
    it('applies the base block and inline borderWidth classNames when using 2 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderWidth: ['thin', 'thick']
      }));
      expect(spy.mock.calls).toMatchObject([[['borderWidthBlockStartThin', 'borderWidthBlockEndThin', 'borderWidthInlineStartThick', 'borderWidthInlineEndThick']]]);
    });
    it('applies the base block start/end and inline start/end borderWidth classNames when using 4 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderWidth: ['thin', 'medium', 'thick', 'thin']
      }));
      expect(spy.mock.calls).toMatchObject([[['borderWidthBlockStartThin', 'borderWidthInlineEndMedium', 'borderWidthBlockEndThick', 'borderWidthInlineStartThin']]]);
    });
  });
  describe('borderColor', function () {
    it('applies the base borderColor classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderColor: "base"
      }));
      expect(spy.mock.calls).toMatchObject([[['borderColorInlineStartBase', 'borderColorInlineEndBase', 'borderColorBlockStartBase', 'borderColorBlockEndBase']]]);
    });
  });
  describe('borderRadius', function () {
    it('applies the base borderRadius classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderRadius: "base"
      }));
      expect(spy.mock.calls).toMatchObject([[['borderRadiusInlineStartBase', 'borderRadiusInlineEndBase', 'borderRadiusBlockStartBase', 'borderRadiusBlockEndBase']]]);
    });
    it('applies the base block and inline borderRadius classNames when using 2 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderRadius: ['base', 'tight']
      }));
      expect(spy.mock.calls).toMatchObject([[['borderRadiusBlockStartBase', 'borderRadiusBlockEndBase', 'borderRadiusInlineStartTight', 'borderRadiusInlineEndTight']]]);
    });
    it('applies the base block start/end and inline start/end borderRadius classNames when using 4 directions shorthand', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        borderRadius: "base"
      }));
      expect(spy.mock.calls).toMatchObject([[['borderRadiusInlineStartBase', 'borderRadiusInlineEndBase', 'borderRadiusBlockStartBase', 'borderRadiusBlockEndBase']]]);
    });
  });
  describe('spacing', function () {
    it('applies the base spacing classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        spacing: "base"
      }));
      expect(spy.mock.calls).toMatchObject([[['spacingBase']]]);
    });
  });
  describe('stack', function () {
    it('applies the base stack classNames', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        stack: false
      }));
      expect(spy.mock.calls).toMatchObject([[['stackFalse']]]);
    });
  });
  describe('media', function () {
    it('applies the classNames to the specified viewport size', function () {
      (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(ResponsiveComponent, {
        background: {
          small: 'surfacePrimary'
        },
        border: {
          small: ['dotted', 'base']
        },
        borderWidth: {
          small: ['thin', 'medium', 'medium', 'thick']
        },
        borderColor: {
          small: 'emphasized'
        },
        borderRadius: {
          small: ['tight', 'base', 'tight', 'base']
        },
        padding: {
          small: 'extraLoose'
        },
        spacing: {
          small: 'thight'
        }
      }));
      expect(spy.mock.calls).toMatchObject([[['smallBackgroundSurfacePrimary', 'smallBorderBlockStartDotted', 'smallBorderBlockEndDotted', 'smallBorderInlineStartBase', 'smallBorderInlineEndBase', 'smallBorderWidthBlockStartThin', 'smallBorderWidthInlineEndMedium', 'smallBorderWidthBlockEndMedium', 'smallBorderWidthInlineStartThick', 'smallBorderColorInlineStartEmphasized', 'smallBorderColorInlineEndEmphasized', 'smallBorderColorBlockStartEmphasized', 'smallBorderColorBlockEndEmphasized', 'smallBorderRadiusBlockStartTight', 'smallBorderRadiusInlineEndBase', 'smallBorderRadiusBlockEndTight', 'smallBorderRadiusInlineStartBase', 'smallPaddingInlineStartExtraLoose', 'smallPaddingInlineEndExtraLoose', 'smallPaddingBlockStartExtraLoose', 'smallPaddingBlockEndExtraLoose', 'smallSpacingThight']]]);
    });
  });
});