"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useResponsiveValue = useResponsiveValue;
exports.useResponsiveStyle = useResponsiveStyle;
exports.maybeResponsiveToArray = maybeResponsiveToArray;
exports.isResponsiveValue = isResponsiveValue;

var _breakpoint2 = require("./breakpoint");

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function useResponsiveValue(values) {
  var breakpoint = (0, _breakpoint2.useBreakpoint)();
  return getResponsiveValue(values, breakpoint);
}

/**
 * Returns a style object matching the passed one, where each property value
 * is the one that applies to the current viewport size.
 *
 * @param options
 */
function useResponsiveStyle(options) {
  var currentBreakpoint = (0, _breakpoint2.useBreakpoint)();
  return Object.entries(options).reduce(function (styleObject, _ref) {
    var _getResponsiveValue;

    var _ref2 = _slicedToArray(_ref, 2),
        cssProperty = _ref2[0],
        _ref2$ = _ref2[1],
        value = _ref2$.value,
        transform = _ref2$.transform;

    return _objectSpread(_objectSpread({}, styleObject), {}, _defineProperty({}, cssProperty, (_getResponsiveValue = getResponsiveValue(maybeResponsiveToArray(value).reduce(function (values, _ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
          breakpoint = _ref4[0],
          breakpointValue = _ref4[1];

      if (breakpointValue) {
        return _objectSpread(_objectSpread({}, values), {}, _defineProperty({}, breakpoint, transform ? transform(breakpointValue) : breakpointValue));
      }

      return values;
    }, {}), currentBreakpoint)) !== null && _getResponsiveValue !== void 0 ? _getResponsiveValue : {}));
  }, {});
}

function maybeResponsiveToArray(maybeResponsive) {
  if (isResponsiveValue(maybeResponsive)) {
    return Object.entries(maybeResponsive);
  }

  return [['base', maybeResponsive]];
}

function isResponsiveValue(obj) {
  if (_typeof(obj) !== 'object' || !obj) {
    return false;
  }

  var hasBreakpoint = false;

  for (var _i2 = 0, _Object$keys = Object.keys(obj); _i2 < _Object$keys.length; _i2++) {
    var prop = _Object$keys[_i2];

    if (prop in _breakpoint2.BREAKPOINTS) {
      hasBreakpoint = true;
    } else {
      return false;
    }
  }

  return hasBreakpoint;
}

function getResponsiveValue(values, breakpoint) {
  if (!breakpoint) {
    return undefined;
  }

  if (values[breakpoint] !== undefined) {
    return values[breakpoint];
  }

  var breakpoints = Object.keys(_breakpoint2.BREAKPOINTS);
  var breakpointIndex = breakpoints.indexOf(breakpoint);

  for (var i = breakpointIndex; i >= 0; i--) {
    var _breakpoint = breakpoints[i];

    if (values[_breakpoint] !== undefined) {
      return values[_breakpoint];
    }
  }
}