"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var _react = _interopRequireWildcard(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../test-utilities");

var _responsiveValue = require("./responsiveValue");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('useResponsiveValue', function () {
  var spy = jest.fn();

  function Component(_ref) {
    var values = _ref.values;
    var value = (0, _responsiveValue.useResponsiveValue)(values);
    (0, _react.useEffect)(function () {
      spy(value);
    });
    return null;
  }

  beforeEach(function () {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(function () {
    _jestDomMocks.matchMedia.restore();

    spy.mockReset();
  });
  it('returns undefined if no breakpoint matches', function () {
    var values = {
      small: 'small'
    };

    _jestDomMocks.matchMedia.setMedia(function () {
      return {
        matches: false
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[undefined]]);
  });
  it('returns base value if it maches base breakpoint', function () {
    var values = {
      base: 'base'
    };

    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 0px) and (max-width: 749px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.base]]);
  });
  it('returns small value if it maches small breakpoint', function () {
    var values = {
      small: 'small'
    };

    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 750px) and (max-width: 999px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.small]]);
  });
  it('returns medium value if it maches medium breakpoint', function () {
    var values = {
      medium: 'medium'
    };

    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1000px) and (max-width: 1199px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.medium]]);
  });
  it('returns large value if it maches large breakpoint', function () {
    var values = {
      large: 'large'
    };

    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1200px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.large]]);
  });
  it('returns closest value if no breakpoint matches', function () {
    var values = {
      small: 'small',
      large: 'large'
    };

    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 750px) and (max-width: 999px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.small]]);
  });
  it('returns closest non undefined value', function () {
    var values = {
      small: 'small',
      medium: null,
      large: undefined
    };

    _jestDomMocks.matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1200px)'
      };
    });

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.medium]]);
  });
});
describe('isResponsiveValue', function () {
  it('returns false when a value different of a responsive value is passed', function () {
    expect((0, _responsiveValue.isResponsiveValue)(undefined)).toBe(false);
    expect((0, _responsiveValue.isResponsiveValue)(null)).toBe(false);
    expect((0, _responsiveValue.isResponsiveValue)('some value')).toBe(false);
    expect((0, _responsiveValue.isResponsiveValue)({})).toBe(false);
    expect((0, _responsiveValue.isResponsiveValue)({
      foo: 1,
      bar: 2
    })).toBe(false);
    expect((0, _responsiveValue.isResponsiveValue)({
      base: 1,
      small: 2,
      medium: 3,
      foo: 4
    })).toBe(false);
  });
  it('returns true when responsive value is passed', function () {
    expect((0, _responsiveValue.isResponsiveValue)({
      small: 'some value'
    })).toBe(true);
    expect((0, _responsiveValue.isResponsiveValue)({
      base: 1,
      small: 2,
      medium: 3,
      large: 4
    })).toBe(true);
  });
});
describe('maybeResponsiveToArray', function () {
  it('returns an array containing the passed non-responsive value as the value for the "base" breakpoint', function () {
    expect((0, _responsiveValue.maybeResponsiveToArray)('some value')).toStrictEqual([['base', 'some value']]);
  });
  it('returns an array containing the entries of the responsive value as an array', function () {
    expect(new Set((0, _responsiveValue.maybeResponsiveToArray)({
      base: 1,
      small: 2,
      medium: 3,
      large: 4
    }))).toStrictEqual(new Set([['base', 1], ['small', 2], ['medium', 3], ['large', 4]]));
    expect(new Set((0, _responsiveValue.maybeResponsiveToArray)({
      small: 2,
      medium: 3
    }))).toStrictEqual(new Set([['small', 2], ['medium', 3]]));
  });
});
describe('useResponsiveStyle', function () {
  var spy = jest.fn();

  function Component(_ref2) {
    var config = _ref2.config;
    var value = (0, _responsiveValue.useResponsiveStyle)(config);
    (0, _react.useEffect)(function () {
      spy(value);
    });
    return null;
  }

  beforeEach(function () {
    _jestDomMocks.matchMedia.mock();

    _jestDomMocks.matchMedia.setMedia(function () {
      return {
        matches: true
      };
    });
  });
  afterEach(function () {
    _jestDomMocks.matchMedia.restore();

    spy.mockReset();
  });
  it('returns an empty object if passed value is undefined', function () {
    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      config: {
        color: {
          value: undefined
        }
      }
    }));
    expect(spy.mock.calls).toMatchObject([[{}]]);
  });
  it('returns a style object with the values', function () {
    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      config: {
        color: {
          value: 'red'
        },
        paddingLeft: {
          value: 1
        }
      }
    }));
    expect(spy.mock.calls).toMatchObject([[{
      color: 'red',
      paddingLeft: 1
    }]]);
  });
  it('returns a style object with the responsive value', function () {
    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      config: {
        color: {
          value: {
            base: 'red'
          }
        },
        paddingLeft: {
          value: {
            base: 1
          }
        }
      }
    }));
    expect(spy.mock.calls).toMatchObject([[{
      color: 'red',
      paddingLeft: 1
    }]]);
  });
  it('returns a style object with the transformed value', function () {
    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(Component, {
      config: {
        color: {
          value: 'red',
          transform: function transform(value) {
            return "dark".concat(value);
          }
        },
        paddingLeft: {
          value: 1,
          transform: function transform(value) {
            return Number(value);
          }
        }
      }
    }));
    expect(spy.mock.calls).toMatchObject([[{
      color: 'darkred',
      paddingLeft: 1
    }]]);
  });
});