import React, { forwardRef, useCallback } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { useContainingForm } from '../../utilities/forms';
import { useTranslate } from '../AppContext';
import { useTransition } from '../../utilities/transition';
import { Spinner } from '../Spinner';
import { UnstyledLink } from '../Link';
import { button as legacyButtonClassName, buttonPrimary as legacyButtonPrimaryClassName, buttonSecondary as legacyButtonSecondaryClassName, buttonCritical as legacyButtonCriticalClassName, colorCriticalAccent as legacyColorCriticalAccent } from '../../utilities/legacy';
import { usePrefersReducedMotion } from '../../utilities/media-query';
import { useConnected } from '../Connected';
import { useThemeConfiguration } from '../Theme';
import { useResponsive } from '../../utilities/responsive';
import typographyStyles from '../../utilities/typography-styles.css';
import styles from './Button.css';
export var Button = /*#__PURE__*/forwardRef(function Button(_ref, ref) {
  var children = _ref.children,
      _ref$kind = _ref.kind,
      kind = _ref$kind === void 0 ? 'primary' : _ref$kind,
      _ref$submit = _ref.submit,
      submit = _ref$submit === void 0 ? false : _ref$submit,
      disabled = _ref.disabled,
      onPress = _ref.onPress,
      to = _ref.to,
      _ref$loading = _ref.loading,
      loading = _ref$loading === void 0 ? false : _ref$loading,
      loadingLabel = _ref.loadingLabel,
      accessibilityLabel = _ref.accessibilityLabel,
      _ref$fill = _ref.fill,
      fill = _ref$fill === void 0 ? false : _ref$fill,
      appearance = _ref.appearance,
      onMouseEnter = _ref.onMouseEnter,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'base' : _ref$size;
  var href = disabled ? undefined : to;
  var onClick = disabled ? undefined : function () {
    return onPress === null || onPress === void 0 ? void 0 : onPress();
  };
  var refsSetter = useCallback(function (instance) {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }
  }, [ref]);
  var translate = useTranslate();
  var prefersReducedMotion = usePrefersReducedMotion();
  var transition = useTransition(loading, {
    enter: 'slow'
  });
  var connected = useConnected();
  var responsiveSizes = useResponsive({
    size: size
  });

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.primaryButton,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.style,
      primaryStyle = _useThemeConfiguratio3 === void 0 ? 'fill' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.border,
      primaryBorder = _useThemeConfiguratio4 === void 0 ? 'none' : _useThemeConfiguratio4,
      primaryTypographyStyle = _useThemeConfiguratio2.typographyStyle,
      _useThemeConfiguratio5 = _useThemeConfiguratio2.loadingStyle,
      primaryLoading = _useThemeConfiguratio5 === void 0 ? 'spinner' : _useThemeConfiguratio5,
      _useThemeConfiguratio6 = _useThemeConfiguratio.secondaryButton,
      _useThemeConfiguratio7 = _useThemeConfiguratio6.style,
      secondaryStyle = _useThemeConfiguratio7 === void 0 ? 'inverse' : _useThemeConfiguratio7,
      _useThemeConfiguratio8 = _useThemeConfiguratio6.border,
      secondaryBorder = _useThemeConfiguratio8 === void 0 ? 'full' : _useThemeConfiguratio8,
      secondaryTypographyStyle = _useThemeConfiguratio6.typographyStyle,
      _useThemeConfiguratio9 = _useThemeConfiguratio6.loadingStyle,
      secondaryLoading = _useThemeConfiguratio9 === void 0 ? 'spinner' : _useThemeConfiguratio9,
      _useThemeConfiguratio10 = _useThemeConfiguratio.link,
      plainColorHovered = _useThemeConfiguratio10.colorHovered,
      linkTypographyStyle = _useThemeConfiguratio10.typographyStyle;

  var form = useContainingForm();
  var isSecondary = kind === 'secondary';
  var style = isSecondary ? secondaryStyle : primaryStyle;
  var border = isSecondary ? secondaryBorder : primaryBorder;
  var typographyStyle = isSecondary ? secondaryTypographyStyle : primaryTypographyStyle;
  var loadingStyle = isSecondary ? secondaryLoading : primaryLoading;
  var isPlain = kind === 'plain' || style === 'plain';
  var classes = classNames(styles.Button, kind && !isPlain && styles[variationName('kind', kind)], responsiveSizes && !isPlain && responsiveSizes.map(function (className) {
    return styles[className];
  }), border && !isPlain && styles[variationName('border', border)], style && !isPlain && styles[variationName('style', style)], appearance && styles[variationName('appearance', appearance)], isPlain && styles.stylePlain, isPlain && plainColorHovered && styles[variationName('stylePlainColorHovered', plainColorHovered)], fill && styles.fill, disabled && styles.disabled, loading && styles[variationName('loading', loadingStyle)], loading && loadingStyle === 'spinner' && styles[variationName('loading-transition', transition)], !isPlain && typographyStyle && typographyStyles[typographyStyle], isPlain && linkTypographyStyle && typographyStyles[linkTypographyStyle], connected && styles.connected,
  /* Basic theming for older browsers that do not support CSS Custom Properties: */
  legacyButtonClassName, kind === 'primary' && legacyButtonPrimaryClassName, kind === 'secondary' && legacyButtonSecondaryClassName, appearance === 'critical' && legacyButtonCriticalClassName, kind === 'plain' && appearance === 'critical' && legacyColorCriticalAccent);
  var normalizedLoadingLabel = loadingLabel ? loadingLabel : translate('processing');
  var contentClassNames = classNames(styles.Content);
  var content = /*#__PURE__*/React.createElement("span", {
    className: contentClassNames
  }, loading && loadingStyle === 'progressBar' && prefersReducedMotion ? normalizedLoadingLabel : children);
  var type = submit ? 'submit' : 'button';
  var loadingMarkup = loadingStyle === 'spinner' ? /*#__PURE__*/React.createElement("span", {
    className: classNames(styles.LoadingContent, !prefersReducedMotion && styles.Spinner)
  }, /*#__PURE__*/React.createElement(Spinner, {
    size: "small",
    color: "inherit",
    accessibilityLabel: normalizedLoadingLabel
  })) : /*#__PURE__*/React.createElement("span", {
    className: styles.ProgressBar
  });

  if (href) {
    return /*#__PURE__*/React.createElement(UnstyledLink, {
      to: href,
      className: classes,
      onPress: onPress,
      ariaBusy: loading,
      ariaLive: loading ? 'assertive' : 'polite',
      ariaLabel: accessibilityLabel
    }, content, loading && loadingMarkup);
  }

  return /*#__PURE__*/React.createElement("button", {
    type: type,
    form: submit && (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined,
    className: classes,
    disabled: disabled || loading,
    onClick: onClick,
    "aria-busy": loading || undefined,
    "aria-live": loading ? 'assertive' : undefined,
    "aria-label": accessibilityLabel,
    ref: refsSetter,
    onMouseEnter: onMouseEnter
  }, content, loading && loadingMarkup);
});