import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { CheckboxControl } from '../Checkbox';
import { RadioControl } from '../RadioControl';
import { ChoiceList, Choice } from './ChoiceList';
var defaultProps = {
  name: 'choice_list'
};
var id = '123';
var singleValue = id;
var multiValue = [id];
var labelContent = 'Label content';
var accessibilityLabel = 'Accessibility label content';
describe('<ChoiceList />', function () {
  it('renders a `RadioControl` component as the `Choice` when `value` is a single string', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).toContainReactComponent(RadioControl);
  });
  it('does not render a `RadioControl` component as the `Choice` when `value` is a single string', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).not.toContainReactComponent(CheckboxControl);
  });
  it('renders a `CheckboxControl` component as the `Choice` when `value` is a string array', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).toContainReactComponent(CheckboxControl);
  });
  it('does not render a `RadioControl` component as the `Choice` when `value` is a string array', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).not.toContainReactComponent(RadioControl);
  });
  it('passes its name down to its `RadioControl` component', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(RadioControl)).toHaveReactProps({
      name: defaultProps.name
    });
  });
  it('passes its onChange down to its `RadioControl` component', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(RadioControl)).toHaveReactProps({
      onChange: expect.any(Function)
    });
  });
  it('sets a checked prop on its `RadioControl` component whose id equals the Choice value', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(RadioControl)).toHaveReactProps({
      checked: true
    });
  });
  it('does not set a checked prop on its `RadioControl` component whose id does not equal the Choice value', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: "",
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(RadioControl)).toHaveReactProps({
      checked: false
    });
  });
  it('passes its name down to its `CheckboxControl` component', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(CheckboxControl)).toHaveReactProps({
      name: defaultProps.name
    });
  });
  it('passes its onChange down to its `CheckboxControl` component', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(CheckboxControl)).toHaveReactProps({
      onChange: expect.any(Function)
    });
  });
  it('sets a checked prop on its `CheckboxControl` component whose id is contained in the Choice value', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(CheckboxControl)).toHaveReactProps({
      checked: true
    });
  });
  it('does not set a checked prop on its `CheckboxControl` component whose id is not contained in the Choice value', function () {
    var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
      value: [''],
      onChange: noop
    }), /*#__PURE__*/React.createElement(Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(CheckboxControl)).toHaveReactProps({
      checked: false
    });
  });
  describe('<Choice />', function () {
    it('renders children as its label content', function () {
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: noop
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id
      }, labelContent)));
      expect(choiceList.find('label')).toHaveReactProps({
        children: labelContent
      });
    });
    it('sets an aria-label on the Choice label when accessibilityLabel is provided', function () {
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: noop
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id,
        accessibilityLabel: accessibilityLabel
      }, labelContent)));
      expect(choiceList.find('label')).toHaveReactProps({
        'aria-label': accessibilityLabel
      });
    });
    it('does not set an aria-label on the Choice label when accessibilityLabel is not provided', function () {
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: noop
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id
      }, labelContent)));
      expect(choiceList.find('label')).not.toHaveReactProps({
        'aria-label': accessibilityLabel
      });
    });
    it('calls its `onChange` handler with a string value when checked on a choicelist with a string value', function () {
      var onChangeSpy = jest.fn();
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: "",
        onChange: onChangeSpy
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id
      }, labelContent)));
      choiceList.find(RadioControl).trigger('onChange', true);
      expect(onChangeSpy).toHaveBeenCalledWith(id);
    });
    it('calls its `onChange` handler with a string value when unchecked on a choicelist with a string value', function () {
      var onChangeSpy = jest.fn();
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: singleValue,
        onChange: onChangeSpy
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id
      }, labelContent)));
      choiceList.find(RadioControl).trigger('onChange', false);
      expect(onChangeSpy).toHaveBeenCalledWith('');
    });
    it('calls its `onChange` handler with a string array value when checked on a choicelist with a string array value', function () {
      var onChangeSpy = jest.fn();
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: [],
        onChange: onChangeSpy
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id
      }, labelContent)));
      choiceList.find(CheckboxControl).trigger('onChange', true);
      expect(onChangeSpy).toHaveBeenCalledWith([id]);
    });
    it('calls its `onChange` handler with a string array value when unchecked on a choicelist with a string array value', function () {
      var onChangeSpy = jest.fn();
      var choiceList = mountWithContext( /*#__PURE__*/React.createElement(ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: onChangeSpy
      }), /*#__PURE__*/React.createElement(Choice, {
        id: id
      }, labelContent)));
      choiceList.find(CheckboxControl).trigger('onChange', false);
      expect(onChangeSpy).toHaveBeenCalledWith([]);
    });
  });
});

function noop() {}