import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { Collapsible } from './Collapsible';
describe('<Collapsible />', function () {
  describe('open', function () {
    it('renders children but is hidden when closed', function () {
      var collapsible = mountWithContext( /*#__PURE__*/React.createElement(Collapsible, {
        id: "test-collapsible",
        open: false
      }, "content"));
      expect(collapsible).toContainReactComponent('div', {
        'aria-expanded': false,
        hidden: true,
        style: {
          height: 0
        }
      });
      expect(collapsible).toContainReactText('content');
    });
    it('renders children and is aria-expanded when open', function () {
      var collapsible = mountWithContext( /*#__PURE__*/React.createElement(Collapsible, {
        id: "test-collapsible",
        open: true
      }, "content"));
      expect(collapsible).toContainReactComponent('div', {
        'aria-expanded': true,
        hidden: false,
        style: {
          height: 'auto'
        }
      });
      expect(collapsible).toContainReactText('content');
    });
  });
  describe('minSize', function () {
    it('height is set to minSize when closed and not hidden', function () {
      var minSize = 50;
      var collapsible = mountWithContext( /*#__PURE__*/React.createElement(Collapsible, {
        id: "test-collapsible",
        open: false,
        minSize: minSize
      }, "content"));
      expect(collapsible).toContainReactComponent('div', {
        'aria-expanded': false,
        hidden: false,
        style: {
          height: minSize
        }
      });
    });
  });
});