import React from 'react';
import { withKnobs } from '@storybook/addon-knobs';
import faker from 'faker';
import { themeWithKnobs } from '../../storybook-utilities';
import { BlockStack } from '../BlockStack';
import { InlineStack } from '../InlineStack';
import { Text } from '../Text';
import { View } from '../View';
import { Divider } from './Divider';
var meta = {
  component: Divider,
  title: 'checkout-web-ui/Divider',
  decorators: [withKnobs, themeWithKnobs('colors')],
  argTypes: {
    width: {
      control: {
        type: 'select',
        options: [undefined, 'thin', 'medium', 'thick', 'extraThick']
      }
    },
    blockSpacing: {
      control: {
        type: 'select',
        options: [undefined, 'none', 'extraTight', 'tight', 'base', 'loose', 'extraLoose']
      }
    },
    alignment: {
      control: {
        type: 'select',
        options: [undefined, 'start', 'center', 'end']
      }
    }
  }
};
export default meta;

function Content() {
  return /*#__PURE__*/React.createElement(Text, null, "Hello, world!");
}

function ChildContent() {
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Text, {
    subdued: true
  }, "Hello, "), /*#__PURE__*/React.createElement(Text, {
    emphasized: true
  }, "world!"));
}

function LoremIpsum() {
  return /*#__PURE__*/React.createElement(View, {
    border: "dotted",
    display: "block"
  }, /*#__PURE__*/React.createElement(Text, {
    subdued: true
  }, faker.lorem.words(20)));
}

export var defaultState = function defaultState() {
  return /*#__PURE__*/React.createElement(BlockStack, null, /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, null), /*#__PURE__*/React.createElement(Content, null));
};
export var vertical = function vertical() {
  return /*#__PURE__*/React.createElement(InlineStack, null, /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical"
  }), /*#__PURE__*/React.createElement(Content, null));
};
export var width = function width() {
  return /*#__PURE__*/React.createElement(BlockStack, null, /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, null), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    width: "medium"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    width: "thick"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    width: "extraThick"
  }), /*#__PURE__*/React.createElement(InlineStack, null, /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "medium"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "thick"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "extraThick"
  }), /*#__PURE__*/React.createElement(Content, null)));
};
export var blockSpacing = function blockSpacing() {
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(View, {
    display: "block",
    border: "dotted",
    padding: "loose"
  }, /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    blockSpacing: "none"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    blockSpacing: "extraTight"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    blockSpacing: "tight"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    blockSpacing: "base"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    blockSpacing: "loose"
  }), /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, {
    blockSpacing: "extraLoose"
  }), /*#__PURE__*/React.createElement(Content, null)), /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement(View, {
    display: "block",
    border: "dotted",
    padding: "loose"
  }, /*#__PURE__*/React.createElement(InlineStack, {
    spacing: "none"
  }, /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    blockSpacing: "none"
  }), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    blockSpacing: "extraTight"
  }), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    blockSpacing: "tight"
  }), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    blockSpacing: "base"
  }), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    blockSpacing: "loose"
  }), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    blockSpacing: "extraLoose"
  }), /*#__PURE__*/React.createElement(LoremIpsum, null))));
};
export var alignment = function alignment() {
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Text, {
    subdued: true
  }, "With alignment, width, children"), /*#__PURE__*/React.createElement(View, {
    display: "block",
    padding: "loose",
    border: "dotted"
  }, /*#__PURE__*/React.createElement(BlockStack, {
    spacing: "extraLoose"
  }, /*#__PURE__*/React.createElement(Divider, {
    direction: "horizontal",
    width: "thin",
    alignment: "center"
  }, /*#__PURE__*/React.createElement(ChildContent, null)), /*#__PURE__*/React.createElement(Divider, {
    direction: "horizontal",
    width: "medium",
    alignment: "center"
  }, /*#__PURE__*/React.createElement(ChildContent, null)), /*#__PURE__*/React.createElement(Divider, {
    direction: "horizontal",
    width: "thick",
    alignment: "start"
  }, /*#__PURE__*/React.createElement(ChildContent, null)), /*#__PURE__*/React.createElement(Divider, {
    direction: "horizontal",
    width: "extraThick",
    alignment: "end"
  }, /*#__PURE__*/React.createElement(ChildContent, null)))), /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement(Text, {
    subdued: true
  }, "With direction vertical, alignment, width, children"), /*#__PURE__*/React.createElement(View, {
    display: "block",
    padding: "loose",
    border: "dotted"
  }, /*#__PURE__*/React.createElement(InlineStack, {
    alignment: "center",
    spacing: "extraLoose"
  }, /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "extraThick",
    alignment: "start"
  }, /*#__PURE__*/React.createElement(Content, null)), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "thick",
    alignment: "center"
  }, /*#__PURE__*/React.createElement(Content, null)), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "medium",
    alignment: "end"
  }, /*#__PURE__*/React.createElement(Content, null)), /*#__PURE__*/React.createElement(LoremIpsum, null), /*#__PURE__*/React.createElement(Divider, {
    direction: "vertical",
    width: "thin",
    alignment: "end"
  }, /*#__PURE__*/React.createElement(Content, null)))));
};
export var withControls = function withControls(props) {
  return /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Content, null), /*#__PURE__*/React.createElement(Divider, props), /*#__PURE__*/React.createElement(Content, null));
};
withControls.args = {
  width: undefined,
  blockSpacing: undefined,
  children: '',
  alignment: undefined
};