import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../../../test-utilities';
import { UnstyledLink } from './UnstyledLink';
var defaultProps = {
  to: faker.internet.url()
};
describe('<UnstyledLink />', function () {
  it('renders an anchor with expected target and rel if external', function () {
    var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, Object.assign({}, defaultProps, {
      external: true
    })));
    expect(unstyledLink).toContainReactComponent('a', {
      target: '_blank',
      rel: 'noopener noreferrer'
    });
  });
  it('renders an anchor without target or rel if not external', function () {
    var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, defaultProps));
    expect(unstyledLink).toContainReactComponent('a', {
      target: undefined,
      rel: undefined
    });
  });
  it('renders a custom link provided by the consumer', function () {
    function CustomLink() {
      return /*#__PURE__*/React.createElement("div", null, "No navigation allowed!");
    }

    var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, defaultProps), {
      linkComponent: CustomLink
    });
    expect(unstyledLink).toContainReactComponent(CustomLink, defaultProps);
  });
  describe('language', function () {
    it('renders an anchor with lang attribute', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, Object.assign({}, defaultProps, {
        language: "en"
      })));
      expect(unstyledLink).toContainReactComponent('a', {
        lang: 'en'
      });
    });
  });
  describe('ariaBusy', function () {
    it('renders an anchor with aria-busy when set', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, Object.assign({}, defaultProps, {
        ariaBusy: true
      })));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-busy': true
      });
    });
    it('renders an anchor without aria-busy when not set', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, defaultProps));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-busy': undefined
      });
    });
    it('renders an anchor without aria-busy when false', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, Object.assign({}, defaultProps, {
        ariaBusy: false
      })));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-busy': undefined
      });
    });
  });
  describe('ariaLive', function () {
    it('renders an anchor with aria-live value when set', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, Object.assign({}, defaultProps, {
        ariaLive: "assertive"
      })));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-live': 'assertive'
      });
    });
    it('does not renders with aria-live when not set', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, defaultProps));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-live': undefined
      });
    });
  });
  describe('ariaLabel', function () {
    it('renders an anchor with aria-label when set', function () {
      var content = 'Accessible label';
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, Object.assign({}, defaultProps, {
        ariaLabel: content
      })));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-label': content
      });
    });
    it('does not renders with aria-live when not set', function () {
      var unstyledLink = mountWithContext( /*#__PURE__*/React.createElement(UnstyledLink, defaultProps));
      expect(unstyledLink).toContainReactComponent('a', {
        'aria-label': undefined
      });
    });
  });
});