import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../../../test-utilities';
import { Text } from '../../../Text';
import { MoneyLine, MoneyLineContent, MoneyLineHeader } from './MoneyLine';
describe('<MoneyLine />', function () {
  it('renders a label', function () {
    var label = faker.random.word();
    var moneyLine = mountWithContext( /*#__PURE__*/React.createElement(MoneyLine, {
      label: label
    }));
    expect(moneyLine.find(MoneyLineHeader)).toContainReactComponent(Text, {
      children: label
    });
  });
  it('renders a value', function () {
    var value = faker.random.word();
    var moneyLine = mountWithContext( /*#__PURE__*/React.createElement(MoneyLine, {
      label: "label",
      value: value
    }));
    expect(moneyLine.find(MoneyLineContent)).toContainReactComponent(Text, {
      children: value
    });
  });
  it('renders a subdued value', function () {
    var value = faker.random.word();
    var moneyLine = mountWithContext( /*#__PURE__*/React.createElement(MoneyLine, {
      label: "label",
      value: value,
      subdued: true
    }));
    expect(moneyLine.find(MoneyLineContent)).toContainReactComponent(Text, {
      subdued: true,
      children: value
    });
  });
  it('renders the children', function () {
    var moneyLine = mountWithContext( /*#__PURE__*/React.createElement(MoneyLine, null, /*#__PURE__*/React.createElement(MoneyLineHeader, null), /*#__PURE__*/React.createElement(MoneyLineContent, null)));
    expect(moneyLine).toContainReactComponent(MoneyLineHeader);
    expect(moneyLine).toContainReactComponent(MoneyLineContent);
  });
  describe('<MoneyLineHeader />', function () {
    it('renders the children', function () {
      var children = 'children';
      var moneyLine = mountWithContext( /*#__PURE__*/React.createElement(MoneyLine, null, /*#__PURE__*/React.createElement(MoneyLineHeader, null, children)));
      expect(moneyLine.find(MoneyLineHeader)).toContainReactText(children);
    });
  });
  describe('<MoneyLineContent />', function () {
    it('renders the children', function () {
      var children = 'children';
      var moneyLine = mountWithContext( /*#__PURE__*/React.createElement(MoneyLine, null, /*#__PURE__*/React.createElement(MoneyLineContent, null, children)));
      expect(moneyLine.find(MoneyLineContent)).toContainReactText(children);
    });
  });
});