import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../../../test-utilities';
import { Text } from '../../../Text';
import { MoneySummary, MoneySummaryContent, MoneySummaryHeader } from './MoneySummary';
describe('<MoneySummary />', function () {
  it('renders a label', function () {
    var label = faker.random.word();
    var moneySummary = mountWithContext( /*#__PURE__*/React.createElement(MoneySummary, {
      label: label,
      prefix: "prefix",
      value: "value"
    }));
    expect(moneySummary.find(MoneySummaryHeader)).toContainReactComponent(Text, {
      children: label
    });
  });
  it('renders a prefix', function () {
    var prefix = faker.random.word();
    var moneySummary = mountWithContext( /*#__PURE__*/React.createElement(MoneySummary, {
      label: "label",
      prefix: prefix,
      value: "value"
    }));
    expect(moneySummary.find(MoneySummaryContent)).toContainReactComponent(Text, {
      children: prefix
    });
  });
  it('renders a value', function () {
    var value = faker.random.word();
    var moneySummary = mountWithContext( /*#__PURE__*/React.createElement(MoneySummary, {
      label: "label",
      prefix: "prefix",
      value: value
    }));
    expect(moneySummary.find(MoneySummaryContent)).toContainReactComponent(Text, {
      children: value
    });
  });
  it('renders the children', function () {
    var moneySummary = mountWithContext( /*#__PURE__*/React.createElement(MoneySummary, null, /*#__PURE__*/React.createElement(MoneySummaryHeader, null), /*#__PURE__*/React.createElement(MoneySummaryContent, null)));
    expect(moneySummary).toContainReactComponent(MoneySummaryHeader);
    expect(moneySummary).toContainReactComponent(MoneySummaryContent);
  });
  describe('<MoneySummaryHeader />', function () {
    it('renders the children', function () {
      var children = 'children';
      var moneySummary = mountWithContext( /*#__PURE__*/React.createElement(MoneySummary, {
        label: "label",
        prefix: "prefix",
        value: "value"
      }, /*#__PURE__*/React.createElement(MoneySummaryHeader, null, children)));
      expect(moneySummary.find(MoneySummaryHeader)).toContainReactText(children);
    });
  });
  describe('<MoneySummaryContent />', function () {
    it('renders the children', function () {
      var children = 'children';
      var moneySummary = mountWithContext( /*#__PURE__*/React.createElement(MoneySummary, {
        label: "label",
        prefix: "prefix",
        value: "value"
      }, /*#__PURE__*/React.createElement(MoneySummaryContent, null, children)));
      expect(moneySummary.find(MoneySummaryContent)).toContainReactText(children);
    });
  });
});