import React, { useRef, useMemo } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { Heading } from '../Heading';
import { View } from '../View';
import { useThemeConfiguration } from '../Theme';
import { OptionListContext } from './context';
import styles from './OptionList.css';
export function OptionList(_ref) {
  var id = _ref.id,
      selectedItems = _ref.selectedItems,
      onChange = _ref.onChange,
      title = _ref.title,
      titleHidden = _ref.titleHidden,
      _ref$controlHidden = _ref.controlHidden,
      controlHidden = _ref$controlHidden === void 0 ? false : _ref$controlHidden,
      _ref$allowMultiple = _ref.allowMultiple,
      allowMultiple = _ref$allowMultiple === void 0 ? false : _ref$allowMultiple,
      children = _ref.children;
  var onChangeRef = useRef(onChange);
  onChangeRef.current = onChange;
  var contextValue = useMemo(function () {
    return {
      id: id,
      selectedItems: selectedItems,
      allowMultiple: allowMultiple,
      controlHidden: controlHidden,

      get onChange() {
        return onChangeRef.current;
      }

    };
  }, [allowMultiple, id, selectedItems, controlHidden]);
  var titleMarkup = title && (titleHidden ? /*#__PURE__*/React.createElement(View, {
    visibility: "hidden"
  }, /*#__PURE__*/React.createElement("legend", null, title)) : /*#__PURE__*/React.createElement("legend", {
    className: styles.Title
  }, /*#__PURE__*/React.createElement(Heading, {
    level: 3,
    role: "presentation"
  }, title)));

  var _useThemeConfiguratio = useThemeConfiguration(),
      controlsBackground = _useThemeConfiguratio.controls.background,
      _useThemeConfiguratio2 = _useThemeConfiguratio.optionList,
      optionListBackground = _useThemeConfiguratio2.background,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.spacing,
      spacing = _useThemeConfiguratio3 === void 0 ? 'none' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.border,
      border = _useThemeConfiguratio4 === void 0 ? 'full' : _useThemeConfiguratio4,
      _useThemeConfiguratio5 = _useThemeConfiguratio2.borderStyle,
      borderStyle = _useThemeConfiguratio5 === void 0 ? 'base' : _useThemeConfiguratio5;

  var background = optionListBackground || controlsBackground || 'surfaceTertiary';
  var className = classNames(styles.OptionList, styles[variationName('OptionList-background', background)], styles[variationName('OptionList-border', border)], styles[variationName('OptionList-borderStyle', borderStyle)], spacing === 'none' && styles.isContainer);
  return /*#__PURE__*/React.createElement(OptionListContext.Provider, {
    value: contextValue
  }, /*#__PURE__*/React.createElement("fieldset", null, titleMarkup, /*#__PURE__*/React.createElement("div", {
    className: className
  }, children)));
}