import { classNames, variationName } from '@shopify/css-utilities';
import React, { useCallback, useEffect, useRef } from 'react';
import { createIdCreator, useId } from '../../utilities/id';
import { isFocused, findFirstFocusableNode, findLastFocusableNode, findNextFocusableNode } from '../../utilities/focus';
import { Popper } from '../Popper';
import { useThemeConfiguration } from '../Theme';
import styles from './Popover.css';
var createId = createIdCreator('Popover');
export function Popover(_ref) {
  var children = _ref.children,
      activator = _ref.activator,
      open = _ref.open,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? 'inlineEnd' : _ref$placement,
      _ref$backdrop = _ref.backdrop,
      backdrop = _ref$backdrop === void 0 ? 'none' : _ref$backdrop,
      onClose = _ref.onClose;
  var popoverRef = useRef(null);

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.popover,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.connector,
      connector = _useThemeConfiguratio3 === void 0 ? 'arrow' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.depth,
      depth = _useThemeConfiguratio4 === void 0 ? 'far' : _useThemeConfiguratio4;

  var id = useId(undefined, createId);
  var setActivatorAccessibilityAttributes = useCallback(function () {
    activator === null || activator === void 0 ? void 0 : activator.setAttribute('aria-controls', id);
    activator === null || activator === void 0 ? void 0 : activator.setAttribute('aria-expanded', String(open));
  }, [activator === null || activator === void 0 ? void 0 : activator.setAttribute, id, open]);
  var handleClose = useCallback(function () {
    onClose === null || onClose === void 0 ? void 0 : onClose();
  }, [onClose]);
  var handleClickOutside = useCallback(function (event) {
    if (event.target instanceof Node && !(activator === null || activator === void 0 ? void 0 : activator.contains(event.target)) && open) {
      handleClose();
    }
  }, [activator === null || activator === void 0 ? void 0 : activator.contains, open, handleClose]);
  var handleKeyDown = useCallback(function (event) {
    if (!open) return;
    var nextFocusableNode = activator && findNextFocusableNode(activator);
    var firstFocusableNode = popoverRef.current && findFirstFocusableNode(popoverRef.current);
    var lastFocusableNode = popoverRef.current && findLastFocusableNode(popoverRef.current);

    switch (event.key) {
      case 'Escape':
      case 'Esc':
        handleClose();
        activator === null || activator === void 0 ? void 0 : activator.focus();
        break;

      case 'Tab':
        {
          if (isFocused(activator) && event.shiftKey) {
            handleClose();
          } else if (isFocused(activator)) {
            event.preventDefault();
            firstFocusableNode === null || firstFocusableNode === void 0 ? void 0 : firstFocusableNode.focus();
          } else if (isFocused(firstFocusableNode) && event.shiftKey) {
            event.preventDefault();
            activator === null || activator === void 0 ? void 0 : activator.focus();
            handleClose();
          } else if (isFocused(lastFocusableNode) && !event.shiftKey) {
            event.preventDefault();
            nextFocusableNode === null || nextFocusableNode === void 0 ? void 0 : nextFocusableNode.focus();
            handleClose();
          }

          break;
        }
    }
  }, [open, activator, handleClose, activator === null || activator === void 0 ? void 0 : activator.focus]);
  useEffect(function () {
    document.addEventListener('click', handleClickOutside);
    return function () {
      document.removeEventListener('click', handleClickOutside);
    };
  }, [handleClickOutside]);
  useEffect(function () {
    if (open) {
      document.addEventListener('keydown', handleKeyDown, false);
    }

    return function () {
      document.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [open, handleKeyDown]);
  useEffect(function () {
    setActivatorAccessibilityAttributes();
  });
  var popoverClassName = classNames(styles.Popover, styles[variationName('Popover-placement', placement)], styles[variationName('Popover-connector', connector)], styles[variationName('Popover-depth', depth)]);
  var contentClassName = classNames(styles.Content, styles[variationName('Content-placement', placement)]);
  var backdropClassName = classNames(styles.Backdrop, styles[variationName('Backdrop-style', backdrop)]);
  var offset = connector === 'arrow' ? 15 : 5;
  return open ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Popper, {
    activator: activator,
    placement: placement,
    offset: offset,
    preventOverflow: true
  }, /*#__PURE__*/React.createElement("div", {
    className: popoverClassName,
    id: id,
    ref: popoverRef
  }, /*#__PURE__*/React.createElement("div", {
    className: contentClassName
  }, children))), backdrop === 'translucent' ? /*#__PURE__*/React.createElement("div", {
    className: backdropClassName
  }) : null) : null;
}