import React from 'react';
import { classNames } from '@shopify/css-utilities';
import { Icon } from '../../../Icon';
import { TextBlock } from '../../../TextBlock';
import { View } from '../../../View';
import { useProgressTracker } from '../../hooks';
import styles from './ProgressTrackerStep.css';
export function ProgressTrackerStep(_ref) {
  var children = _ref.children,
      description = _ref.description,
      icon = _ref.icon,
      iconAppearance = _ref.iconAppearance,
      id = _ref.id,
      label = _ref.label,
      state = _ref.state,
      _ref$stateHidden = _ref.stateHidden,
      stateHidden = _ref$stateHidden === void 0 ? true : _ref$stateHidden;

  var _useProgressTracker = useProgressTracker(),
      steps = _useProgressTracker.steps;

  var first = Object.keys(steps).indexOf(id) === 0;
  var _steps$id = steps[id],
      active = _steps$id.active,
      completed = _steps$id.completed;
  var className = classNames(styles.ProgressTrackerStep, completed && styles.Completed);
  return /*#__PURE__*/React.createElement(React.Fragment, null, !first && /*#__PURE__*/React.createElement(ProgressTrackerStepConnector, {
    active: active,
    completed: completed
  }), /*#__PURE__*/React.createElement("li", {
    className: className,
    "aria-current": active
  }, /*#__PURE__*/React.createElement(ProgressTrackerStepIcon, {
    active: active,
    completed: completed,
    source: icon,
    appearance: iconAppearance
  }), /*#__PURE__*/React.createElement(ProgressTrackerStepLabel, {
    active: active,
    completed: completed,
    description: description,
    label: label,
    state: state,
    stateHidden: stateHidden
  }), children));
}
export function ProgressTrackerStepIcon(_ref2) {
  var active = _ref2.active,
      _ref2$appearance = _ref2.appearance,
      appearance = _ref2$appearance === void 0 ? 'info' : _ref2$appearance,
      source = _ref2.source,
      completed = _ref2.completed;
  var className = classNames(styles.ProgressTrackerStepIcon, active && styles.active, completed && styles.completed);
  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, /*#__PURE__*/React.createElement(Icon, {
    source: source,
    appearance: active || completed ? appearance : 'subdued',
    size: "large"
  }));
}
export function ProgressTrackerStepLabel(_ref3) {
  var active = _ref3.active,
      completed = _ref3.completed,
      description = _ref3.description,
      label = _ref3.label,
      state = _ref3.state,
      stateHidden = _ref3.stateHidden;
  var className = classNames(styles.ProgressTrackerStepLabel, (active || completed) && styles.completed);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: className
  }, stateHidden ? /*#__PURE__*/React.createElement(View, {
    visibility: "hidden"
  }, state) : /*#__PURE__*/React.createElement(TextBlock, null, state), /*#__PURE__*/React.createElement(TextBlock, {
    emphasized: active || completed
  }, label)), (active || completed) && description && /*#__PURE__*/React.createElement(TextBlock, {
    size: "small",
    subdued: true
  }, description));
}
export function ProgressTrackerStepConnector(_ref4) {
  var active = _ref4.active,
      completed = _ref4.completed;
  var className = classNames(styles.ProgressTrackerStepConnector, (active || completed) && styles.completed);
  return /*#__PURE__*/React.createElement("li", {
    className: className,
    "aria-hidden": true
  });
}