import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { Heading } from '../Heading';
import { HeadingGroup } from '../HeadingGroup';
import { Section, SectionContext } from './Section';
describe('<Section />', function () {
  it('renders its children', function () {
    var children = faker.random.words();
    var section = mountWithContext( /*#__PURE__*/React.createElement(Section, null, children));
    expect(section).toContainReactText(children);
  });
  it('wraps children with SectionContext of level 1', function () {
    var section = mountWithContext( /*#__PURE__*/React.createElement(Section, null));
    expect(section).toProvideReactContext(SectionContext, {
      level: 1
    });
  });
  it('renders the Heading not wrapped in a HeadingGroup', function () {
    var heading = faker.random.words();
    var section = mountWithContext( /*#__PURE__*/React.createElement(Section, null, /*#__PURE__*/React.createElement(Heading, null, heading)));
    expect(section).not.toContainReactComponent(HeadingGroup);
    expect(section).toContainReactComponent(Heading, {
      children: heading
    });
  });
  describe('nested <Section />', function () {
    it('renders the Heading wrapped in a HeadingGroup', function () {
      var heading = faker.random.words();
      var section = mountWithContext( /*#__PURE__*/React.createElement(Section, null, /*#__PURE__*/React.createElement(Section, null, /*#__PURE__*/React.createElement(Heading, null, heading))));
      expect(section.find(HeadingGroup)).toContainReactComponent(Heading, {
        children: heading
      });
    });
    it('wraps the nested Section children with SectionContext of level 2', function () {
      var children = faker.random.words();
      var section = mountWithContext( /*#__PURE__*/React.createElement(Section, null, /*#__PURE__*/React.createElement(Section, null, /*#__PURE__*/React.createElement(Heading, null, children))));
      expect(section.find(Section)).toProvideReactContext(SectionContext, {
        level: 2
      });
    });
  });
});