function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useEffect, useState, useCallback, useRef } from 'react';
import { classNames } from '@shopify/css-utilities';
import { useTranslate } from '../AppContext';
import { useThemeConfiguration } from '../Theme';
import { BlockStack } from '../BlockStack';
import { TextFieldInternal } from '../TextField';
import { Icon } from '../Icon';
import { InlineError } from '../InlineError';
import { createIdCreator, useId } from '../../utilities/id';
import styles from './Stepper.css';
var createId = createIdCreator('StepperField');

var SpinButtons = function SpinButtons(_ref) {
  var handleButtonPress = _ref.handleButtonPress,
      handleTap = _ref.handleTap,
      minReached = _ref.minReached,
      maxReached = _ref.maxReached,
      separator = _ref.separator;
  var translate = useTranslate();
  return /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.SpinButtonGroup),
    role: "group"
  }, /*#__PURE__*/React.createElement("button", {
    type: "button",
    "aria-label": translate('decrement') || 'Decrement',
    onTouchStart: function onTouchStart() {
      return handleTap(-1);
    },
    onMouseDown: function onMouseDown(evt) {
      return handleButtonPress(evt, -1);
    },
    className: classNames(styles.SpinButton),
    disabled: minReached,
    tabIndex: -1
  }, /*#__PURE__*/React.createElement(Icon, {
    source: "minus",
    size: "base"
  })), separator && /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.SpinButtonSeparator)
  }), /*#__PURE__*/React.createElement("button", {
    type: "button",
    "aria-label": translate('increment') || 'Increment',
    onTouchStart: function onTouchStart() {
      return handleTap(1);
    },
    onMouseDown: function onMouseDown(evt) {
      return handleButtonPress(evt, 1);
    },
    className: classNames(styles.SpinButton),
    disabled: maxReached,
    tabIndex: -1
  }, /*#__PURE__*/React.createElement(Icon, {
    source: "plus",
    size: "base"
  })));
};

export function Stepper(_ref2) {
  var accessibilityDescription = _ref2.accessibilityDescription,
      disabled = _ref2.disabled,
      label = _ref2.label,
      error = _ref2.error,
      name = _ref2.name,
      _ref2$min = _ref2.min,
      min = _ref2$min === void 0 ? 0 : _ref2$min,
      max = _ref2.max,
      value = _ref2.value,
      _ref2$step = _ref2.step,
      step = _ref2$step === void 0 ? 1 : _ref2$step,
      explicitId = _ref2.id,
      required = _ref2.required,
      _onChange = _ref2.onChange,
      onBlur = _ref2.onBlur,
      onFocus = _ref2.onFocus,
      readonly = _ref2.readonly;

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.stepper.separator,
      separator = _useThemeConfiguratio2 === void 0 ? true : _useThemeConfiguratio2;

  var _useState = useState(value),
      _useState2 = _slicedToArray(_useState, 2),
      quantity = _useState2[0],
      setQuantity = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      spinning = _useState4[0],
      setSpinning = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      minReached = _useState6[0],
      setMinReached = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      maxReached = _useState8[0],
      setMaxReached = _useState8[1];

  var buttonPressTimer = useRef();
  var id = useId(explicitId, createId);
  useEffect(function () {
    setQuantity(Number(value));
  }, [value]);
  useEffect(function () {
    setMinReached(function () {
      return quantity !== undefined && min !== undefined && quantity <= min;
    });
  }, [quantity, min]);
  useEffect(function () {
    setMaxReached(function () {
      return quantity !== undefined && max !== undefined && quantity >= max;
    });
  }, [quantity, max]); // because we do not register value changes until the blur, we need to manually handle disabling/enabling spin buttons onInput

  var handleMinOrMaxReached = function handleMinOrMaxReached(value) {
    var numVal = Number(value);
    if (numVal <= min) setMinReached(true);
    if (max !== undefined && numVal >= max) setMaxReached(true);
    if (numVal > min) setMinReached(false);
    if (max !== undefined && numVal < max) setMaxReached(false);
  };

  var errorMarkup = error && /*#__PURE__*/React.createElement(InlineError, {
    controlID: id
  }, error);
  var calculateQuantity = useCallback(function (_ref3) {
    var factor = _ref3.factor,
        prevQuantity = _ref3.prevQuantity,
        max = _ref3.max,
        min = _ref3.min,
        step = _ref3.step;
    var normalizedMax = max === undefined ? Infinity : max;
    var normalizedMin = min === undefined ? -Infinity : min;
    var quantity = prevQuantity ? prevQuantity : 0;

    if (isNaN(quantity)) {
      return 0;
    } // Returns the length of decimal places in a number


    var decimalLength = function decimalLength(num) {
      return (num.toString().split('.')[1] || []).length;
    }; // Making sure the new value has the same length of decimal places as the
    // step / value has.


    var decimalPlaces = Math.max(decimalLength(quantity), decimalLength(step));
    var newQuantity = Math.min(Number(normalizedMax), Math.max(quantity + factor * step, Number(normalizedMin)));
    return parseFloat(newQuantity.toFixed(decimalPlaces));
  }, []);
  var handleLocalQuantityChange = useCallback(function (factor) {
    setQuantity(function (prevQuantity) {
      return calculateQuantity({
        factor: factor,
        prevQuantity: prevQuantity,
        max: max,
        min: min,
        step: step
      });
    });
  }, [step, max, min, calculateQuantity]);
  var handleTap = useCallback(function (factor) {
    setQuantity(function (prevQuantity) {
      var val = calculateQuantity({
        factor: factor,
        prevQuantity: prevQuantity,
        max: max,
        min: min,
        step: step
      });
      _onChange === null || _onChange === void 0 ? void 0 : _onChange("".concat(val));
      return val;
    });
  }, [step, max, min, calculateQuantity, _onChange]);
  /* this mimics native spinner press and hold
   * and is lifted from polaris-react
   * https://github.com/Shopify/polaris-react/blob/main/src/components/TextField/TextField.tsx#L320-L346
   **/

  var handleButtonRelease = useCallback(function () {
    clearTimeout(buttonPressTimer.current);
    setSpinning(false);
    setQuantity(function (newQuantity) {
      if (newQuantity !== undefined) {
        _onChange === null || _onChange === void 0 ? void 0 : _onChange("".concat(newQuantity));
      }

      return newQuantity === undefined ? quantity : newQuantity;
    });
  }, [_onChange, quantity]);
  var handleButtonPress = useCallback(function (evt, factor) {
    // only increment/decrement if it's left click
    if ((evt === null || evt === void 0 ? void 0 : evt.button) !== 0) return; // if somehow spinning already stop it

    if (spinning) {
      handleButtonRelease();
      return;
    }

    var minInterval = 50;
    var decrementBy = 10;
    var interval = 200;

    var onChangeInterval = function onChangeInterval() {
      if (!spinning) setSpinning(true);
      if (interval > minInterval) interval -= decrementBy;
      handleLocalQuantityChange(factor);
      buttonPressTimer.current = window.setTimeout(onChangeInterval, interval);
    };

    buttonPressTimer.current = window.setTimeout(onChangeInterval, 0);
    document.addEventListener('mouseup', handleButtonRelease, {
      once: true
    });
    return function () {
      document.removeEventListener('mouseup', handleButtonRelease);
    };
  }, [handleButtonRelease, handleLocalQuantityChange, spinning]);
  return /*#__PURE__*/React.createElement(BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/React.createElement(TextFieldInternal, {
    accessibilityDescription: accessibilityDescription,
    "aria-required": required,
    disabled: disabled,
    error: Boolean(error),
    id: id,
    label: label,
    max: max,
    min: min,
    name: name,
    readonly: readonly,
    required: required,
    step: step,
    type: "number",
    value: quantity === undefined ? '' : "".concat(quantity),
    onInput: handleMinOrMaxReached,
    onChange: function onChange(value) {
      setQuantity(Number(value));
      _onChange === null || _onChange === void 0 ? void 0 : _onChange(value);
    },
    onBlur: onBlur,
    onFocus: onFocus
  }, !disabled && !readonly && /*#__PURE__*/React.createElement(SpinButtons, {
    handleButtonPress: handleButtonPress,
    handleTap: handleTap,
    maxReached: maxReached,
    minReached: minReached,
    separator: separator
  })), errorMarkup);
}