import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Tabs } from './Tabs';
describe('<Tabs />', function () {
  describe('selected', function () {
    it('selects the corresponding tab and panel', function () {
      var index = 1;
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2'],
        selected: index,
        onChange: jest.fn(),
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2")));
      var buttons = tabs.findAll('button');
      var panels = tabs.findAll('div', {
        role: 'tabpanel'
      }) || [];
      expect(buttons[index].prop('aria-selected')).toBe(true);
      expect(panels[index].prop('hidden')).toBe(false);
      expect(buttons[0].prop('aria-selected')).toBe(false);
      expect(panels[0].prop('hidden')).toBe(true);
    });
  });
  describe('onChange', function () {
    it('is called with the corresponding index', function () {
      var _tabs$find;

      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2'],
        selected: 1,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2")));
      (_tabs$find = tabs.find('button')) === null || _tabs$find === void 0 ? void 0 : _tabs$find.trigger('onClick');
      expect(onChangeSpy).toHaveBeenCalledWith(0);
    });
  });
  describe('keyboard events', function () {
    it('"Right" selects the next tab', function () {
      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2', 'Tab 3'],
        selected: 0,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 3")));
      keydown(tabs, 'Right');
      expect(onChangeSpy).toHaveBeenCalledWith(1);
    });
    it('"Right" wraps to the first tab if on the last tab', function () {
      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2', 'Tab 3'],
        selected: 2,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 3")));
      keydown(tabs, 'Right');
      expect(onChangeSpy).toHaveBeenCalledWith(0);
    });
    it('"Left" selects the prev tab', function () {
      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2', 'Tab 3'],
        selected: 1,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 3")));
      keydown(tabs, 'Left');
      expect(onChangeSpy).toHaveBeenCalledWith(0);
    });
    it('"Left" wraps to the last tab if on the first tab', function () {
      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2', 'Tab 3'],
        selected: 0,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 3")));
      keydown(tabs, 'Left');
      expect(onChangeSpy).toHaveBeenCalledWith(2);
    });
    it('"Home" selects the first tab', function () {
      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2', 'Tab 3'],
        selected: 2,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 3")));
      keydown(tabs, 'Home');
      expect(onChangeSpy).toHaveBeenCalledWith(0);
    });
    it('"End" selects the last tab', function () {
      var onChangeSpy = jest.fn();
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: ['Tab 1', 'Tab 2', 'Tab 3'],
        selected: 0,
        onChange: onChangeSpy,
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 2"), /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 3")));
      keydown(tabs, 'End');
      expect(onChangeSpy).toHaveBeenCalledWith(2);
    });
  });
  describe('<Tab />', function () {
    it('`icon` is rendered', function () {
      var tabs = mountWithContext( /*#__PURE__*/React.createElement(Tabs, {
        tabs: [{
          label: 'Tab 1',
          icon: 'truck'
        }],
        selected: 0,
        onChange: jest.fn(),
        ariaLabel: "Tabs test"
      }, /*#__PURE__*/React.createElement(React.Fragment, null, "Content for tab 1")));
      expect(tabs).toContainReactComponent(Icon, {
        source: 'truck'
      });
    });
  });
});

function keydown(tabs, event) {
  var _tabs$find2;

  var tabList = (_tabs$find2 = tabs.find('div', {
    role: 'tablist'
  })) === null || _tabs$find2 === void 0 ? void 0 : _tabs$find2.domNode;
  tabs.act(function () {
    return tabList.dispatchEvent(new KeyboardEvent('keydown', {
      key: event
    }));
  });
}