import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Text } from '../Text';
import { Tag } from './Tag';
describe('<Tag />', function () {
  it('renders a basic tag without close icon', function () {
    var str = faker.random.word();
    var tag = mountWithContext( /*#__PURE__*/React.createElement(Tag, null, /*#__PURE__*/React.createElement(Text, null, str)));
    expect(tag).toContainReactComponent(Text, {
      children: str
    });
    expect(tag).not.toContainReactComponent(Icon, {
      source: 'close'
    });
    expect(tag.findAll(Icon)).toHaveLength(0);
  });
  it('renders a tag with a close icon if there is an onRemove method', function () {
    var str = faker.random.word();
    var onRemove = jest.fn();
    var tag = mountWithContext( /*#__PURE__*/React.createElement(Tag, {
      onRemove: onRemove
    }, /*#__PURE__*/React.createElement(Text, null, str)));
    expect(tag).toContainReactComponent(Icon, {
      source: 'close'
    });
  });
  it('calls onRemove when button is clicked', function () {
    var str = faker.random.word();
    var onRemove = jest.fn();
    var tag = mountWithContext( /*#__PURE__*/React.createElement(Tag, {
      onRemove: onRemove
    }, /*#__PURE__*/React.createElement(Text, null, str)));
    tag.find('button').trigger('onClick');
    expect(onRemove).toHaveBeenCalled();
  });
  it('renders a tag with an icon if there is an icon prop', function () {
    var str = faker.random.word();
    var icon = 'delivered';
    var tag = mountWithContext( /*#__PURE__*/React.createElement(Tag, {
      icon: icon
    }, /*#__PURE__*/React.createElement(Text, null, str)));
    expect(tag).toContainReactComponent(Icon, {
      source: 'delivered'
    });
    expect(tag.findAll(Icon)).toHaveLength(1);
  });
});