import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import faker from 'faker';
import { View } from './View';
describe('<View />', function () {
  describe('children', function () {
    it('renders its children', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, null, text, " "));
      expect(view).toContainReactText(text);
    });
  });
  describe('id', function () {
    it('sets id when id is set', function () {
      var id = faker.random.uuid();
      var view = mount( /*#__PURE__*/React.createElement(View, {
        id: id
      }));
      expect(view).toContainReactComponent('div', {
        id: id
      });
    });
  });
  describe('role', function () {
    it('renders a div by default', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, null, text, " "));
      expect(view).toContainReactComponent('div');
    });
    it('renders a section when "region" is set', function () {
      var view = mount( /*#__PURE__*/React.createElement(View, {
        role: "region"
      }));
      expect(view).toContainReactComponent('section');
    });
    it('renders an aside when "complimentary" is set', function () {
      var view = mount( /*#__PURE__*/React.createElement(View, {
        role: "complementary"
      }));
      expect(view).toContainReactComponent('aside');
    });
  });
  describe('accessibilityVisibility', function () {
    it('sets aria-hidden to true when accessibilityVisibility is set', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, {
        accessibilityVisibility: "hidden"
      }, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': true
      });
    });
    it('does not set aria-hidden when accessibilityVisibility is not set', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, null, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': undefined
      });
    });
  });
  describe('accessibilityLabel', function () {
    it('sets aria-label with accessibilityLabel if role is set', function () {
      var text = faker.random.words();
      var view = mount( /*#__PURE__*/React.createElement(View, {
        accessibilityLabel: text,
        role: "region"
      }));
      expect(view).toContainReactComponent('section', {
        'aria-label': text
      });
    });
    it('does not set aria-label if role is not set', function () {
      var text = faker.random.words();
      var view = mount( /*#__PURE__*/React.createElement(View, {
        accessibilityLabel: text
      }));
      expect(view).not.toContainReactComponent('div', {
        'aria-label': text
      });
    });
  });
});