"use strict";

var _react = _interopRequireWildcard(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _TextField = require("../TextField");

var _Labelled = require("../Labelled");

var _Autocomplete = require("./Autocomplete");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

jest.mock('../../utilities/focus', () => ({
  isFocused: jest.fn()
}));
const {
  isFocused
} = jest.requireMock('../../utilities/focus');
const defaultProps = {
  id: 'address',
  label: 'Address',
  name: 'address',
  options: ['address 1', 'address 2'],
  value: '',
  title: 'Suggestions',
  ariaLabel: 'Close Predictions'
};

const autocompleteOptions = options => {
  return /*#__PURE__*/_react.default.createElement(_Autocomplete.AutocompleteOptions, null, options && options.map(option => /*#__PURE__*/_react.default.createElement(_Autocomplete.AutocompleteOption, {
    key: option
  }, option)));
};

describe('<Autocomplete />', () => {
  beforeEach(() => {
    isFocused.mockReset();
    isFocused.mockImplementation(() => true);
  });
  describe('<Labelled />', () => {
    it('renders a <Labelled />', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_Labelled.Labelled);
    });
  });
  describe('<Field />', () => {
    it('renders a <Field />', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        id: 'address'
      });
    });
    it('renders a disabled <Field /> when the disabled prop is true', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        disabled: true,
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        disabled: true
      });
    });
    it('renders a readonly <Field /> when the readonly prop is true', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        readonly: true,
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        readonly: true
      });
    });
    it('sets the default aria-controls and aria-expanded properties', () => {
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      })));
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        id: 'address',
        ariaControls: 'address-options',
        ariaExpanded: false
      });
    });
    it('sets the aria-controls, aria-activedescendant and aria-expanded when the input is focused', () => {
      var _autocomplete$find;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps));
      (_autocomplete$find = autocomplete.find(_TextField.Field)) === null || _autocomplete$find === void 0 ? void 0 : _autocomplete$find.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(_TextField.Field, {
        id: 'address',
        ariaControls: 'address-options',
        ariaActiveDescendant: 'address-option-0',
        ariaExpanded: true
      });
    });
    it('calls the onChange callback when the Field onChange is called', () => {
      var _autocomplete$find2;

      const onChangeSpy = jest.fn();
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      })));
      (_autocomplete$find2 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find2 === void 0 ? void 0 : _autocomplete$find2.trigger('onChange', 'address');
      expect(onChangeSpy.mock.calls).toMatchObject([['address']]);
      expect(onChangeSpy).toHaveBeenCalledTimes(1);
    });
    it('calls the onChange callback when the enter key is pressed and AutocompleteOptions is closed', () => {
      const onChangeSpy = jest.fn();
      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      })));

      const value = _faker.default.random.alphaNumeric();

      autocomplete.find('input').trigger('oninput', {
        currentTarget: {
          value
        }
      });
      autocomplete.find('input').trigger('onKeyDown', {
        key: 'Escape'
      });
      autocomplete.find('input').trigger('onKeyDown', {
        key: 'Enter',
        currentTarget: {
          value
        }
      });
      expect(onChangeSpy).toHaveBeenCalledWith(value);
    });
  });
  describe('<AutocompleteOptions />', () => {
    it('renders when the input is focused', () => {
      var _autocomplete$find3;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find3 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find3 === void 0 ? void 0 : _autocomplete$find3.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(_Autocomplete.AutocompleteOptions, {
        children: expect.any(Array)
      });
    });
    it("doesn't render when no options", () => {
      var _autocomplete$find4;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
        options: []
      }), autocompleteOptions(defaultProps.options)));
      (_autocomplete$find4 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find4 === void 0 ? void 0 : _autocomplete$find4.trigger('onFocus');
      expect(autocomplete).not.toContainReactComponent(_Autocomplete.AutocompleteOptions);
    });
    it('renders when the options change', () => {
      var _options$find;

      function Options() {
        const [options, setOptions] = (0, _react.useState)([]);

        const search = () => {
          setOptions(['address 1', 'address 2']);
        };

        return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, Object.assign({}, defaultProps, {
          options: options
        }), autocompleteOptions(defaultProps.options)), /*#__PURE__*/_react.default.createElement("button", {
          onClick: search
        }));
      }

      const options = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Options, null));
      expect(options).not.toContainReactComponent(_Autocomplete.AutocompleteOptions);
      (_options$find = options.find('button')) === null || _options$find === void 0 ? void 0 : _options$find.trigger('onClick');
      expect(options).toContainReactComponent(_Autocomplete.AutocompleteOptions, {
        children: expect.any(Array)
      });
    });
    it("doesn't render when the value is empty", () => {
      var _autocomplete$find5;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find5 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find5 === void 0 ? void 0 : _autocomplete$find5.trigger('onInput', '');
      expect(autocomplete).not.toContainReactComponent(_Autocomplete.AutocompleteOptions);
    });
    it('renders an <ul> with unique id', () => {
      var _autocomplete$find6;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find6 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find6 === void 0 ? void 0 : _autocomplete$find6.trigger('onFocus');
      expect(autocomplete).toContainReactComponent('ul', {
        id: 'address-options'
      });
    });
    it('hides when the close button is clicked', () => {
      var _autocomplete$find7, _autocomplete$find8;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find7 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find7 === void 0 ? void 0 : _autocomplete$find7.trigger('onFocus');
      (_autocomplete$find8 = autocomplete.find('button')) === null || _autocomplete$find8 === void 0 ? void 0 : _autocomplete$find8.trigger('onClick');
      expect(autocomplete).not.toContainReactComponent(_Autocomplete.AutocompleteOptions);
    });
  });
  describe('<AutocompleteOption />', () => {
    it('selects the first option when focus is on field', () => {
      var _autocomplete$find9;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find9 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find9 === void 0 ? void 0 : _autocomplete$find9.trigger('onFocus');
      const [firstOption, secondOption] = autocomplete.findAll(_Autocomplete.AutocompleteOption);
      expect(firstOption.prop('isSelected')).toStrictEqual(true);
      expect(secondOption.prop('isSelected')).toStrictEqual(false);
    });
    it('renders a <li> with unique id', () => {
      var _autocomplete$find10;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, autocompleteOptions(defaultProps.options)));
      (_autocomplete$find10 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find10 === void 0 ? void 0 : _autocomplete$find10.trigger('onFocus');
      const [firstOption, secondOption] = autocomplete.findAll(_Autocomplete.AutocompleteOption);
      expect(firstOption).toContainReactComponent('li', {
        id: 'address-option-0'
      });
      expect(secondOption).toContainReactComponent('li', {
        id: 'address-option-1'
      });
    });
  });
  describe('<AutocompleteFooter />', () => {
    it('renders when the input is focused', () => {
      var _autocomplete$find11;

      const autocomplete = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Autocomplete.Autocomplete, defaultProps, /*#__PURE__*/_react.default.createElement(_Autocomplete.AutocompleteFooter, null, "This is a test footer"), ";"));
      (_autocomplete$find11 = autocomplete.find(_TextField.Field)) === null || _autocomplete$find11 === void 0 ? void 0 : _autocomplete$find11.trigger('onFocus');
      expect(autocomplete).toContainReactComponent(_Autocomplete.AutocompleteFooter, {
        children: 'This is a test footer'
      });
    });
  });
});