"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _Text = require("../Text");

var _Bookend = require("../Bookend");

var _Banner = require("./Banner");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  title: 'There was an error'
};
describe('<Banner />', () => {
  describe('children', () => {
    it('renders the children', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, defaultProps, /*#__PURE__*/_react.default.createElement(_Text.Text, null, "Hello")));
      expect(banner).toContainReactComponent(_Text.Text);
      expect(banner).toContainReactComponent(_Bookend.Bookend, {
        trailing: false
      });
    });
  });
  describe('title', () => {
    it('renders the title', () => {
      const title = 'There was an error.';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, {
        title: title
      }));
      expect(banner).toContainReactText(title);
    });
  });
  describe('status', () => {
    it('renders the info <Icon /> by default', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, defaultProps));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: 'info'
      });
    });
    it('renders the success <Icon /> if status is success', () => {
      const status = 'success';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: status
      });
    });
    it('renders the warning <Icon /> if status is warning', () => {
      const status = 'warning';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: status
      });
    });
    it('renders the critical <Icon /> if status is critical', () => {
      const status = 'critical';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: status
      });
    });
    it('sets the status live region role by default', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, defaultProps));
      expect(banner).toContainReactComponent('div', {
        role: 'status'
      });
    });
    it('sets the alert live region role if status is critical', () => {
      const status = 'critical';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent('div', {
        role: 'alert'
      });
    });
  });
  describe('collapsible', () => {
    it('renders a chevronDown button with the required aria attributes if collapsible', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      expect(banner).toContainReactComponent('button', {
        'aria-pressed': false,
        'aria-expanded': false
      });
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: 'chevronDown'
      });
      expect(banner).toContainReactComponent(_Bookend.Bookend, {
        trailing: true
      });
    });
    it('hides the children if collapsible', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/_react.default.createElement(_Text.Text, null, "Hello")));
      expect(banner).not.toContainReactComponent(_Text.Text);
    });
    it('renders a chevronUp button with the required aria attributes icon on button click if collapsible', () => {
      var _banner$find;

      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      (_banner$find = banner.find('button')) === null || _banner$find === void 0 ? void 0 : _banner$find.trigger('onClick');
      expect(banner).toContainReactComponent('button', {
        'aria-pressed': true,
        'aria-expanded': true
      });
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: 'chevronUp'
      });
      expect(banner).toContainReactComponent(_Bookend.Bookend, {
        trailing: true
      });
    });
    it('renders the children on button click if collapsible', () => {
      var _banner$find2;

      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/_react.default.createElement(_Text.Text, null, "Hello")));
      (_banner$find2 = banner.find('button')) === null || _banner$find2 === void 0 ? void 0 : _banner$find2.trigger('onClick');
      expect(banner).toContainReactComponent(_Text.Text);
    });
  });
  describe('iconHidden', () => {
    it('renders the <Icon /> by default', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, defaultProps));
      expect(banner).toContainReactComponent(_Icon.Icon);
      expect(banner).toContainReactComponent(_Bookend.Bookend, {
        leading: true
      });
    });
    it('does not render the <Icon /> if iconHidden', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        iconHidden: true
      })));
      expect(banner).not.toContainReactComponent(_Icon.Icon);
      expect(banner).toContainReactComponent(_Bookend.Bookend, {
        leading: false
      });
    });
  });
  describe('autofocus', () => {
    const rawCreateElement = document.createElement;
    const focusSpy = jest.fn();
    const createElementSpy = jest.spyOn(document, 'createElement');
    beforeEach(() => {
      createElementSpy.mockImplementation((...args) => {
        const result = rawCreateElement.apply(document, args);

        if (args[0].toLocaleLowerCase() === 'div') {
          result.focus = focusSpy;
        }

        return result;
      });
    });
    afterEach(() => {
      focusSpy.mockReset();
    });
    afterAll(() => {
      createElementSpy.mockRestore();
    });
    it('does not focus the banner by default', () => {
      (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, defaultProps));
      expect(focusSpy).not.toHaveBeenCalled();
    });
    it('focuses on the banner when autofocus is specified', () => {
      (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        autofocus: true
      })));
      expect(focusSpy).toHaveBeenCalledTimes(1);
    });
    it('sets the tabIndex to -1', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        autofocus: true
      })));
      expect(banner).toContainReactComponent('div', {
        tabIndex: -1
      });
    });
  });
  describe('onDismiss()', () => {
    it('is called when the dismiss button is clicked', () => {
      var _banner$find3;

      const spy = jest.fn();
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, {
        onDismiss: spy
      }));
      (_banner$find3 = banner.find('button')) === null || _banner$find3 === void 0 ? void 0 : _banner$find3.trigger('onClick');
      expect(spy).toHaveBeenCalled();
    });
    it('renders a close button', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({
        onDismiss: () => {}
      }, defaultProps)));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: 'close'
      });
      expect(banner).toContainReactComponent(_Icon.Icon);
      expect(banner).toContainReactComponent(_Bookend.Bookend, {
        leading: true
      });
    });
  });
});