"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Breadcrumbs = Breadcrumbs;
exports.Marker = Marker;

var _react = _interopRequireDefault(require("react"));

var _Icon = require("../Icon");

var _Text = require("../Text");

var _Theme = require("../Theme");

var _ = require("..");

var _Breadcrumbs = _interopRequireDefault(require("./Breadcrumbs.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable jsx-a11y/no-redundant-roles */
const NUMBER_STYLE_MAP = {
  none: () => null,
  decimal: index => /*#__PURE__*/_react.default.createElement(Marker, null, index.toString()),
  decimalLeadingZero: index => /*#__PURE__*/_react.default.createElement(Marker, null, index.toString().padStart(2, '0'))
};

function Breadcrumbs({
  active,
  breadcrumbs
}) {
  const {
    buyerJourney: {
      numberStyle = 'none',
      chevronIconSeparator = true,
      typographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  return (
    /*#__PURE__*/
    // eslint-disable-next-line @shopify/jsx-no-hardcoded-content
    _react.default.createElement("nav", {
      "aria-label": "Breadcrumbs"
    }, /*#__PURE__*/_react.default.createElement("ol", {
      className: _Breadcrumbs.default.Breadcrumbs,
      role: "list"
    }, breadcrumbs.map(({
      id,
      to,
      disabled,
      content
    }, index) => {
      const showSeparator = breadcrumbs.length !== index + 1;
      const isActive = active === id;
      const isClickable = !isActive && !disabled;
      const ariaCurrent = isActive ? 'step' : false;
      const marker = NUMBER_STYLE_MAP[numberStyle](index + 1);
      const breadcrumbContent = isClickable ? /*#__PURE__*/_react.default.createElement(_Text.Text, {
        size: "small",
        style: typographyStyle
      }, /*#__PURE__*/_react.default.createElement(_.Link, {
        to: to
      }, marker, content)) : /*#__PURE__*/_react.default.createElement(_Text.Text, {
        emphasized: isActive,
        subdued: !isActive,
        size: "small",
        style: typographyStyle
      }, marker, content);
      return /*#__PURE__*/_react.default.createElement("li", {
        className: _Breadcrumbs.default.Item,
        key: id,
        "aria-current": ariaCurrent
      }, breadcrumbContent, showSeparator && /*#__PURE__*/_react.default.createElement("span", {
        className: _Breadcrumbs.default.Separator
      }, chevronIconSeparator && /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
        source: "chevronRight",
        size: "small",
        appearance: "subdued"
      })));
    })))
  );
}

function Marker({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("span", {
    className: _Breadcrumbs.default.Marker
  }, children);
}