"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Button = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _forms = require("../../utilities/forms");

var _AppContext = require("../AppContext");

var _transition = require("../../utilities/transition");

var _Spinner = require("../Spinner");

var _Link = require("../Link");

var _legacy = require("../../utilities/legacy");

var _mediaQuery = require("../../utilities/media-query");

var _Connected = require("../Connected");

var _Theme = require("../Theme");

var _responsive = require("../../utilities/responsive");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Button = _interopRequireDefault(require("./Button.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Button = /*#__PURE__*/(0, _react.forwardRef)(function Button({
  children,
  kind = 'primary',
  submit = false,
  disabled,
  onPress,
  to,
  loading = false,
  loadingLabel,
  accessibilityLabel,
  fill = false,
  appearance,
  onMouseEnter,
  size = 'base'
}, ref) {
  const href = disabled ? undefined : to;
  const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
  const refsSetter = (0, _react.useCallback)(instance => {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }
  }, [ref]);
  const translate = (0, _AppContext.useTranslate)();
  const prefersReducedMotion = (0, _mediaQuery.usePrefersReducedMotion)();
  const transition = (0, _transition.useTransition)(loading, {
    enter: 'slow'
  });
  const connected = (0, _Connected.useConnected)();
  const responsiveSizes = (0, _responsive.useResponsive)({
    size
  });
  const {
    primaryButton: {
      style: primaryStyle = 'fill',
      border: primaryBorder = 'none',
      typographyStyle: primaryTypographyStyle,
      loadingStyle: primaryLoading = 'spinner'
    },
    secondaryButton: {
      style: secondaryStyle = 'inverse',
      border: secondaryBorder = 'full',
      typographyStyle: secondaryTypographyStyle,
      loadingStyle: secondaryLoading = 'spinner'
    },
    link: {
      colorHovered: plainColorHovered,
      typographyStyle: linkTypographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const form = (0, _forms.useContainingForm)();
  const isSecondary = kind === 'secondary';
  const style = isSecondary ? secondaryStyle : primaryStyle;
  const border = isSecondary ? secondaryBorder : primaryBorder;
  const typographyStyle = isSecondary ? secondaryTypographyStyle : primaryTypographyStyle;
  const loadingStyle = isSecondary ? secondaryLoading : primaryLoading;
  const isPlain = kind === 'plain' || style === 'plain';
  const classes = (0, _cssUtilities.classNames)(_Button.default.Button, kind && !isPlain && _Button.default[(0, _cssUtilities.variationName)('kind', kind)], responsiveSizes && !isPlain && responsiveSizes.map(className => _Button.default[className]), border && !isPlain && _Button.default[(0, _cssUtilities.variationName)('border', border)], style && !isPlain && _Button.default[(0, _cssUtilities.variationName)('style', style)], appearance && _Button.default[(0, _cssUtilities.variationName)('appearance', appearance)], isPlain && _Button.default.stylePlain, isPlain && plainColorHovered && _Button.default[(0, _cssUtilities.variationName)('stylePlainColorHovered', plainColorHovered)], fill && _Button.default.fill, disabled && _Button.default.disabled, loading && _Button.default[(0, _cssUtilities.variationName)('loading', loadingStyle)], loading && loadingStyle === 'spinner' && _Button.default[(0, _cssUtilities.variationName)('loading-transition', transition)], !isPlain && typographyStyle && _typographyStyles.default[typographyStyle], isPlain && linkTypographyStyle && _typographyStyles.default[linkTypographyStyle], connected && _Button.default.connected,
  /* Basic theming for older browsers that do not support CSS Custom Properties: */
  _legacy.button, kind === 'primary' && _legacy.buttonPrimary, kind === 'secondary' && _legacy.buttonSecondary, appearance === 'critical' && _legacy.buttonCritical, kind === 'plain' && appearance === 'critical' && _legacy.colorCriticalAccent);
  const normalizedLoadingLabel = loadingLabel ? loadingLabel : translate('processing');
  const contentClassNames = (0, _cssUtilities.classNames)(_Button.default.Content);

  const content = /*#__PURE__*/_react.default.createElement("span", {
    className: contentClassNames
  }, loading && loadingStyle === 'progressBar' && prefersReducedMotion ? normalizedLoadingLabel : children);

  const type = submit ? 'submit' : 'button';
  const loadingMarkup = loadingStyle === 'spinner' ? /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _cssUtilities.classNames)(_Button.default.LoadingContent, !prefersReducedMotion && _Button.default.Spinner)
  }, /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
    size: "small",
    color: "inherit",
    accessibilityLabel: normalizedLoadingLabel
  })) : /*#__PURE__*/_react.default.createElement("span", {
    className: _Button.default.ProgressBar
  });

  if (href) {
    return /*#__PURE__*/_react.default.createElement(_Link.UnstyledLink, {
      to: href,
      className: classes,
      onPress: onPress,
      ariaBusy: loading,
      ariaLive: loading ? 'assertive' : 'polite',
      ariaLabel: accessibilityLabel
    }, content, loading && loadingMarkup);
  }

  return /*#__PURE__*/_react.default.createElement("button", {
    type: type,
    form: submit && (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined,
    className: classes,
    disabled: disabled || loading,
    onClick: onClick,
    "aria-busy": loading || undefined,
    "aria-live": loading ? 'assertive' : undefined,
    "aria-label": accessibilityLabel,
    ref: refsSetter,
    onMouseEnter: onMouseEnter
  }, content, loading && loadingMarkup);
});
exports.Button = Button;