"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DatePicker = DatePicker;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _AppContext = require("../AppContext");

var _dates = require("../../utilities/dates");

var _Text = require("../Text");

var _Icon = require("../Icon");

var _DatePicker = _interopRequireDefault(require("./DatePicker.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function DatePicker({
  month,
  year,
  onMonthChange
}) {
  const translate = (0, _AppContext.useTranslate)();
  const geolocation = (0, _AppContext.useGeolocation)();
  const weekStartDay = (0, _react.useMemo)(() => (0, _dates.getWeekStartDay)(geolocation === null || geolocation === void 0 ? void 0 : geolocation.countryCode), [geolocation === null || geolocation === void 0 ? void 0 : geolocation.countryCode]);
  const now = new Date();
  const currentMonth = now.getMonth() === month && now.getFullYear() === year;
  const weekdaysMarkup = (0, _dates.getOrderedWeekdays)(weekStartDay).map(weekday => {
    return /*#__PURE__*/_react.default.createElement(WeekdayUI, {
      key: weekday,
      day: _dates.Weekday[weekday],
      current: currentMonth && new Date().getDay() === weekday
    });
  });
  const weeks = (0, _react.useMemo)(() => (0, _dates.getWeeksForMonth)(month, year, weekStartDay), [month, year, weekStartDay]);
  const weeksMarkup = weeks.map(week => {
    const index = week.map(date => date === null || date === void 0 ? void 0 : date.getDate()).join('');
    return /*#__PURE__*/_react.default.createElement("tr", {
      className: _DatePicker.default.Week,
      key: index
    }, week.map(date => /*#__PURE__*/_react.default.createElement(Day, {
      date: date,
      key: date === null || date === void 0 ? void 0 : date.getDate()
    })));
  });
  const previousYear = (0, _dates.getPreviousDisplayYear)(month, year);
  const previousMonth = (0, _dates.getPreviousDisplayMonth)(month);
  const showPreviousMonthLabel = translate('showPreviousMonth', {
    month: translate(_dates.Month[previousMonth].toLowerCase()),
    year: `${previousYear}`
  });
  const nextYear = (0, _dates.getNextDisplayYear)(month, year);
  const nextMonth = (0, _dates.getNextDisplayMonth)(month);
  const showNextMonthLabel = translate('showNextMonth', {
    month: translate(_dates.Month[nextMonth].toLowerCase()),
    year: `${nextYear}`
  });
  const handleMonthChange = (0, _react.useCallback)((month, year) => {
    if (!onMonthChange) {
      return;
    }

    onMonthChange(month, year);
  }, [onMonthChange]);
  const monthLabelClassName = (0, _cssUtilities.classNames)(_DatePicker.default.MonthLabel, currentMonth && _DatePicker.default['MonthLabel-current']);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _DatePicker.default.DatePicker
  }, onMonthChange && /*#__PURE__*/_react.default.createElement("div", {
    className: _DatePicker.default.Controls
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    onClick: () => handleMonthChange(previousMonth, previousYear),
    className: _DatePicker.default.ControlsPrevious,
    "aria-label": showPreviousMonthLabel
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "arrowLeft",
    size: "base"
  })), /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    onClick: () => handleMonthChange(nextMonth, nextYear),
    className: _DatePicker.default.ControlsNext,
    "aria-label": showNextMonthLabel
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "arrowRight",
    size: "base"
  }))), /*#__PURE__*/_react.default.createElement("table", {
    role: "grid",
    className: _DatePicker.default.Month
  }, /*#__PURE__*/_react.default.createElement("caption", {
    className: monthLabelClassName,
    "aria-live": "polite"
  }, translate(_dates.Month[month].toLowerCase()), " ", year), /*#__PURE__*/_react.default.createElement("thead", null, /*#__PURE__*/_react.default.createElement("tr", {
    className: _DatePicker.default.WeekDays
  }, weekdaysMarkup)), /*#__PURE__*/_react.default.createElement("tbody", null, weeksMarkup)));
}

const WeekdayUI = /*#__PURE__*/(0, _react.memo)(function Weekday({
  day,
  current
}) {
  const translate = (0, _AppContext.useTranslate)();
  const className = (0, _cssUtilities.classNames)(_DatePicker.default.Weekday);
  return /*#__PURE__*/_react.default.createElement("th", {
    scope: "col",
    className: className
  }, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    role: {
      type: 'abbreviation',
      for: translate(day.toLowerCase())
    },
    subdued: !current,
    emphasized: current,
    size: "small"
  }, translate(`${day.toLowerCase()}Abbreviation`)));
});

function Day({
  date,
  disabled,
  selected,
  inRange
}) {
  if (!date) {
    return /*#__PURE__*/_react.default.createElement("td", null);
  }

  const label = date.getDate();
  const today = (0, _dates.isToday)(date);
  const className = (0, _cssUtilities.classNames)(_DatePicker.default.Day, today && _DatePicker.default['Day-today'], disabled && _DatePicker.default['Day-disabled'], selected && _DatePicker.default['Day-selected'], inRange && _DatePicker.default['Day-inRange']);
  return /*#__PURE__*/_react.default.createElement("td", {
    className: _DatePicker.default.DayCell
  }, disabled ? /*#__PURE__*/_react.default.createElement("span", {
    className: className
  }, label) : /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    tabIndex: -1,
    className: className
  }, label));
}