"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Image = Image;
exports.MEDIA_MAP = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _View = require("../View");

var _breakpoint = require("../../utilities/breakpoint");

var _Image = _interopRequireDefault(require("./Image.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MEDIA_MAP = new Map((0, _breakpoint.createMediaQueries)({
  addMaxWidth: false
}).map(({
  breakpoint,
  query
}) => [breakpoint, query]));
exports.MEDIA_MAP = MEDIA_MAP;

function Image({
  source,
  sources,
  description = '',
  fit,
  loading,
  aspectRatio,
  decorative
}) {
  const sourcesMarkup = sources && Object.entries(sources).sort(([firstBreakpoint], [secondBreakpoint]) => {
    const firstWidth = _breakpoint.BREAKPOINTS[firstBreakpoint];
    const secondWidth = _breakpoint.BREAKPOINTS[secondBreakpoint];

    if (firstWidth != null && secondWidth != null) {
      return secondWidth - firstWidth;
    }

    return 0;
  }).map(([viewportSize, sizeSources]) => {
    if (typeof sizeSources === 'string') {
      return [viewportSize, [{
        source: sizeSources
      }]];
    }

    if (!Array.isArray(sizeSources) && sizeSources !== undefined) {
      return [viewportSize, [sizeSources]];
    }

    return [viewportSize, sizeSources];
  }).map(([viewportSize, sizeSources]) => {
    const media = MEDIA_MAP.get(viewportSize);

    if (media !== undefined && Array.isArray(sizeSources)) {
      const srcSet = sizeSources.map(({
        source,
        resolution
      }) => [source, resolution && `${resolution}x`].join(' ').trim()).join(', ');
      return /*#__PURE__*/_react.default.createElement("source", {
        key: media,
        media: media,
        srcSet: srcSet
      });
    }
  });
  const className = (0, _cssUtilities.classNames)(_Image.default.Image, fit && _Image.default[(0, _cssUtilities.variationName)('fit', fit)]);
  return /*#__PURE__*/_react.default.createElement(MaybeHiddenForA11y, {
    condition: decorative === true
  }, /*#__PURE__*/_react.default.createElement(MaybeAspectRatio, {
    condition: aspectRatio != null,
    aspectRatio: aspectRatio
  }, /*#__PURE__*/_react.default.createElement(MaybePicture, {
    condition: sourcesMarkup != null
  }, sourcesMarkup, /*#__PURE__*/_react.default.createElement("img", {
    src: source,
    alt: description,
    className: className,
    loading: loading
  }))));
}

function MaybeHiddenForA11y({
  children,
  condition
}) {
  return condition ? /*#__PURE__*/_react.default.createElement(_View.View, {
    accessibilityVisibility: "hidden"
  }, children) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
}

function MaybeAspectRatio({
  children,
  condition,
  aspectRatio
}) {
  return condition ? /*#__PURE__*/_react.default.createElement("div", {
    className: _Image.default.aspectRatio,
    style: {
      paddingBottom: `calc(100% / ${aspectRatio})`
    }
  }, children) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
}

function MaybePicture({
  children,
  condition
}) {
  return condition ? /*#__PURE__*/_react.default.createElement("picture", null, children) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
}