"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Labelled = Labelled;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Text = require("../Text");

var _Truncate = require("../Truncate");

var _Theme = require("../Theme");

var _context = require("./context");

var _Labelled = _interopRequireDefault(require("./Labelled.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function Labelled({
  children,
  label,
  htmlFor,
  empty,
  position = 'inside',
  background = 'surfaceTertiary',
  subdued,
  prefixed,
  hasIcon
}) {
  const [focused, setFocused] = (0, _react.useState)(false);
  const [wasNotEmpty, setWasNotEmpty] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    if (!empty) {
      setWasNotEmpty(true);
    } else if (!focused) {
      setWasNotEmpty(false);
    }
  }, [focused, empty]);
  const floating = (!empty || empty && wasNotEmpty) && position === 'inside';
  const handleFocus = (0, _react.useCallback)(() => {
    setFocused(true);

    if (prefixed) {
      setWasNotEmpty(true);
    }
  }, [prefixed]);
  const handleBlur = (0, _react.useCallback)(() => setFocused(false), []);
  const {
    label: {
      typographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  return /*#__PURE__*/_react.default.createElement(_context.LabelledContext.Provider, {
    value: {
      onFocus: handleFocus,
      onBlur: handleBlur,
      focused,
      floating
    }
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Labelled.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)({
      [_Labelled.default.floating]: floating
    })
  }, /*#__PURE__*/_react.default.createElement("label", {
    id: `${htmlFor}-label`,
    htmlFor: htmlFor,
    className: (0, _cssUtilities.classNames)(_Labelled.default.Label, _Labelled.default[(0, _cssUtilities.variationName)('Label-position', position)], subdued && _Labelled.default['Label-subdued'], background && _Labelled.default[(0, _cssUtilities.variationName)('Label-onBackground', background)], hasIcon && _Labelled.default['Label-nextToIcon'])
  }, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    size: "small",
    subdued: true,
    style: typographyStyle
  }, /*#__PURE__*/_react.default.createElement(_Truncate.Truncate, null, label))), children)));
}