"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Labelled = require("./Labelled");

var _hook = require("./hook");

var _context = require("./context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  children: /*#__PURE__*/_react.default.createElement(Child, null),
  label: '',
  htmlFor: '',
  empty: true
};
describe('<Labelled />', () => {
  it('renders the children', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, defaultProps));
    expect(labelled).toContainReactComponent(Child);
  });
  it('wraps children with a LabelledContext.Provider', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email"
    })));
    expect(labelled).toProvideReactContext(_context.LabelledContext);
  });
  it('renders a floating label when the value is prefilled', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email",
      empty: false
    })));
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: true
    }));
  });
  it('does not render a floating label on focus when empty', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email"
    }))); // Gain focus

    labelled.act(() => {
      var _labelled$find;

      (_labelled$find = labelled.find('input')) === null || _labelled$find === void 0 ? void 0 : _labelled$find.trigger('onFocus');
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: false
    }));
  });
  it('renders a floating label once a value is entered', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email"
    }))); // Enter value

    labelled.act(() => {
      labelled.setProps({
        empty: false
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: true
    }));
  });
  it('renders a floating label when focused, then the value is removed', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      empty: false,
      label: "Email"
    }))); // Gain focus

    labelled.act(() => {
      var _labelled$find2;

      (_labelled$find2 = labelled.find('input')) === null || _labelled$find2 === void 0 ? void 0 : _labelled$find2.trigger('onFocus');
    }); // Remove value

    labelled.act(() => {
      labelled.setProps({
        empty: true
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: true
    }));
  });
  it('does not render a floating label when not focused and the value is removed', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      empty: false,
      label: "Email"
    }))); // Remove value

    labelled.act(() => {
      labelled.setProps({
        empty: true
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: false
    }));
  });
  it('does not render a floating label when focused, then a value is entered, then removed, then the focus is lost', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email"
    }))); // Gain focus

    labelled.act(() => {
      var _labelled$find3;

      (_labelled$find3 = labelled.find('input')) === null || _labelled$find3 === void 0 ? void 0 : _labelled$find3.trigger('onFocus');
    }); // Enter value

    labelled.act(() => {
      labelled.setProps({
        empty: false
      });
    }); // Remove value

    labelled.act(() => {
      labelled.setProps({
        empty: true
      });
    }); // Lose focus

    labelled.act(() => {
      var _labelled$find4;

      (_labelled$find4 = labelled.find('input')) === null || _labelled$find4 === void 0 ? void 0 : _labelled$find4.trigger('onBlur');
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: false
    }));
  });
  it('renders a floating label when focused, then a value is entered, then the focus is lost', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email"
    }))); // Gain focus

    labelled.act(() => {
      var _labelled$find5;

      (_labelled$find5 = labelled.find('input')) === null || _labelled$find5 === void 0 ? void 0 : _labelled$find5.trigger('onFocus');
    }); // Enter value

    labelled.act(() => {
      labelled.setProps({
        empty: false
      });
    }); // Lose focus

    labelled.act(() => {
      var _labelled$find6;

      (_labelled$find6 = labelled.find('input')) === null || _labelled$find6 === void 0 ? void 0 : _labelled$find6.trigger('onBlur');
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: true
    }));
  });
  it('renders a floating label when focused, then a value is entered, then lost focus, then focused, then the value removed', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: "Email"
    }))); // Gain focus

    labelled.act(() => {
      var _labelled$find7;

      (_labelled$find7 = labelled.find('input')) === null || _labelled$find7 === void 0 ? void 0 : _labelled$find7.trigger('onFocus');
    }); // Enter value

    labelled.act(() => {
      labelled.setProps({
        empty: false
      });
    }); // Lose focus

    labelled.act(() => {
      var _labelled$find8;

      (_labelled$find8 = labelled.find('input')) === null || _labelled$find8 === void 0 ? void 0 : _labelled$find8.trigger('onBlur');
    }); // Gain focus

    labelled.act(() => {
      var _labelled$find9;

      (_labelled$find9 = labelled.find('input')) === null || _labelled$find9 === void 0 ? void 0 : _labelled$find9.trigger('onFocus');
    }); // Remove value

    labelled.act(() => {
      labelled.setProps({
        empty: true
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      floating: true
    }));
  });
});

function Child({
  value
}) {
  const {
    onBlur,
    onFocus
  } = (0, _hook.useLabelled)();
  return /*#__PURE__*/_react.default.createElement("input", {
    value: value,
    onBlur: onBlur,
    onFocus: onFocus,
    onChange: () => {}
  });
}