"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Layout = Layout;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsive = require("../../utilities/responsive");

var _units = require("../../utilities/units");

var _id = require("../../utilities/id");

var _Layout = _interopRequireDefault(require("./Layout.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MEDIAQUERY_MAP = new Map([['small', '@media all and (min-width: 750px)'], ['medium', '@media all and (min-width: 1000px)'], ['large', '@media all and (min-width: 1200px)']]);
const createId = (0, _id.createIdCreator)('Layout');

function Layout({
  inlineAlignment = 'center',
  blockAlignment = 'leading',
  maxInlineSize,
  sizes,
  spacing,
  children
}) {
  const uniqueClassName = createId();
  const CSSSelector = `.${uniqueClassName} > .${_Layout.default.LayoutInner}`;
  const responsiveClassNames = (0, _responsive.useResponsive)({
    spacing
  });
  const layoutClassName = (0, _cssUtilities.classNames)(_Layout.default.Layout, uniqueClassName, blockAlignment && _Layout.default[(0, _cssUtilities.variationName)('blockAlignment', blockAlignment)], inlineAlignment && _Layout.default[(0, _cssUtilities.variationName)('inlineAlignment', inlineAlignment)]);
  const layoutInnerClassName = (0, _cssUtilities.classNames)(_Layout.default.LayoutInner, inlineAlignment && _Layout.default[(0, _cssUtilities.variationName)('LayoutInner-inlineAlignment', inlineAlignment)], blockAlignment && _Layout.default[(0, _cssUtilities.variationName)('LayoutInner-blockAlignment', blockAlignment)], responsiveClassNames && responsiveClassNames.map(className => _Layout.default[`LayoutInner-${className}`]));
  const layoutStyles = [sizes && generateSizesStyle(CSSSelector, sizes), maxInlineSize && generateMaxInlineSizeStyles(CSSSelector, maxInlineSize)].join(' ');
  return /*#__PURE__*/_react.default.createElement("div", {
    className: layoutClassName
  }, Boolean(layoutStyles.trim()) && /*#__PURE__*/_react.default.createElement("style", null, layoutStyles), /*#__PURE__*/_react.default.createElement("div", {
    className: layoutInnerClassName
  }, _react.default.Children.map(children, child => /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Layout.default.LayoutInnerSpacing, responsiveClassNames && responsiveClassNames.map(className => _Layout.default[`LayoutInnerSpacing-${className}`]))
  }, /*#__PURE__*/_react.default.createElement("div", null, child)))));
}

function generateSizesStyles(selector, sizes) {
  return sizes.reduce((acc, basicSize, index) => {
    const mustFill = basicSize === 'fill';
    const sizeStyles = typeof basicSize === 'number' ? `flex: 0 0 ${(0, _units.pixelOrPercent)(basicSize)};` : 'flex: 0 1 auto;';
    const inlineStyles = `
        ${selector} > :nth-child(${index + 1}) {
          ${mustFill ? 'flex: 1 0px;' : `${sizeStyles}`}
        }
      `;
    return [acc, inlineStyles].join(' ');
  }, '');
}

function generateSizesStyle(selector, sizes) {
  if (Array.isArray(sizes) || typeof sizes !== 'object') {
    const sizesStyles = sizes && generateSizesStyles(selector, sizes);
    const wrappingStyles = (sizes === null || sizes === void 0 ? void 0 : sizes.includes(1)) ? `${selector} { flex-wrap: wrap; }` : `${selector} { flex-wrap: nowrap; }`;
    return [sizesStyles, wrappingStyles].join(' ');
  }

  return Object.entries(sizes).reduce((acc, [breakpoint, sizes]) => {
    const sizesStyles = sizes && generateSizesStyles(selector, sizes);
    const wrappingStyles = (sizes === null || sizes === void 0 ? void 0 : sizes.includes(1)) ? `${selector} { flex-wrap: wrap; }` : `${selector} { flex-wrap: nowrap; }`;
    const mediaStyles = [sizesStyles, wrappingStyles];
    const inlineStyles = breakpoint === 'base' ? mediaStyles : [MEDIAQUERY_MAP.get(breakpoint), '{', ...mediaStyles, '}'];
    return [acc, ...inlineStyles].join(' ');
  }, '');
}

function generateMaxInlineSizeStyles(selector, maxInlineSize) {
  if (typeof maxInlineSize !== 'object') {
    return maxInlineSize ? `${selector} { max-width: ${(0, _units.pixelOrPercent)(maxInlineSize)}; }` : '';
  }

  return Object.entries(maxInlineSize).reduce((acc, [breakpoint, maxInlineSize]) => {
    const maxInlineSizeStyles = maxInlineSize ? `${selector} { max-width: ${(0, _units.pixelOrPercent)(maxInlineSize)}; }` : '';
    const inlineStyles = breakpoint === 'base' ? [maxInlineSizeStyles] : [MEDIAQUERY_MAP.get(breakpoint), '{', maxInlineSizeStyles, '}'];
    return [acc, ...inlineStyles].join(' ');
  }, '');
}