"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Link = Link;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Button = require("../Button");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _components = require("./components");

var _Link = _interopRequireDefault(require("./Link.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Link is used to navigate the buyer to another page or section within the same page.
 */
function Link({
  children,
  to,
  language,
  onPress,
  appearance,
  accessibilityLabel,
  ...rest
}) {
  const {
    link: {
      colorHovered,
      typographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();

  if (!to) {
    return /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({
      onPress: onPress,
      kind: "plain",
      appearance: appearance
    }, rest), children);
  }

  return /*#__PURE__*/_react.default.createElement(_components.UnstyledLink, Object.assign({
    className: (0, _cssUtilities.classNames)(_Link.default.Link, appearance && appearance === 'monochrome' ? _Link.default.appearanceMonochrome : _Link.default.appearanceDefault, colorHovered && _Link.default[(0, _cssUtilities.variationName)('colorHovered', colorHovered)], typographyStyle && _typographyStyles.default[typographyStyle]),
    to: to,
    onPress: onPress,
    language: language,
    accessibilityLabel: accessibilityLabel
  }, rest), children);
}