"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Modal = Modal;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsiveValue = require("../../utilities/responsiveValue");

var _AppContext = require("../AppContext");

var _FocusTrap = require("../FocusTrap");

var _Portal = require("../Portal");

var _Heading = require("../Heading");

var _Icon = require("../Icon");

var _units = require("../../utilities/units");

var _transition = require("../../utilities/transition");

var _id = require("../../utilities/id");

var _Modal = _interopRequireDefault(require("./Modal.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('ModalHeading');
const IFRAME_HEIGHT_NOT_ACCESSIBLE = -1;

function Modal({
  maxInlineSize,
  blockSize,
  open,
  title,
  titleHidden,
  source,
  noMountTransition = false,
  children,
  ...rest
}) {
  const blocking = rest.blocking;
  const onClose = rest.blocking ? undefined : rest.onClose;
  const translate = (0, _AppContext.useTranslate)();
  const [iframeHeight, setIframeHeight] = (0, _react.useState)();
  const activatorRef = (0, _react.useRef)(null);
  const modalRef = (0, _react.useRef)(null);
  const modalHeadingId = (0, _id.useId)(undefined, createId);
  const transition = (0, _transition.useTransition)(open, 'fast', !noMountTransition);

  const transitionClassName = _Modal.default[(0, _cssUtilities.variationName)('transition', transition)];

  const isMobile = (0, _responsiveValue.useResponsiveValue)({
    base: true,
    medium: false
  });
  (0, _react.useEffect)(() => {
    if (transition === 'enter') {
      document.body.style.overflow = 'hidden';
      activatorRef.current = document.activeElement;
    }

    if (transition === 'exited') {
      document.body.style.overflow = 'auto';
      if ((activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current) instanceof HTMLElement) activatorRef.current.focus();
      setIframeHeight(undefined);
    }
  }, [transition]);

  const handleDialogFocus = () => {
    // workaround for browsers that don't support `preventScroll` for `focus`
    setTimeout(() => {
      const modal = modalRef.current;
      modal && modal.scrollTo(0, 0);
    }, 0);
  };

  (0, _react.useEffect)(() => {
    const handleKeyDown = event => {
      if ((event.key === 'Escape' || event.key === 'Esc') && !blocking) {
        onClose && onClose();
      }
    };

    document.addEventListener('keydown', handleKeyDown, false);
    return () => {
      document.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [blocking, onClose]);
  const handleIFrameLoad = (0, _react.useCallback)(evt => {
    const iframe = evt.target;

    if (iframe && iframe.contentWindow) {
      try {
        setIframeHeight(iframe.contentWindow.document.body.scrollHeight);
      } catch {
        setIframeHeight(IFRAME_HEIGHT_NOT_ACCESSIBLE);
      }
    }
  }, []);

  function handleBackdropClick() {
    onClose && onClose();
  }

  if (transition === 'exited') return null;
  const ariaLabelOrLabelledby = titleHidden ? {
    'aria-label': title
  } : {
    'aria-labelledby': modalHeadingId
  };
  const titleMarkup = titleHidden ?
  /*#__PURE__*/
  // `null` breaks close button's right alignment
  _react.default.createElement("span", null) : /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
    level: 1,
    id: modalHeadingId
  }, title);

  const header = (!titleHidden || !blocking) && /*#__PURE__*/_react.default.createElement("header", {
    className: _Modal.default.Header
  }, titleMarkup, !blocking && /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Modal.default.CloseButton,
    onClick: onClose,
    "aria-label": translate('close') || 'Close'
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "close",
    size: "large"
  })));

  const content = source ? /*#__PURE__*/_react.default.createElement("iframe", Object.assign({
    src: source,
    title: title,
    className: _Modal.default.IFrame
  }, iframeHeight && iframeHeight > 0 && {
    style: {
      height: iframeHeight
    }
  }, !blockSize && {
    onLoad: handleIFrameLoad
  })) : /*#__PURE__*/_react.default.createElement("div", Object.assign({
    className: _Modal.default.Content
  }, (blockSize || isMobile) && {
    tabIndex: 0
  }), children);
  return /*#__PURE__*/_react.default.createElement(_Portal.Portal, null, /*#__PURE__*/_react.default.createElement("div", {
    className: _Modal.default.Modal,
    ref: modalRef
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Modal.default.Backdrop, transitionClassName),
    onClick: handleBackdropClick
  }), /*#__PURE__*/_react.default.createElement(_FocusTrap.FocusTrap, {
    onContainerFocus: handleDialogFocus
  }, /*#__PURE__*/_react.default.createElement("div", Object.assign({
    className: (0, _cssUtilities.classNames)(_Modal.default.Dialog, transitionClassName, {
      [_Modal.default['Dialog-blockSizeFill']]: blockSize === 'fill' || iframeHeight === -1
    }),
    role: "dialog",
    "aria-modal": true,
    style: { ...(maxInlineSize && {
        maxWidth: (0, _units.pixelOrPercent)(maxInlineSize === 'fill' ? 1 : maxInlineSize)
      })
    }
  }, ariaLabelOrLabelledby), header, content))));
}