"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../../../test-utilities");

var _Text = require("../../../Text");

var _MoneyLine = require("./MoneyLine");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<MoneyLine />', () => {
  it('renders a label', () => {
    const label = _faker.default.random.word();

    const moneyLine = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLine, {
      label: label
    }));
    expect(moneyLine.find(_MoneyLine.MoneyLineHeader)).toContainReactComponent(_Text.Text, {
      children: label
    });
  });
  it('renders a value', () => {
    const value = _faker.default.random.word();

    const moneyLine = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLine, {
      label: "label",
      value: value
    }));
    expect(moneyLine.find(_MoneyLine.MoneyLineContent)).toContainReactComponent(_Text.Text, {
      children: value
    });
  });
  it('renders a subdued value', () => {
    const value = _faker.default.random.word();

    const moneyLine = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLine, {
      label: "label",
      value: value,
      subdued: true
    }));
    expect(moneyLine.find(_MoneyLine.MoneyLineContent)).toContainReactComponent(_Text.Text, {
      subdued: true,
      children: value
    });
  });
  it('renders the children', () => {
    const moneyLine = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLine, null, /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLineHeader, null), /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLineContent, null)));
    expect(moneyLine).toContainReactComponent(_MoneyLine.MoneyLineHeader);
    expect(moneyLine).toContainReactComponent(_MoneyLine.MoneyLineContent);
  });
  describe('<MoneyLineHeader />', () => {
    it('renders the children', () => {
      const children = 'children';
      const moneyLine = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLine, null, /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLineHeader, null, children)));
      expect(moneyLine.find(_MoneyLine.MoneyLineHeader)).toContainReactText(children);
    });
  });
  describe('<MoneyLineContent />', () => {
    it('renders the children', () => {
      const children = 'children';
      const moneyLine = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLine, null, /*#__PURE__*/_react.default.createElement(_MoneyLine.MoneyLineContent, null, children)));
      expect(moneyLine.find(_MoneyLine.MoneyLineContent)).toContainReactText(children);
    });
  });
});