"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../../../test-utilities");

var _Text = require("../../../Text");

var _MoneySummary = require("./MoneySummary");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<MoneySummary />', () => {
  it('renders a label', () => {
    const label = _faker.default.random.word();

    const moneySummary = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummary, {
      label: label,
      prefix: "prefix",
      value: "value"
    }));
    expect(moneySummary.find(_MoneySummary.MoneySummaryHeader)).toContainReactComponent(_Text.Text, {
      children: label
    });
  });
  it('renders a prefix', () => {
    const prefix = _faker.default.random.word();

    const moneySummary = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummary, {
      label: "label",
      prefix: prefix,
      value: "value"
    }));
    expect(moneySummary.find(_MoneySummary.MoneySummaryContent)).toContainReactComponent(_Text.Text, {
      children: prefix
    });
  });
  it('renders a value', () => {
    const value = _faker.default.random.word();

    const moneySummary = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummary, {
      label: "label",
      prefix: "prefix",
      value: value
    }));
    expect(moneySummary.find(_MoneySummary.MoneySummaryContent)).toContainReactComponent(_Text.Text, {
      children: value
    });
  });
  it('renders the children', () => {
    const moneySummary = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummary, null, /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummaryHeader, null), /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummaryContent, null)));
    expect(moneySummary).toContainReactComponent(_MoneySummary.MoneySummaryHeader);
    expect(moneySummary).toContainReactComponent(_MoneySummary.MoneySummaryContent);
  });
  describe('<MoneySummaryHeader />', () => {
    it('renders the children', () => {
      const children = 'children';
      const moneySummary = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummary, {
        label: "label",
        prefix: "prefix",
        value: "value"
      }, /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummaryHeader, null, children)));
      expect(moneySummary.find(_MoneySummary.MoneySummaryHeader)).toContainReactText(children);
    });
  });
  describe('<MoneySummaryContent />', () => {
    it('renders the children', () => {
      const children = 'children';
      const moneySummary = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummary, {
        label: "label",
        prefix: "prefix",
        value: "value"
      }, /*#__PURE__*/_react.default.createElement(_MoneySummary.MoneySummaryContent, null, children)));
      expect(moneySummary.find(_MoneySummary.MoneySummaryContent)).toContainReactText(children);
    });
  });
});