"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../../../test-utilities");

var _Checkbox = require("../../../Checkbox");

var _RadioControl = require("../../../RadioControl");

var _OptionList = require("../../OptionList");

var _Option = require("./Option");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  id: _faker.default.random.uuid(),
  label: _faker.default.random.word()
};
const defaultOptionListProps = {
  id: _faker.default.random.uuid(),
  selectedItems: [],
  onChange: () => null,
  children: /*#__PURE__*/_react.default.createElement("div", null)
};
describe('<Option />', () => {
  it('triggers onChange when input is selected', () => {
    const id = _faker.default.random.uuid();

    const onChangeSpy = jest.fn();
    const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
      onChange: onChangeSpy
    }), /*#__PURE__*/_react.default.createElement(_Option.Option, Object.assign({}, defaultProps, {
      id: id
    }))));
    optionList.find(_Option.Option).find(_RadioControl.RadioControl).trigger('onChange');
    expect(onChangeSpy).toHaveBeenCalledWith([id]);
  });
  it('input is active if selected', () => {
    const id = _faker.default.random.uuid();

    const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
      selectedItems: [id]
    }), /*#__PURE__*/_react.default.createElement(_Option.Option, Object.assign({}, defaultProps, {
      id: id
    }))));
    expect(optionList.find(_Option.Option)).toContainReactComponent('input', {
      checked: true
    });
  });
  it('renders a RadioControl if allow multiple is false', () => {
    const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react.default.createElement(_Option.Option, defaultProps)));
    expect(optionList.find(_Option.Option)).toContainReactComponent(_RadioControl.RadioControl);
  });
  it('renders a CheckboxControl if allow multiple is true', () => {
    const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
      allowMultiple: true
    }), /*#__PURE__*/_react.default.createElement(_Option.Option, defaultProps)));
    expect(optionList.find(_Option.Option)).toContainReactComponent(_Checkbox.CheckboxControl);
  });
  describe('allowMultiple', () => {
    it('allows the selection of multiple options', () => {
      const firstItem = _faker.default.random.uuid();

      const secondItem = _faker.default.random.uuid();

      const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
        allowMultiple: true,
        selectedItems: [firstItem, secondItem]
      }), /*#__PURE__*/_react.default.createElement(_Option.Option, Object.assign({}, defaultProps, {
        id: firstItem
      })), /*#__PURE__*/_react.default.createElement(_Option.Option, Object.assign({}, defaultProps, {
        id: secondItem
      }))));
      const [firstOption, secondOption] = optionList.findAll(_Option.Option);
      expect(firstOption).toContainReactComponent(_Checkbox.CheckboxControl, {
        checked: true
      });
      expect(secondOption).toContainReactComponent(_Checkbox.CheckboxControl, {
        checked: true
      });
    });
    it('toggles the selection of already selection options', () => {
      const selected = _faker.default.random.uuid();

      const onChangeSpy = jest.fn();
      const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
        allowMultiple: true,
        selectedItems: [selected],
        onChange: onChangeSpy
      }), /*#__PURE__*/_react.default.createElement(_Option.Option, Object.assign({}, defaultProps, {
        id: selected
      }))));
      optionList.find(_Option.Option).find(_Checkbox.CheckboxControl).trigger('onChange');
      expect(onChangeSpy).toHaveBeenCalledWith([]);
    });
  });
  describe('controlHidden', () => {
    it('shows control by default', () => {
      const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react.default.createElement(_Option.Option, defaultProps)));
      expect(optionList.find(_Option.Option)).toContainReactComponent(_RadioControl.RadioControl);
    });
    it('hides control when true', () => {
      const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
        controlHidden: true
      }), /*#__PURE__*/_react.default.createElement(_Option.Option, defaultProps)));
      expect(optionList.find(_Option.Option)).not.toContainReactComponent(_RadioControl.RadioControl);
    });
  });
  describe('accessibilityLabel', () => {
    it('renders an accessible label for an option when provided', () => {
      const accessibilityLabel = _faker.default.random.word();

      const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react.default.createElement(_Option.Option, Object.assign({}, defaultProps, {
        accessibilityLabel: accessibilityLabel
      }))));
      expect(optionList.find(_Option.Option)).toContainReactComponent('label', {
        'aria-label': accessibilityLabel
      });
    });
    it('does not render an accessible label by default', () => {
      const accessibilityLabel = _faker.default.random.word();

      const optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react.default.createElement(_Option.Option, defaultProps)));
      expect(optionList.find(_Option.Option)).not.toContainReactComponent('label', {
        'aria-label': accessibilityLabel
      });
    });
  });
});