"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popover = Popover;

var _cssUtilities = require("@shopify/css-utilities");

var _react = _interopRequireWildcard(require("react"));

var _id = require("../../utilities/id");

var _focus = require("../../utilities/focus");

var _Popper = require("../Popper");

var _Theme = require("../Theme");

var _Popover = _interopRequireDefault(require("./Popover.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('Popover');

function Popover({
  children,
  activator,
  open,
  placement = 'inlineEnd',
  backdrop = 'none',
  onClose
}) {
  const popoverRef = (0, _react.useRef)(null);
  const {
    popover: {
      connector = 'arrow',
      depth = 'far'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const id = (0, _id.useId)(undefined, createId);
  const setActivatorAccessibilityAttributes = (0, _react.useCallback)(() => {
    activator === null || activator === void 0 ? void 0 : activator.setAttribute('aria-controls', id);
    activator === null || activator === void 0 ? void 0 : activator.setAttribute('aria-expanded', String(open));
  }, [activator === null || activator === void 0 ? void 0 : activator.setAttribute, id, open]);
  const handleClose = (0, _react.useCallback)(() => {
    onClose === null || onClose === void 0 ? void 0 : onClose();
  }, [onClose]);
  const handleClickOutside = (0, _react.useCallback)(event => {
    if (event.target instanceof Node && !(activator === null || activator === void 0 ? void 0 : activator.contains(event.target)) && open) {
      handleClose();
    }
  }, [activator === null || activator === void 0 ? void 0 : activator.contains, open, handleClose]);
  const handleKeyDown = (0, _react.useCallback)(event => {
    if (!open) return;
    const nextFocusableNode = activator && (0, _focus.findNextFocusableNode)(activator);
    const firstFocusableNode = popoverRef.current && (0, _focus.findFirstFocusableNode)(popoverRef.current);
    const lastFocusableNode = popoverRef.current && (0, _focus.findLastFocusableNode)(popoverRef.current);

    switch (event.key) {
      case 'Escape':
      case 'Esc':
        handleClose();
        activator === null || activator === void 0 ? void 0 : activator.focus();
        break;

      case 'Tab':
        {
          if ((0, _focus.isFocused)(activator) && event.shiftKey) {
            handleClose();
          } else if ((0, _focus.isFocused)(activator)) {
            event.preventDefault();
            firstFocusableNode === null || firstFocusableNode === void 0 ? void 0 : firstFocusableNode.focus();
          } else if ((0, _focus.isFocused)(firstFocusableNode) && event.shiftKey) {
            event.preventDefault();
            activator === null || activator === void 0 ? void 0 : activator.focus();
            handleClose();
          } else if ((0, _focus.isFocused)(lastFocusableNode) && !event.shiftKey) {
            event.preventDefault();
            nextFocusableNode === null || nextFocusableNode === void 0 ? void 0 : nextFocusableNode.focus();
            handleClose();
          }

          break;
        }
    }
  }, [open, activator, handleClose, activator === null || activator === void 0 ? void 0 : activator.focus]);
  (0, _react.useEffect)(() => {
    document.addEventListener('click', handleClickOutside);
    return () => {
      document.removeEventListener('click', handleClickOutside);
    };
  }, [handleClickOutside]);
  (0, _react.useEffect)(() => {
    if (open) {
      document.addEventListener('keydown', handleKeyDown, false);
    }

    return () => {
      document.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [open, handleKeyDown]);
  (0, _react.useEffect)(() => {
    setActivatorAccessibilityAttributes();
  });
  const popoverClassName = (0, _cssUtilities.classNames)(_Popover.default.Popover, _Popover.default[(0, _cssUtilities.variationName)('Popover-placement', placement)], _Popover.default[(0, _cssUtilities.variationName)('Popover-connector', connector)], _Popover.default[(0, _cssUtilities.variationName)('Popover-depth', depth)]);
  const contentClassName = (0, _cssUtilities.classNames)(_Popover.default.Content, _Popover.default[(0, _cssUtilities.variationName)('Content-placement', placement)]);
  const backdropClassName = (0, _cssUtilities.classNames)(_Popover.default.Backdrop, _Popover.default[(0, _cssUtilities.variationName)('Backdrop-style', backdrop)]);
  const offset = connector === 'arrow' ? 15 : 5;
  return open ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Popper.Popper, {
    activator: activator,
    placement: placement,
    offset: offset,
    preventOverflow: true
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: popoverClassName,
    id: id,
    ref: popoverRef
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: contentClassName
  }, children))), backdrop === 'translucent' ? /*#__PURE__*/_react.default.createElement("div", {
    className: backdropClassName
  }) : null) : null;
}