"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popper = Popper;

var _react = _interopRequireWildcard(require("react"));

var _Portal = require("../Portal");

var _units = require("../../utilities/units");

var _hooks = require("./hooks");

var _context = require("./context");

var _offsets = require("./utilities/offsets");

var _Popper = _interopRequireDefault(require("./Popper.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function Popper({
  children,
  offset,
  placement = 'blockStart',
  preventOverflow,
  activator,
  sameInlineSize,
  minInlineSize
}) {
  const referenceRect = (0, _hooks.useEffectRect)(activator);
  const [popperRect, popperRef] = (0, _hooks.useRect)();
  const {
    clipping,
    offsets,
    spacing
  } = (0, _react.useMemo)(() => (0, _offsets.computeOffsets)(placement, popperRect, referenceRect, {
    offset,
    preventOverflow,
    sameInlineSize
  }), [offset, placement, popperRect, preventOverflow, referenceRect, sameInlineSize]);
  const contextValue = (0, _react.useMemo)(() => ({
    clipping,
    offsets,
    placement,
    popperRect,
    referenceRect,
    spacing
  }), [clipping, offsets, placement, popperRect, referenceRect, spacing]);
  const {
    x,
    y
  } = (0, _offsets.roundOffsets)({
    x: offsets.x + spacing + (window.scrollX || window.pageXOffset),
    y: offsets.y + (window.scrollY || window.pageYOffset)
  });
  const transform = (window.devicePixelRatio || 1) < 2 ? `translate(${x}px, ${y}px)` : `translate3d(${x}px, ${y}px, 0)`;
  return /*#__PURE__*/_react.default.createElement(_context.PopperContext.Provider, {
    value: contextValue
  }, /*#__PURE__*/_react.default.createElement(_Portal.Portal, null, /*#__PURE__*/_react.default.createElement("div", {
    className: _Popper.default.Popper,
    style: { ...(referenceRect && {
        transform,
        MozTransform: transform,
        webkitTransform: transform,
        ...(sameInlineSize && {
          width: referenceRect.width
        }),
        ...(minInlineSize && {
          minWidth: (0, _units.rem)(minInlineSize)
        })
      })
    },
    ref: popperRef
  }, children)));
}