"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioControl = RadioControl;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Theme = require("../Theme");

var _id = require("../../utilities/id");

var _RadioControl = _interopRequireDefault(require("./RadioControl.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createId = (0, _id.createIdCreator)('Radio');

function RadioControl({
  id: explicitId,
  name,
  value = false,
  checked = value,
  disabled,
  onChange
}) {
  const id = (0, _id.useId)(explicitId, createId);
  const {
    controls: {
      background: controlsBackground
    },
    radio: {
      background: radioBackground,
      borderColor = 'base',
      checkedStyle = 'ring',
      checkedColor = 'interactive',
      size = 'base'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const background = radioBackground || controlsBackground || 'surfaceTertiary';
  const className = (0, _cssUtilities.classNames)(_RadioControl.default.Input, disabled && _RadioControl.default['Input-isDisabled'], _RadioControl.default[(0, _cssUtilities.variationName)('Input-size', size)], _RadioControl.default[(0, _cssUtilities.variationName)('Input-background', background)], _RadioControl.default[(0, _cssUtilities.variationName)('Input-borderColor', borderColor)], _RadioControl.default[(0, _cssUtilities.variationName)('Input-checkedStyle', checkedStyle)], _RadioControl.default[(0, _cssUtilities.variationName)('Input-checkedColor', checkedColor)]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _RadioControl.default.Radio
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "radio",
    id: id,
    name: name,
    checked: checked,
    disabled: disabled,
    onChange: ({
      currentTarget
    }) => {
      onChange === null || onChange === void 0 ? void 0 : onChange(currentTarget.checked);
    },
    className: className
  }));
}