"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Heading = require("../Heading");

var _HeadingGroup = require("../HeadingGroup");

var _Section = require("./Section");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Section />', () => {
  it('renders its children', () => {
    const children = _faker.default.random.words();

    const section = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Section.Section, null, children));
    expect(section).toContainReactText(children);
  });
  it('wraps children with SectionContext of level 1', () => {
    const section = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Section.Section, null));
    expect(section).toProvideReactContext(_Section.SectionContext, {
      level: 1
    });
  });
  it('renders the Heading not wrapped in a HeadingGroup', () => {
    const heading = _faker.default.random.words();

    const section = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Section.Section, null, /*#__PURE__*/_react.default.createElement(_Heading.Heading, null, heading)));
    expect(section).not.toContainReactComponent(_HeadingGroup.HeadingGroup);
    expect(section).toContainReactComponent(_Heading.Heading, {
      children: heading
    });
  });
  describe('nested <Section />', () => {
    it('renders the Heading wrapped in a HeadingGroup', () => {
      const heading = _faker.default.random.words();

      const section = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Section.Section, null, /*#__PURE__*/_react.default.createElement(_Section.Section, null, /*#__PURE__*/_react.default.createElement(_Heading.Heading, null, heading))));
      expect(section.find(_HeadingGroup.HeadingGroup)).toContainReactComponent(_Heading.Heading, {
        children: heading
      });
    });
    it('wraps the nested Section children with SectionContext of level 2', () => {
      const children = _faker.default.random.words();

      const section = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Section.Section, null, /*#__PURE__*/_react.default.createElement(_Section.Section, null, /*#__PURE__*/_react.default.createElement(_Heading.Heading, null, children))));
      expect(section.find(_Section.Section)).toProvideReactContext(_Section.SectionContext, {
        level: 2
      });
    });
  });
});