"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Select = Select;
exports.PLACEHOLDER_VALUE = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _InlineError = require("../InlineError");

var _Text = require("../Text");

var _Icon = require("../Icon");

var _Truncate = require("../Truncate");

var _BlockStack = require("../BlockStack");

var _Theme = require("../Theme");

var _autocomplete = require("../../utilities/autocomplete");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Select = _interopRequireDefault(require("./Select.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const PLACEHOLDER_VALUE = '';
exports.PLACEHOLDER_VALUE = PLACEHOLDER_VALUE;
const createId = (0, _id.createIdCreator)('Select');

function Select({
  id: explicitId,
  name,
  label,
  options,
  value = PLACEHOLDER_VALUE,
  disabled,
  readonly,
  required,
  error,
  autocomplete,
  placeholder,
  onChange
}) {
  const {
    controls: {
      background: controlsBackground
    },
    select: {
      labelPosition = 'inside',
      background: selectBackground,
      border = 'full',
      borderColor = 'base',
      focusBorder = 'full',
      disclosureIcon = 'caretDown',
      disclosureIconSeparator = true,
      typographyStyle,
      errorIndentation,
      errorTypographyStyle
    },
    label: {
      typographyStyle: labelTypographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const id = (0, _id.useId)(explicitId, createId);
  const background = selectBackground || controlsBackground || 'surfaceTertiary';

  const errorMarkup = error && /*#__PURE__*/_react.default.createElement("span", {
    className: (errorIndentation && _Select.default[(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles.default[errorTypographyStyle])
  }, /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  const className = (0, _cssUtilities.classNames)(_Select.default.Select, Boolean(error) && _Select.default.hasError, disabled && _Select.default['Select-isDisabled'], readonly && _Select.default['Select-isReadOnly'], _Select.default[(0, _cssUtilities.variationName)('Select-label', labelPosition)], _Select.default[(0, _cssUtilities.variationName)('Select-background', background)], _Select.default[(0, _cssUtilities.variationName)('Select-border', border)], _Select.default[(0, _cssUtilities.variationName)('Select-borderColor', borderColor)], _Select.default[(0, _cssUtilities.variationName)('Select-focusBorder', focusBorder)], typographyStyle && _typographyStyles.default[typographyStyle]);

  const labelMarkup = /*#__PURE__*/_react.default.createElement("label", {
    className: (0, _cssUtilities.classNames)(_Select.default.Label, _Select.default[(0, _cssUtilities.variationName)('Label-position', labelPosition)], {
      [_Select.default['Label-isPlaceholder']]: value === PLACEHOLDER_VALUE && placeholder === label
    }, _Select.default[(0, _cssUtilities.variationName)('Label-onBackground', background)]),
    htmlFor: id
  }, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    size: !(value === PLACEHOLDER_VALUE && placeholder === label) || labelPosition === 'inside' ? 'small' : undefined,
    subdued: true,
    style: labelTypographyStyle
  }, /*#__PURE__*/_react.default.createElement(_Truncate.Truncate, null, label)));

  const view =
  /*#__PURE__*/

  /* eslint-disable-next-line @shopify/jsx-prefer-fragment-wrappers */
  _react.default.createElement("div", null, labelPosition === 'outside' ? labelMarkup : null, /*#__PURE__*/_react.default.createElement("div", {
    className: _Select.default.Wrapper
  }, labelPosition === 'inside' && labelMarkup, /*#__PURE__*/_react.default.createElement("select", {
    name: name,
    id: id,
    disabled: disabled,
    onChange: event => onChange === null || onChange === void 0 ? void 0 : onChange(event.target.value),
    required: required,
    value: value,
    className: className,
    "aria-describedby": error ? (0, _errors.errorId)(id) : undefined,
    "aria-invalid": Boolean(error),
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete)
  }, placeholder && (value === PLACEHOLDER_VALUE || placeholder !== label) && /*#__PURE__*/_react.default.createElement("option", {
    value: PLACEHOLDER_VALUE,
    hidden: placeholder === label,
    disabled: true
  }, placeholder === label ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, "\xA0") : placeholder), options.map((option, index) => /*#__PURE__*/_react.default.createElement("option", {
    /* eslint-disable-next-line react/no-array-index-key */
    key: `${option.value}${index}`,
    value: option.value,
    disabled: option.disabled || readonly
  }, option.label))), /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Select.default.Selector, disclosureIconSeparator && _Select.default['Selector-separated'], disclosureIconSeparator && _Select.default[(0, _cssUtilities.variationName)('Selector-borderColor', borderColor)])
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: disclosureIcon,
    size: "small"
  }))));

  return /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "extraTight"
  }, view, errorMarkup);
}