"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Shell = Shell;
exports.ShellSubheader = ShellSubheader;
exports.ShellSection = ShellSection;
exports.ShellSectionContent = ShellSectionContent;
exports.ShellFooter = ShellFooter;
exports.ShellDisclosure = ShellDisclosure;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Collapsible = require("../Collapsible");

var _InlineStack = require("../InlineStack");

var _HeadingGroup = require("../HeadingGroup");

var _Icon = require("../Icon");

var _Text = require("../Text");

var _legacy = require("../../utilities/legacy");

var _Shell = _interopRequireDefault(require("./Shell.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function Shell({
  children,
  headerPosition,
  subheaderPosition,
  footerPosition,
  subheaderHidden
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Shell.default.Shell, headerPosition && _Shell.default[(0, _cssUtilities.variationName)('headerPosition', headerPosition)], subheaderPosition && _Shell.default[(0, _cssUtilities.variationName)('subheaderPosition', subheaderPosition)], footerPosition && _Shell.default[(0, _cssUtilities.variationName)('footerPosition', footerPosition)], subheaderHidden && _Shell.default.subheaderHidden)
  }, children);
}

function ShellSubheader({
  children,
  alignment
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Shell.default.Subheader, _Shell.default[(0, _cssUtilities.variationName)('Subheader-alignment', alignment)])
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SubheaderInner
  }, children));
}

function ShellSection({
  bordered,
  background,
  inlineSize,
  blockSize,
  children,
  secondary,
  backgroundImage
}) {
  const Element = secondary ? 'aside' : 'div';
  const style = backgroundImage ? {
    backgroundImage: `url(${JSON.stringify(backgroundImage)})`
  } : undefined;
  return /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement(Element, {
    className: (0, _cssUtilities.classNames)(_Shell.default.Section, bordered && _Shell.default['Section-bordered'], background && backgroundToLegacyClassName(background), background && _Shell.default[(0, _cssUtilities.variationName)('Section-background', background)], inlineSize && _Shell.default[(0, _cssUtilities.variationName)('Section-inlineSize', inlineSize)], blockSize && _Shell.default[(0, _cssUtilities.variationName)('Section-blockSize', blockSize)], secondary && _Shell.default['Section-secondary']),
    style: inlineSize === 'toContainerEdge' ? style : undefined
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SectionInner,
    style: inlineSize === 'contentSize' ? style : undefined
  }, children)));
}

function ShellSectionContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SectionContent
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SectionContentInner
  }, children));
}

function ShellFooter({
  children
}) {
  return /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement("footer", {
    role: "contentinfo",
    className: _Shell.default.Footer
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.FooterInner
  }, children)));
}

// TODO: a11y
function ShellDisclosure({
  children,
  detail,
  labels,
  icon,
  bordered,
  background
}) {
  const [open, setOpen] = (0, _react.useState)(false);
  const {
    text,
    icon: disclosureIcon
  } = open ? {
    text: labels.closed,
    icon: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      source: "chevronUp",
      size: "small",
      appearance: "interactive"
    })
  } : {
    text: labels.open,
    icon: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      source: "chevronDown",
      size: "small",
      appearance: "interactive"
    })
  };
  const contentId = 'disclosure_content';
  return /*#__PURE__*/_react.default.createElement("aside", {
    className: (0, _cssUtilities.classNames)(_Shell.default.Disclosure, bordered && _Shell.default['Disclosure-bordered'], background && backgroundToLegacyClassName(background), background && _Shell.default[(0, _cssUtilities.variationName)('Disclosure-background', background)])
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: (0, _cssUtilities.classNames)(_Shell.default.DisclosureButton, _legacy.utilityDefaultBorderColor),
    onClick: () => setOpen(open => !open),
    "aria-pressed": open,
    "aria-controls": contentId,
    "aria-expanded": open
  }, /*#__PURE__*/_react.default.createElement("span", {
    className: _Shell.default.DisclosureLayout
  }, /*#__PURE__*/_react.default.createElement(_InlineStack.InlineStack, {
    spacing: "tight",
    alignment: "center"
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: icon,
    size: "large",
    appearance: "interactive"
  }), /*#__PURE__*/_react.default.createElement(_Text.Text, null, text), disclosureIcon), detail)), /*#__PURE__*/_react.default.createElement(_Collapsible.Collapsible, {
    open: open,
    id: contentId
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Shell.default.DisclosureContent, _legacy.utilityDefaultBorderColor)
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.DisclosureContentInner
  }, children))));
}

function backgroundToLegacyClassName(background) {
  switch (background) {
    case 'surfacePrimary':
      return _legacy.colorSurfacePrimary;

    case 'surfaceSecondary':
      return _legacy.colorSurfaceSecondary;

    case 'surfaceTertiary':
      return _legacy.colorSurfaceTertiary;
  }
}