"use strict";

var _react = _interopRequireDefault(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _Spinner = require("./Spinner");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Spinner />', () => {
  beforeEach(() => {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(() => {
    _jestDomMocks.matchMedia.restore();
  });
  it('removes the Spinner when user prefers reduced motion and that accessible content is provided', () => {
    _jestDomMocks.matchMedia.setMedia(() => ({
      matches: true
    }));

    const spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
      accessibilityLabel: "Loading"
    }));
    expect(spinner).not.toContainReactComponent('div', {
      className: 'Spinner'
    });
  });
  it('renders an Icon when user prefers motion', () => {
    _jestDomMocks.matchMedia.setMedia(() => ({
      matches: false
    }));

    const spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, null));
    expect(spinner).toContainReactComponent(_Icon.Icon);
  });
  describe('accessibilityLabel', () => {
    it('renders the accessible label if user prefers reduced motion', () => {
      _jestDomMocks.matchMedia.setMedia(() => ({
        matches: true
      }));

      const accessibleText = 'Loading';
      const spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
        accessibilityLabel: accessibleText
      }));
      expect(spinner).toContainReactText(accessibleText);
    });
    it('does not renders the accessible label if user prefers motion', () => {
      _jestDomMocks.matchMedia.setMedia(() => ({
        matches: false
      }));

      const accessibleText = 'Loading';
      const spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
        accessibilityLabel: accessibleText
      }));
      expect(spinner).not.toContainReactText(accessibleText);
    });
  });
  describe('color', () => {
    it('renders an Icon with "accent" color by default', () => {
      const spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, null));
      expect(spinner).toContainReactComponent(_Icon.Icon, {
        appearance: 'accent'
      });
    });
    it('renders an Icon with with no color prop if "inherit" is passed', () => {
      const spinner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
        color: "inherit"
      }));
      expect(spinner).toContainReactComponent(_Icon.Icon, {
        appearance: undefined
      });
    });
  });
});