"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Stepper = Stepper;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _AppContext = require("../AppContext");

var _Theme = require("../Theme");

var _BlockStack = require("../BlockStack");

var _TextField = require("../TextField");

var _Icon = require("../Icon");

var _InlineError = require("../InlineError");

var _id = require("../../utilities/id");

var _Stepper = _interopRequireDefault(require("./Stepper.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('StepperField');

const SpinButtons = ({
  handleButtonPress,
  handleTap,
  minReached,
  maxReached,
  separator
}) => {
  const translate = (0, _AppContext.useTranslate)();
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Stepper.default.SpinButtonGroup),
    role: "group"
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    "aria-label": translate('decrement') || 'Decrement',
    onTouchStart: () => handleTap(-1),
    onMouseDown: evt => handleButtonPress(evt, -1),
    className: (0, _cssUtilities.classNames)(_Stepper.default.SpinButton),
    disabled: minReached,
    tabIndex: -1
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "minus",
    size: "base"
  })), separator && /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Stepper.default.SpinButtonSeparator)
  }), /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    "aria-label": translate('increment') || 'Increment',
    onTouchStart: () => handleTap(1),
    onMouseDown: evt => handleButtonPress(evt, 1),
    className: (0, _cssUtilities.classNames)(_Stepper.default.SpinButton),
    disabled: maxReached,
    tabIndex: -1
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "plus",
    size: "base"
  })));
};

function Stepper({
  accessibilityDescription,
  disabled,
  label,
  error,
  name,
  min = 0,
  max,
  value,
  step = 1,
  id: explicitId,
  required,
  onChange,
  onBlur,
  onFocus,
  readonly
}) {
  const {
    stepper: {
      separator = true
    }
  } = (0, _Theme.useThemeConfiguration)();
  const [quantity, setQuantity] = (0, _react.useState)(value);
  const [spinning, setSpinning] = (0, _react.useState)(false);
  const [minReached, setMinReached] = (0, _react.useState)(false);
  const [maxReached, setMaxReached] = (0, _react.useState)(false);
  const buttonPressTimer = (0, _react.useRef)();
  const id = (0, _id.useId)(explicitId, createId);
  (0, _react.useEffect)(() => {
    setQuantity(Number(value));
  }, [value]);
  (0, _react.useEffect)(() => {
    setMinReached(() => {
      return quantity !== undefined && min !== undefined && quantity <= min;
    });
  }, [quantity, min]);
  (0, _react.useEffect)(() => {
    setMaxReached(() => {
      return quantity !== undefined && max !== undefined && quantity >= max;
    });
  }, [quantity, max]); // because we do not register value changes until the blur, we need to manually handle disabling/enabling spin buttons onInput

  const handleMinOrMaxReached = value => {
    const numVal = Number(value);
    if (numVal <= min) setMinReached(true);
    if (max !== undefined && numVal >= max) setMaxReached(true);
    if (numVal > min) setMinReached(false);
    if (max !== undefined && numVal < max) setMaxReached(false);
  };

  const errorMarkup = error && /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error);

  const calculateQuantity = (0, _react.useCallback)(({
    factor,
    prevQuantity,
    max,
    min,
    step
  }) => {
    const normalizedMax = max === undefined ? Infinity : max;
    const normalizedMin = min === undefined ? -Infinity : min;
    const quantity = prevQuantity ? prevQuantity : 0;

    if (isNaN(quantity)) {
      return 0;
    } // Returns the length of decimal places in a number


    const decimalLength = num => (num.toString().split('.')[1] || []).length; // Making sure the new value has the same length of decimal places as the
    // step / value has.


    const decimalPlaces = Math.max(decimalLength(quantity), decimalLength(step));
    const newQuantity = Math.min(Number(normalizedMax), Math.max(quantity + factor * step, Number(normalizedMin)));
    return parseFloat(newQuantity.toFixed(decimalPlaces));
  }, []);
  const handleLocalQuantityChange = (0, _react.useCallback)(factor => {
    setQuantity(prevQuantity => {
      return calculateQuantity({
        factor,
        prevQuantity,
        max,
        min,
        step
      });
    });
  }, [step, max, min, calculateQuantity]);
  const handleTap = (0, _react.useCallback)(factor => {
    setQuantity(prevQuantity => {
      const val = calculateQuantity({
        factor,
        prevQuantity,
        max,
        min,
        step
      });
      onChange === null || onChange === void 0 ? void 0 : onChange(`${val}`);
      return val;
    });
  }, [step, max, min, calculateQuantity, onChange]);
  /* this mimics native spinner press and hold
   * and is lifted from polaris-react
   * https://github.com/Shopify/polaris-react/blob/main/src/components/TextField/TextField.tsx#L320-L346
   **/

  const handleButtonRelease = (0, _react.useCallback)(() => {
    clearTimeout(buttonPressTimer.current);
    setSpinning(false);
    setQuantity(newQuantity => {
      if (newQuantity !== undefined) {
        onChange === null || onChange === void 0 ? void 0 : onChange(`${newQuantity}`);
      }

      return newQuantity === undefined ? quantity : newQuantity;
    });
  }, [onChange, quantity]);
  const handleButtonPress = (0, _react.useCallback)((evt, factor) => {
    // only increment/decrement if it's left click
    if ((evt === null || evt === void 0 ? void 0 : evt.button) !== 0) return; // if somehow spinning already stop it

    if (spinning) {
      handleButtonRelease();
      return;
    }

    const minInterval = 50;
    const decrementBy = 10;
    let interval = 200;

    const onChangeInterval = () => {
      if (!spinning) setSpinning(true);
      if (interval > minInterval) interval -= decrementBy;
      handleLocalQuantityChange(factor);
      buttonPressTimer.current = window.setTimeout(onChangeInterval, interval);
    };

    buttonPressTimer.current = window.setTimeout(onChangeInterval, 0);
    document.addEventListener('mouseup', handleButtonRelease, {
      once: true
    });
    return () => {
      document.removeEventListener('mouseup', handleButtonRelease);
    };
  }, [handleButtonRelease, handleLocalQuantityChange, spinning]);
  return /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react.default.createElement(_TextField.TextFieldInternal, {
    accessibilityDescription: accessibilityDescription,
    "aria-required": required,
    disabled: disabled,
    error: Boolean(error),
    id: id,
    label: label,
    max: max,
    min: min,
    name: name,
    readonly: readonly,
    required: required,
    step: step,
    type: "number",
    value: quantity === undefined ? '' : `${quantity}`,
    onInput: handleMinOrMaxReached,
    onChange: value => {
      setQuantity(Number(value));
      onChange === null || onChange === void 0 ? void 0 : onChange(value);
    },
    onBlur: onBlur,
    onFocus: onFocus
  }, !disabled && !readonly && /*#__PURE__*/_react.default.createElement(SpinButtons, {
    handleButtonPress: handleButtonPress,
    handleTap: handleTap,
    maxReached: maxReached,
    minReached: minReached,
    separator: separator
  })), errorMarkup);
}