"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _Text = require("../Text");

var _Tag = require("./Tag");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Tag />', () => {
  it('renders a basic tag without close icon', () => {
    const str = _faker.default.random.word();

    const tag = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Tag.Tag, null, /*#__PURE__*/_react.default.createElement(_Text.Text, null, str)));
    expect(tag).toContainReactComponent(_Text.Text, {
      children: str
    });
    expect(tag).not.toContainReactComponent(_Icon.Icon, {
      source: 'close'
    });
    expect(tag.findAll(_Icon.Icon)).toHaveLength(0);
  });
  it('renders a tag with a close icon if there is an onRemove method', () => {
    const str = _faker.default.random.word();

    const onRemove = jest.fn();
    const tag = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Tag.Tag, {
      onRemove: onRemove
    }, /*#__PURE__*/_react.default.createElement(_Text.Text, null, str)));
    expect(tag).toContainReactComponent(_Icon.Icon, {
      source: 'close'
    });
  });
  it('calls onRemove when button is clicked', () => {
    const str = _faker.default.random.word();

    const onRemove = jest.fn();
    const tag = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Tag.Tag, {
      onRemove: onRemove
    }, /*#__PURE__*/_react.default.createElement(_Text.Text, null, str)));
    tag.find('button').trigger('onClick');
    expect(onRemove).toHaveBeenCalled();
  });
  it('renders a tag with an icon if there is an icon prop', () => {
    const str = _faker.default.random.word();

    const icon = 'delivered';
    const tag = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Tag.Tag, {
      icon: icon
    }, /*#__PURE__*/_react.default.createElement(_Text.Text, null, str)));
    expect(tag).toContainReactComponent(_Icon.Icon, {
      source: 'delivered'
    });
    expect(tag.findAll(_Icon.Icon)).toHaveLength(1);
  });
});