"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _ = require(".");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  description: _faker.default.lorem.words(2)
};
describe('<Thumbnail />', () => {
  describe('badge', () => {
    it('renders a badge when provided as a string', () => {
      const badge = 'New';
      const thumbnail = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
        badge: badge
      })));
      expect(thumbnail).toContainReactComponent('span', {
        children: badge
      });
    });
    it('renders a badge when provided as a number', () => {
      const badge = 1;
      const thumbnail = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
        badge: badge
      })));
      expect(thumbnail).toContainReactComponent('span', {
        children: badge
      });
    });
  });
  describe('source & description', () => {
    it('renders an <img /> with a src and alt when provided with source and description', () => {
      const source = _faker.default.internet.url();

      const description = _faker.default.lorem.words(2);

      const thumbnail = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, {
        source: source,
        description: description
      }));
      expect(thumbnail).toContainReactComponent('img', {
        src: source,
        alt: description
      });
    });
    it('renders a placeholder Icon if source is not provided', () => {
      const thumbnail = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, defaultProps));
      expect(thumbnail).toContainReactComponent(_Icon.Icon, {
        source: 'camera'
      });
    });
  });
  describe('sources', () => {
    it('renders a <img /> with srcset when provided with sources', () => {
      const source = _faker.default.internet.url();

      const sources = [{
        source: _faker.default.internet.url(),
        resolution: 1
      }, {
        source: _faker.default.internet.url(),
        resolution: 2
      }, {
        source: _faker.default.internet.url(),
        resolution: 3
      }];
      const thumbnail = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, Object.assign({}, defaultProps, {
        source: source,
        sources: sources
      })));
      expect(thumbnail).toContainReactComponent('img', {
        srcSet: sources.map(({
          source,
          resolution
        }) => `${source} ${resolution}x`).join(', ')
      });
    });
    it('does not render a <img /> with srcset if sources are undefined', () => {
      const thumbnail = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_.Thumbnail, defaultProps));
      expect(thumbnail).not.toContainReactComponent('img', {
        srcSet: expect.anything()
      });
    });
  });
});