"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.View = View;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsive = require("../../utilities/responsive");

var _responsiveValue = require("../../utilities/responsiveValue");

var _units = require("../../utilities/units");

var _View = _interopRequireDefault(require("./View.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ELEMENT_MAP = new Map([['region', 'section'], ['complementary', 'aside']]);

function View({
  accessibilityLabel,
  accessibilityVisibility,
  backgroundFit,
  backgroundImage,
  backgroundPosition = 'center',
  backgroundRepeat = false,
  children,
  display = 'block',
  id,
  maxInlineSize,
  role,
  visibility,
  ...props
}) {
  var _ref;

  const responsiveClassNames = (0, _responsive.useResponsive)(props);
  const responsiveStyle = (0, _responsiveValue.useResponsiveStyle)({
    backgroundImage: {
      value: backgroundImage,
      transform: value => `url(${JSON.stringify(value)})`
    },
    maxWidth: {
      value: maxInlineSize,
      transform: value => (0, _units.pixelOrPercent)(value)
    }
  });
  const Element = (_ref = role && ELEMENT_MAP.get(role)) !== null && _ref !== void 0 ? _ref : 'div';
  return /*#__PURE__*/_react.default.createElement(Element, {
    className: (0, _cssUtilities.classNames)(_View.default.View, backgroundImage && backgroundFit && _View.default[(0, _cssUtilities.variationName)('backgroundFit', backgroundFit)], backgroundImage && backgroundPosition && _View.default[(0, _cssUtilities.variationName)('backgroundPosition', backgroundPosition)], backgroundImage && _View.default[(0, _cssUtilities.variationName)('backgroundRepeat', `${backgroundRepeat}`)], display && _View.default[(0, _cssUtilities.variationName)('display', display)], visibility && _View.default[(0, _cssUtilities.variationName)('visibility', visibility)], responsiveClassNames && responsiveClassNames.map(className => _View.default[className])),
    style: responsiveStyle,
    "aria-hidden": accessibilityVisibility === 'hidden' ? true : undefined,
    "aria-label": role && accessibilityLabel,
    id: id
  }, children);
}