"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _faker = _interopRequireDefault(require("faker"));

var _View = require("./View");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<View />', () => {
  describe('children', () => {
    it('renders its children', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, null, text, " "));
      expect(view).toContainReactText(text);
    });
  });
  describe('id', () => {
    it('sets id when id is set', () => {
      const id = _faker.default.random.uuid();

      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        id: id
      }));
      expect(view).toContainReactComponent('div', {
        id
      });
    });
  });
  describe('role', () => {
    it('renders a div by default', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div');
    });
    it('renders a section when "region" is set', () => {
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        role: "region"
      }));
      expect(view).toContainReactComponent('section');
    });
    it('renders an aside when "complimentary" is set', () => {
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        role: "complementary"
      }));
      expect(view).toContainReactComponent('aside');
    });
  });
  describe('accessibilityVisibility', () => {
    it('sets aria-hidden to true when accessibilityVisibility is set', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        accessibilityVisibility: "hidden"
      }, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': true
      });
    });
    it('does not set aria-hidden when accessibilityVisibility is not set', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': undefined
      });
    });
  });
  describe('accessibilityLabel', () => {
    it('sets aria-label with accessibilityLabel if role is set', () => {
      const text = _faker.default.random.words();

      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        accessibilityLabel: text,
        role: "region"
      }));
      expect(view).toContainReactComponent('section', {
        'aria-label': text
      });
    });
    it('does not set aria-label if role is not set', () => {
      const text = _faker.default.random.words();

      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        accessibilityLabel: text
      }));
      expect(view).not.toContainReactComponent('div', {
        'aria-label': text
      });
    });
  });
});