"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useResponsiveValue = useResponsiveValue;
exports.useResponsiveStyle = useResponsiveStyle;
exports.maybeResponsiveToArray = maybeResponsiveToArray;
exports.isResponsiveValue = isResponsiveValue;

var _breakpoint = require("./breakpoint");

function useResponsiveValue(values) {
  const breakpoint = (0, _breakpoint.useBreakpoint)();
  return getResponsiveValue(values, breakpoint);
}

/**
 * Returns a style object matching the passed one, where each property value
 * is the one that applies to the current viewport size.
 *
 * @param options
 */
function useResponsiveStyle(options) {
  const currentBreakpoint = (0, _breakpoint.useBreakpoint)();
  return Object.entries(options).reduce((styleObject, [cssProperty, {
    value,
    transform
  }]) => {
    var _getResponsiveValue;

    return { ...styleObject,
      [cssProperty]: (_getResponsiveValue = getResponsiveValue(maybeResponsiveToArray(value).reduce((values, [breakpoint, breakpointValue]) => {
        if (breakpointValue) {
          return { ...values,
            [breakpoint]: transform ? transform(breakpointValue) : breakpointValue
          };
        }

        return values;
      }, {}), currentBreakpoint)) !== null && _getResponsiveValue !== void 0 ? _getResponsiveValue : {}
    };
  }, {});
}

function maybeResponsiveToArray(maybeResponsive) {
  if (isResponsiveValue(maybeResponsive)) {
    return Object.entries(maybeResponsive);
  }

  return [['base', maybeResponsive]];
}

function isResponsiveValue(obj) {
  if (typeof obj !== 'object' || !obj) {
    return false;
  }

  let hasBreakpoint = false;

  for (const prop of Object.keys(obj)) {
    if (prop in _breakpoint.BREAKPOINTS) {
      hasBreakpoint = true;
    } else {
      return false;
    }
  }

  return hasBreakpoint;
}

function getResponsiveValue(values, breakpoint) {
  if (!breakpoint) {
    return undefined;
  }

  if (values[breakpoint] !== undefined) {
    return values[breakpoint];
  }

  const breakpoints = Object.keys(_breakpoint.BREAKPOINTS);
  const breakpointIndex = breakpoints.indexOf(breakpoint);

  for (let i = breakpointIndex; i >= 0; i--) {
    const breakpoint = breakpoints[i];

    if (values[breakpoint] !== undefined) {
      return values[breakpoint];
    }
  }
}