"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTransition = useTransition;
exports.durations = void 0;

var _react = require("react");

var _mediaQuery = require("./media-query");

const durations = new Map([['none', 0], ['fast', 133.333], ['base', 200], ['slow', 300], ['slower', 450], ['slowest', 675]]);
exports.durations = durations;

function useTransition(transitionIn, duration = 'slow', transitionOnMount = false) {
  const [state, setState] = (0, _react.useState)(transitionOnMount ? false : transitionIn);
  const [transitioning, setTransitioning] = (0, _react.useState)(false);
  const transitionInRef = (0, _react.useRef)(transitionOnMount ? false : transitionIn);
  const endTransitionRef = (0, _react.useRef)(() => {
    setTransitioning(false);
    setState(transitionInRef.current);
  });
  const prefersReducedMotion = (0, _mediaQuery.usePrefersReducedMotion)();
  (0, _react.useEffect)(() => {
    var _enterDuration, _exitDuration;

    if (transitionIn !== transitionInRef.current) setTransitioning(true);
    transitionInRef.current = transitionIn;
    let enterDuration = typeof duration === 'string' ? duration : duration.enter;
    let exitDuration = typeof duration === 'string' ? duration : duration.exit;

    if (prefersReducedMotion) {
      enterDuration = 'none';
      exitDuration = 'none';
    }

    const timeout = setTimeout(endTransitionRef.current, transitionIn ? durations.get((_enterDuration = enterDuration) !== null && _enterDuration !== void 0 ? _enterDuration : 'none') : durations.get((_exitDuration = exitDuration) !== null && _exitDuration !== void 0 ? _exitDuration : 'none'));
    return () => {
      clearTimeout(timeout);
    };
  }, [duration, prefersReducedMotion, transitionIn]);

  if (transitioning) {
    return transitionIn ? 'entering' : 'exiting';
  }

  if (transitionIn === state) {
    return transitionIn ? 'entered' : 'exited';
  }

  return transitionIn ? 'enter' : 'exit';
}