"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const forms_1 = require("../../utilities/forms");
const AppContext_1 = require("../AppContext");
const transition_1 = require("../../utilities/transition");
const Spinner_1 = require("../Spinner");
const Link_1 = require("../Link");
const legacy_1 = require("../../utilities/legacy");
const media_query_1 = require("../../utilities/media-query");
const Connected_1 = require("../Connected");
const Theme_1 = require("../Theme");
const responsive_1 = require("../../utilities/responsive");
const typography_styles_css_1 = __importDefault(require("../../utilities/typography-styles.css"));
const Button_css_1 = __importDefault(require("./Button.css"));
exports.Button = react_1.forwardRef(function Button({ children, kind = 'primary', submit = false, disabled, onPress, to, loading = false, loadingLabel, accessibilityLabel, fill = false, appearance, onMouseEnter, size = 'base', }, ref) {
    const href = disabled ? undefined : to;
    const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
    const refsSetter = react_1.useCallback((instance) => {
        if (typeof ref === 'function') {
            ref(instance);
        }
        else if (ref) {
            ref.current = instance;
        }
    }, [ref]);
    const translate = AppContext_1.useTranslate();
    const prefersReducedMotion = media_query_1.usePrefersReducedMotion();
    const transition = transition_1.useTransition(loading, {
        enter: 'slow',
    });
    const connected = Connected_1.useConnected();
    const responsiveSizes = responsive_1.useResponsive({ size });
    const { primaryButton: { style: primaryStyle = 'fill', border: primaryBorder = 'none', typographyStyle: primaryTypographyStyle, loadingStyle: primaryLoading = 'spinner', }, secondaryButton: { style: secondaryStyle = 'inverse', border: secondaryBorder = 'full', typographyStyle: secondaryTypographyStyle, loadingStyle: secondaryLoading = 'spinner', }, link: { colorHovered: plainColorHovered, typographyStyle: linkTypographyStyle, }, } = Theme_1.useThemeConfiguration();
    const form = forms_1.useContainingForm();
    const isSecondary = kind === 'secondary';
    const style = isSecondary ? secondaryStyle : primaryStyle;
    const border = isSecondary ? secondaryBorder : primaryBorder;
    const typographyStyle = isSecondary
        ? secondaryTypographyStyle
        : primaryTypographyStyle;
    const loadingStyle = isSecondary ? secondaryLoading : primaryLoading;
    const isPlain = kind === 'plain' || style === 'plain';
    const classes = css_utilities_1.classNames(Button_css_1.default.Button, kind && !isPlain && Button_css_1.default[css_utilities_1.variationName('kind', kind)], responsiveSizes &&
        !isPlain &&
        responsiveSizes.map((className) => Button_css_1.default[className]), border && !isPlain && Button_css_1.default[css_utilities_1.variationName('border', border)], style && !isPlain && Button_css_1.default[css_utilities_1.variationName('style', style)], appearance && Button_css_1.default[css_utilities_1.variationName('appearance', appearance)], isPlain && Button_css_1.default.stylePlain, isPlain &&
        plainColorHovered &&
        Button_css_1.default[css_utilities_1.variationName('stylePlainColorHovered', plainColorHovered)], fill && Button_css_1.default.fill, disabled && Button_css_1.default.disabled, loading && Button_css_1.default[css_utilities_1.variationName('loading', loadingStyle)], loading &&
        loadingStyle === 'spinner' &&
        Button_css_1.default[css_utilities_1.variationName('loading-transition', transition)], !isPlain && typographyStyle && typography_styles_css_1.default[typographyStyle], isPlain && linkTypographyStyle && typography_styles_css_1.default[linkTypographyStyle], connected && Button_css_1.default.connected, 
    /* Basic theming for older browsers that do not support CSS Custom Properties: */
    legacy_1.button, kind === 'primary' && legacy_1.buttonPrimary, kind === 'secondary' && legacy_1.buttonSecondary, appearance === 'critical' && legacy_1.buttonCritical, kind === 'plain' && appearance === 'critical' && legacy_1.colorCriticalAccent);
    const normalizedLoadingLabel = loadingLabel
        ? loadingLabel
        : translate('processing');
    const contentClassNames = css_utilities_1.classNames(Button_css_1.default.Content);
    const content = (<span className={contentClassNames}>
      {loading && loadingStyle === 'progressBar' && prefersReducedMotion
        ? normalizedLoadingLabel
        : children}
    </span>);
    const type = submit ? 'submit' : 'button';
    const loadingMarkup = loadingStyle === 'spinner' ? (<span className={css_utilities_1.classNames(Button_css_1.default.LoadingContent, !prefersReducedMotion && Button_css_1.default.Spinner)}>
        <Spinner_1.Spinner size="small" color="inherit" accessibilityLabel={normalizedLoadingLabel}/>
      </span>) : (<span className={Button_css_1.default.ProgressBar}/>);
    if (href) {
        return (<Link_1.UnstyledLink to={href} className={classes} onPress={onPress} ariaBusy={loading} ariaLive={loading ? 'assertive' : 'polite'} ariaLabel={accessibilityLabel}>
        {content}
        {loading && loadingMarkup}
      </Link_1.UnstyledLink>);
    }
    return (<button type={type} form={submit && (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined} className={classes} disabled={disabled || loading} onClick={onClick} aria-busy={loading || undefined} aria-live={loading ? 'assertive' : undefined} aria-label={accessibilityLabel} ref={refsSetter} onMouseEnter={onMouseEnter}>
      {content}
      {loading && loadingMarkup}
    </button>);
});
