"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const test_utilities_1 = require("../../test-utilities");
const Collapsible_1 = require("./Collapsible");
describe('<Collapsible />', () => {
    describe('open', () => {
        it('renders children but is hidden when closed', () => {
            const collapsible = test_utilities_1.mountWithContext(<Collapsible_1.Collapsible id="test-collapsible" open={false}>
          content
        </Collapsible_1.Collapsible>);
            expect(collapsible).toContainReactComponent('div', {
                'aria-expanded': false,
                hidden: true,
                style: { height: 0 },
            });
            expect(collapsible).toContainReactText('content');
        });
        it('renders children and is aria-expanded when open', () => {
            const collapsible = test_utilities_1.mountWithContext(<Collapsible_1.Collapsible id="test-collapsible" open>
          content
        </Collapsible_1.Collapsible>);
            expect(collapsible).toContainReactComponent('div', {
                'aria-expanded': true,
                hidden: false,
                style: { height: 'auto' },
            });
            expect(collapsible).toContainReactText('content');
        });
    });
    describe('minSize', () => {
        it('height is set to minSize when closed and not hidden', () => {
            const minSize = 50;
            const collapsible = test_utilities_1.mountWithContext(<Collapsible_1.Collapsible id="test-collapsible" open={false} minSize={minSize}>
          content
        </Collapsible_1.Collapsible>);
            expect(collapsible).toContainReactComponent('div', {
                'aria-expanded': false,
                hidden: false,
                style: { height: minSize },
            });
        });
    });
});
