"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../../../test-utilities");
const UnstyledLink_1 = require("./UnstyledLink");
const defaultProps = {
    to: faker_1.default.internet.url(),
};
describe('<UnstyledLink />', () => {
    it('renders an anchor with expected target and rel if external', () => {
        const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} external/>);
        expect(unstyledLink).toContainReactComponent('a', {
            target: '_blank',
            rel: 'noopener noreferrer',
        });
    });
    it('renders an anchor without target or rel if not external', () => {
        const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>);
        expect(unstyledLink).toContainReactComponent('a', {
            target: undefined,
            rel: undefined,
        });
    });
    it('renders a custom link provided by the consumer', () => {
        function CustomLink() {
            return <div>No navigation allowed!</div>;
        }
        const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>, {
            linkComponent: CustomLink,
        });
        expect(unstyledLink).toContainReactComponent(CustomLink, defaultProps);
    });
    describe('language', () => {
        it('renders an anchor with lang attribute', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} language="en"/>);
            expect(unstyledLink).toContainReactComponent('a', {
                lang: 'en',
            });
        });
    });
    describe('ariaBusy', () => {
        it('renders an anchor with aria-busy when set', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} ariaBusy/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-busy': true,
            });
        });
        it('renders an anchor without aria-busy when not set', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-busy': undefined,
            });
        });
        it('renders an anchor without aria-busy when false', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} ariaBusy={false}/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-busy': undefined,
            });
        });
    });
    describe('ariaLive', () => {
        it('renders an anchor with aria-live value when set', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} ariaLive="assertive"/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-live': 'assertive',
            });
        });
        it('does not renders with aria-live when not set', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-live': undefined,
            });
        });
    });
    describe('ariaLabel', () => {
        it('renders an anchor with aria-label when set', () => {
            const content = 'Accessible label';
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} ariaLabel={content}/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-label': content,
            });
        });
        it('does not renders with aria-live when not set', () => {
            const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>);
            expect(unstyledLink).toContainReactComponent('a', {
                'aria-label': undefined,
            });
        });
    });
});
