"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const test_utilities_1 = require("../../test-utilities");
const List_1 = require("./List");
describe('<List />', () => {
    describe('children', () => {
        it('renders the children', () => {
            const content = 'Snowdevil';
            const list = test_utilities_1.mountWithContext(<List_1.List>{content}</List_1.List>);
            expect(list).toContainReactText(content);
        });
        it('renders a <ul> tag by default', () => {
            const content = 'Snowdevil';
            const list = test_utilities_1.mountWithContext(<List_1.List>{content}</List_1.List>);
            expect(list).toContainReactComponent('ul');
        });
    });
    describe('marker', () => {
        it('renders a <ol> tag when marker set to "number"', () => {
            const content = 'Snowdevil';
            const list = test_utilities_1.mountWithContext(<List_1.List marker="number">{content}</List_1.List>);
            expect(list).toContainReactComponent('ol');
        });
        it('sets a role of "list" for accessibility when marker is "none"', () => {
            const content = 'Snowdevil';
            const list = test_utilities_1.mountWithContext(<List_1.List marker="none">{content}</List_1.List>);
            expect(list).toContainReactComponent('ul', { role: 'list' });
        });
    });
});
describe('<ListItem />', () => {
    describe('children', () => {
        it('renders the children', () => {
            const content = 'Snowdevil';
            const list = test_utilities_1.mountWithContext(<List_1.List>
          <List_1.ListItem>{content}</List_1.ListItem>
        </List_1.List>);
            expect(list).toContainReactText(content);
        });
    });
});
