"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MoneyLineContent = exports.MoneyLineHeader = exports.MoneyLine = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Text_1 = require("../../../Text");
const Theme_1 = require("../../../Theme");
const MoneyLine_css_1 = __importDefault(require("./MoneyLine.css"));
function hasChildren(props) {
    return props.children !== undefined;
}
function MoneyLine(props) {
    const { moneyLines: { background, blockPadding, inlinePadding, inlineAlignment, labelTypographyStyle, valueTypographyStyle, }, } = Theme_1.useThemeConfiguration();
    const className = css_utilities_1.classNames(MoneyLine_css_1.default.MoneyLine, background && MoneyLine_css_1.default[css_utilities_1.variationName('background', background)], blockPadding && MoneyLine_css_1.default[css_utilities_1.variationName('blockPadding', blockPadding)], inlineAlignment &&
        MoneyLine_css_1.default[css_utilities_1.variationName('inlineAlignment', inlineAlignment)], inlinePadding && MoneyLine_css_1.default[css_utilities_1.variationName('inlinePadding', inlinePadding)]);
    return (<div className={className} role="row">
      {hasChildren(props) ? (props.children) : (<>
          <MoneyLineHeader>
            <Text_1.Text style={labelTypographyStyle}>{props.label}</Text_1.Text>
          </MoneyLineHeader>
          <MoneyLineContent>
            <Text_1.Text subdued={props.subdued} emphasized={!props.subdued} size={props.subdued ? 'small' : undefined} style={valueTypographyStyle}>
              {props.value}
            </Text_1.Text>
          </MoneyLineContent>
        </>)}
    </div>);
}
exports.MoneyLine = MoneyLine;
function MoneyLineHeader({ children }) {
    return (<div className={MoneyLine_css_1.default.Header} role="rowheader">
      {children}
    </div>);
}
exports.MoneyLineHeader = MoneyLineHeader;
function MoneyLineContent({ children }) {
    return (<div className={MoneyLine_css_1.default.Content} role="cell">
      {children}
    </div>);
}
exports.MoneyLineContent = MoneyLineContent;
