"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../../../test-utilities");
const Text_1 = require("../../../Text");
const MoneyLine_1 = require("./MoneyLine");
describe('<MoneyLine />', () => {
    it('renders a label', () => {
        const label = faker_1.default.random.word();
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine label={label}/>);
        expect(moneyLine.find(MoneyLine_1.MoneyLineHeader)).toContainReactComponent(Text_1.Text, {
            children: label,
        });
    });
    it('renders a value', () => {
        const value = faker_1.default.random.word();
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine label="label" value={value}/>);
        expect(moneyLine.find(MoneyLine_1.MoneyLineContent)).toContainReactComponent(Text_1.Text, {
            children: value,
        });
    });
    it('renders a subdued value', () => {
        const value = faker_1.default.random.word();
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine label="label" value={value} subdued/>);
        expect(moneyLine.find(MoneyLine_1.MoneyLineContent)).toContainReactComponent(Text_1.Text, {
            subdued: true,
            children: value,
        });
    });
    it('renders the children', () => {
        const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine>
        <MoneyLine_1.MoneyLineHeader />
        <MoneyLine_1.MoneyLineContent />
      </MoneyLine_1.MoneyLine>);
        expect(moneyLine).toContainReactComponent(MoneyLine_1.MoneyLineHeader);
        expect(moneyLine).toContainReactComponent(MoneyLine_1.MoneyLineContent);
    });
    describe('<MoneyLineHeader />', () => {
        it('renders the children', () => {
            const children = 'children';
            const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine>
          <MoneyLine_1.MoneyLineHeader>{children}</MoneyLine_1.MoneyLineHeader>
        </MoneyLine_1.MoneyLine>);
            expect(moneyLine.find(MoneyLine_1.MoneyLineHeader)).toContainReactText(children);
        });
    });
    describe('<MoneyLineContent />', () => {
        it('renders the children', () => {
            const children = 'children';
            const moneyLine = test_utilities_1.mountWithContext(<MoneyLine_1.MoneyLine>
          <MoneyLine_1.MoneyLineContent>{children}</MoneyLine_1.MoneyLineContent>
        </MoneyLine_1.MoneyLine>);
            expect(moneyLine.find(MoneyLine_1.MoneyLineContent)).toContainReactText(children);
        });
    });
});
