"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MoneySummaryContent = exports.MoneySummaryHeader = exports.MoneySummary = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const InlineStack_1 = require("../../../InlineStack");
const Text_1 = require("../../../Text");
const Divider_1 = require("../../../Divider");
const Theme_1 = require("../../../Theme");
const MoneySummary_css_1 = __importDefault(require("./MoneySummary.css"));
function hasChildren(props) {
    return props.children !== undefined;
}
function MoneySummary(props) {
    const { moneyLines: { divided, dividerSpacing, inlineAlignment }, moneySummary: { background, blockPadding, currencyCode = true, currencyTypographyStyle, inlinePadding, labelTypographyStyle, valueTypographyStyle, }, } = Theme_1.useThemeConfiguration();
    const className = css_utilities_1.classNames(MoneySummary_css_1.default.MoneySummary, background && MoneySummary_css_1.default[css_utilities_1.variationName('background', background)], blockPadding && MoneySummary_css_1.default[css_utilities_1.variationName('blockPadding', blockPadding)], inlineAlignment &&
        MoneySummary_css_1.default[css_utilities_1.variationName('inlineAlignment', inlineAlignment)], inlinePadding && MoneySummary_css_1.default[css_utilities_1.variationName('inlinePadding', inlinePadding)]);
    return (<>
      {divided && <Divider_1.Divider blockSpacing={dividerSpacing}/>}
      <div className={className} role="row">
        {hasChildren(props) ? (props.children) : (<>
            <MoneySummaryHeader>
              <Text_1.Text emphasized size="medium" style={labelTypographyStyle}>
                {props.label}
              </Text_1.Text>
            </MoneySummaryHeader>
            <MoneySummaryContent>
              <InlineStack_1.InlineStack alignment="baseline" spacing="tight">
                
                {currencyCode && (<Text_1.Text role={{ type: 'abbreviation' }} size="small" subdued style={currencyTypographyStyle}>
                    {props.prefix}
                  </Text_1.Text>)}
                <Text_1.Text emphasized size="extraLarge" style={valueTypographyStyle}>
                  {props.value}
                </Text_1.Text>
              </InlineStack_1.InlineStack>
            </MoneySummaryContent>
          </>)}
      </div>
    </>);
}
exports.MoneySummary = MoneySummary;
function MoneySummaryHeader({ children }) {
    return (<div className={MoneySummary_css_1.default.Header} role="rowheader">
      {children}
    </div>);
}
exports.MoneySummaryHeader = MoneySummaryHeader;
function MoneySummaryContent({ children }) {
    return (<div className={MoneySummary_css_1.default.Content} role="cell">
      {children}
    </div>);
}
exports.MoneySummaryContent = MoneySummaryContent;
