"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../../../test-utilities");
const Text_1 = require("../../../Text");
const MoneySummary_1 = require("./MoneySummary");
describe('<MoneySummary />', () => {
    it('renders a label', () => {
        const label = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary label={label} prefix="prefix" value="value"/>);
        expect(moneySummary.find(MoneySummary_1.MoneySummaryHeader)).toContainReactComponent(Text_1.Text, {
            children: label,
        });
    });
    it('renders a prefix', () => {
        const prefix = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary label="label" prefix={prefix} value="value"/>);
        expect(moneySummary.find(MoneySummary_1.MoneySummaryContent)).toContainReactComponent(Text_1.Text, {
            children: prefix,
        });
    });
    it('renders a value', () => {
        const value = faker_1.default.random.word();
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary label="label" prefix="prefix" value={value}/>);
        expect(moneySummary.find(MoneySummary_1.MoneySummaryContent)).toContainReactComponent(Text_1.Text, {
            children: value,
        });
    });
    it('renders the children', () => {
        const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary>
        <MoneySummary_1.MoneySummaryHeader />
        <MoneySummary_1.MoneySummaryContent />
      </MoneySummary_1.MoneySummary>);
        expect(moneySummary).toContainReactComponent(MoneySummary_1.MoneySummaryHeader);
        expect(moneySummary).toContainReactComponent(MoneySummary_1.MoneySummaryContent);
    });
    describe('<MoneySummaryHeader />', () => {
        it('renders the children', () => {
            const children = 'children';
            const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary label="label" prefix="prefix" value="value">
          <MoneySummary_1.MoneySummaryHeader>{children}</MoneySummary_1.MoneySummaryHeader>
        </MoneySummary_1.MoneySummary>);
            expect(moneySummary.find(MoneySummary_1.MoneySummaryHeader)).toContainReactText(children);
        });
    });
    describe('<MoneySummaryContent />', () => {
        it('renders the children', () => {
            const children = 'children';
            const moneySummary = test_utilities_1.mountWithContext(<MoneySummary_1.MoneySummary label="label" prefix="prefix" value="value">
          <MoneySummary_1.MoneySummaryContent>{children}</MoneySummary_1.MoneySummaryContent>
        </MoneySummary_1.MoneySummary>);
            expect(moneySummary.find(MoneySummary_1.MoneySummaryContent)).toContainReactText(children);
        });
    });
});
