"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Popover = void 0;
const css_utilities_1 = require("@shopify/css-utilities");
const react_1 = __importStar(require("react"));
const id_1 = require("../../utilities/id");
const focus_1 = require("../../utilities/focus");
const Popper_1 = require("../Popper");
const Theme_1 = require("../Theme");
const Popover_css_1 = __importDefault(require("./Popover.css"));
const createId = id_1.createIdCreator('Popover');
function Popover({ children, activator, open, placement = 'inlineEnd', backdrop = 'none', onClose, }) {
    const popoverRef = react_1.useRef(null);
    const { popover: { connector = 'arrow', depth = 'far' }, } = Theme_1.useThemeConfiguration();
    const id = id_1.useId(undefined, createId);
    const setActivatorAccessibilityAttributes = react_1.useCallback(() => {
        activator === null || activator === void 0 ? void 0 : activator.setAttribute('aria-controls', id);
        activator === null || activator === void 0 ? void 0 : activator.setAttribute('aria-expanded', String(open));
    }, [activator === null || activator === void 0 ? void 0 : activator.setAttribute, id, open]);
    const handleClose = react_1.useCallback(() => {
        onClose === null || onClose === void 0 ? void 0 : onClose();
    }, [onClose]);
    const handleClickOutside = react_1.useCallback((event) => {
        if (event.target instanceof Node &&
            !(activator === null || activator === void 0 ? void 0 : activator.contains(event.target)) &&
            open) {
            handleClose();
        }
    }, [activator === null || activator === void 0 ? void 0 : activator.contains, open, handleClose]);
    const handleKeyDown = react_1.useCallback((event) => {
        if (!open)
            return;
        const nextFocusableNode = activator && focus_1.findNextFocusableNode(activator);
        const firstFocusableNode = popoverRef.current && focus_1.findFirstFocusableNode(popoverRef.current);
        const lastFocusableNode = popoverRef.current && focus_1.findLastFocusableNode(popoverRef.current);
        switch (event.key) {
            case 'Escape':
            case 'Esc':
                handleClose();
                activator === null || activator === void 0 ? void 0 : activator.focus();
                break;
            case 'Tab': {
                if (focus_1.isFocused(activator) && event.shiftKey) {
                    handleClose();
                }
                else if (focus_1.isFocused(activator)) {
                    event.preventDefault();
                    firstFocusableNode === null || firstFocusableNode === void 0 ? void 0 : firstFocusableNode.focus();
                }
                else if (focus_1.isFocused(firstFocusableNode) && event.shiftKey) {
                    event.preventDefault();
                    activator === null || activator === void 0 ? void 0 : activator.focus();
                    handleClose();
                }
                else if (focus_1.isFocused(lastFocusableNode) && !event.shiftKey) {
                    event.preventDefault();
                    nextFocusableNode === null || nextFocusableNode === void 0 ? void 0 : nextFocusableNode.focus();
                    handleClose();
                }
                break;
            }
        }
    }, [open, activator, handleClose, activator === null || activator === void 0 ? void 0 : activator.focus]);
    react_1.useEffect(() => {
        document.addEventListener('click', handleClickOutside);
        return () => {
            document.removeEventListener('click', handleClickOutside);
        };
    }, [handleClickOutside]);
    react_1.useEffect(() => {
        if (open) {
            document.addEventListener('keydown', handleKeyDown, false);
        }
        return () => {
            document.removeEventListener('keydown', handleKeyDown, false);
        };
    }, [open, handleKeyDown]);
    react_1.useEffect(() => {
        setActivatorAccessibilityAttributes();
    });
    const popoverClassName = css_utilities_1.classNames(Popover_css_1.default.Popover, Popover_css_1.default[css_utilities_1.variationName('Popover-placement', placement)], Popover_css_1.default[css_utilities_1.variationName('Popover-connector', connector)], Popover_css_1.default[css_utilities_1.variationName('Popover-depth', depth)]);
    const contentClassName = css_utilities_1.classNames(Popover_css_1.default.Content, Popover_css_1.default[css_utilities_1.variationName('Content-placement', placement)]);
    const backdropClassName = css_utilities_1.classNames(Popover_css_1.default.Backdrop, Popover_css_1.default[css_utilities_1.variationName('Backdrop-style', backdrop)]);
    const offset = connector === 'arrow' ? 15 : 5;
    return open ? (<>
      <Popper_1.Popper activator={activator} placement={placement} offset={offset} preventOverflow>
        <div className={popoverClassName} id={id} ref={popoverRef}>
          <div className={contentClassName}>{children}</div>
        </div>
      </Popper_1.Popper>
      {backdrop === 'translucent' ? (<div className={backdropClassName}/>) : null}
    </>) : null;
}
exports.Popover = Popover;
