"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../test-utilities");
const Icon_1 = require("../Icon");
const Text_1 = require("../Text");
const Tag_1 = require("./Tag");
describe('<Tag />', () => {
    it('renders a basic tag without close icon', () => {
        const str = faker_1.default.random.word();
        const tag = test_utilities_1.mountWithContext(<Tag_1.Tag>
        <Text_1.Text>{str}</Text_1.Text>
      </Tag_1.Tag>);
        expect(tag).toContainReactComponent(Text_1.Text, {
            children: str,
        });
        expect(tag).not.toContainReactComponent(Icon_1.Icon, { source: 'close' });
        expect(tag.findAll(Icon_1.Icon)).toHaveLength(0);
    });
    it('renders a tag with a close icon if there is an onRemove method', () => {
        const str = faker_1.default.random.word();
        const onRemove = jest.fn();
        const tag = test_utilities_1.mountWithContext(<Tag_1.Tag onRemove={onRemove}>
        <Text_1.Text>{str}</Text_1.Text>
      </Tag_1.Tag>);
        expect(tag).toContainReactComponent(Icon_1.Icon, {
            source: 'close',
        });
    });
    it('calls onRemove when button is clicked', () => {
        const str = faker_1.default.random.word();
        const onRemove = jest.fn();
        const tag = test_utilities_1.mountWithContext(<Tag_1.Tag onRemove={onRemove}>
        <Text_1.Text>{str}</Text_1.Text>
      </Tag_1.Tag>);
        tag.find('button').trigger('onClick');
        expect(onRemove).toHaveBeenCalled();
    });
    it('renders a tag with an icon if there is an icon prop', () => {
        const str = faker_1.default.random.word();
        const icon = 'delivered';
        const tag = test_utilities_1.mountWithContext(<Tag_1.Tag icon={icon}>
        <Text_1.Text>{str}</Text_1.Text>
      </Tag_1.Tag>);
        expect(tag).toContainReactComponent(Icon_1.Icon, {
            source: 'delivered',
        });
        expect(tag.findAll(Icon_1.Icon)).toHaveLength(1);
    });
});
