"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findNextFocusableNode = exports.findLastFocusableNode = exports.findFirstFocusableNode = exports.FOCUSABLE_SELECTOR = exports.isFocused = void 0;
function isFocused(element) {
    return document.activeElement === element;
}
exports.isFocused = isFocused;
exports.FOCUSABLE_SELECTOR = `
  a[href],
  area[href],
  input:not([type="hidden"]):not([disabled]):not([tabindex="-1"]),
  select:not([disabled]),
  textarea:not([disabled]),
  button:not([disabled]):not([tabindex="-1"]),
  iframe,
  object,
  embed,
  [tabindex="0"],
  [contenteditable],
  audio[controls],
  video[controls]`;
/* https://github.com/Shopify/javascript-utilities/blob/master/src/focus.ts */
function findFirstFocusableNode(element, onlyDescendants = true) {
    if (!onlyDescendants && element.matches(exports.FOCUSABLE_SELECTOR)) {
        return element;
    }
    return element.querySelector(exports.FOCUSABLE_SELECTOR);
}
exports.findFirstFocusableNode = findFirstFocusableNode;
function findLastFocusableNode(element, onlyDescendants = true) {
    if (!onlyDescendants && element.matches(exports.FOCUSABLE_SELECTOR)) {
        return element;
    }
    const allFocusable = element.querySelectorAll(exports.FOCUSABLE_SELECTOR);
    return allFocusable[allFocusable.length - 1];
}
exports.findLastFocusableNode = findLastFocusableNode;
function findNextFocusableNode(node) {
    const allFocusableElements = [
        ...document.querySelectorAll(exports.FOCUSABLE_SELECTOR),
    ];
    const nodeIndex = allFocusableElements.findIndex((currentNode) => node === currentNode);
    if (nodeIndex) {
        return allFocusableElements[nodeIndex + 1];
    }
    return null;
}
exports.findNextFocusableNode = findNextFocusableNode;
