"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isResponsiveValue = exports.maybeResponsiveToArray = exports.useResponsiveStyle = exports.useResponsiveValue = void 0;
const breakpoint_1 = require("./breakpoint");
function useResponsiveValue(values) {
    const breakpoint = breakpoint_1.useBreakpoint();
    return getResponsiveValue(values, breakpoint);
}
exports.useResponsiveValue = useResponsiveValue;
/**
 * Returns a style object matching the passed one, where each property value
 * is the one that applies to the current viewport size.
 *
 * @param options
 */
function useResponsiveStyle(options) {
    const currentBreakpoint = breakpoint_1.useBreakpoint();
    return Object.entries(options).reduce((styleObject, [cssProperty, { value, transform }]) => {
        var _a;
        return Object.assign(Object.assign({}, styleObject), { [cssProperty]: (_a = getResponsiveValue(maybeResponsiveToArray(value).reduce((values, [breakpoint, breakpointValue]) => {
                if (breakpointValue) {
                    return Object.assign(Object.assign({}, values), { [breakpoint]: transform
                            ? transform(breakpointValue)
                            : breakpointValue });
                }
                return values;
            }, {}), currentBreakpoint)) !== null && _a !== void 0 ? _a : {} });
    }, {});
}
exports.useResponsiveStyle = useResponsiveStyle;
function maybeResponsiveToArray(maybeResponsive) {
    if (isResponsiveValue(maybeResponsive)) {
        return Object.entries(maybeResponsive);
    }
    return [['base', maybeResponsive]];
}
exports.maybeResponsiveToArray = maybeResponsiveToArray;
function isResponsiveValue(obj) {
    if (typeof obj !== 'object' || !obj) {
        return false;
    }
    let hasBreakpoint = false;
    for (const prop of Object.keys(obj)) {
        if (prop in breakpoint_1.BREAKPOINTS) {
            hasBreakpoint = true;
        }
        else {
            return false;
        }
    }
    return hasBreakpoint;
}
exports.isResponsiveValue = isResponsiveValue;
function getResponsiveValue(values, breakpoint) {
    if (!breakpoint) {
        return undefined;
    }
    if (values[breakpoint] !== undefined) {
        return values[breakpoint];
    }
    const breakpoints = Object.keys(breakpoint_1.BREAKPOINTS);
    const breakpointIndex = breakpoints.indexOf(breakpoint);
    for (let i = breakpointIndex; i >= 0; i--) {
        const breakpoint = breakpoints[i];
        if (values[breakpoint] !== undefined) {
            return values[breakpoint];
        }
    }
}
